@@ -28,23 +28,23 @@ function install-cmake() {
 }
 
 function install-fmt {
-    echo "::group::Installing fmt"
-  if [[ "$lsb_codename" == "bionic" || $lsb_codename == "buster" ]]; then
+  echo "::group::Installing fmt"
+  #if [[ "$lsb_codename" == "bionic" || "$lsb_codename" == "buster" || "$lsb_codename" == "hirsute" ]]; then
     sudo bash scripts/install-fmt.sh static
-  else
-     sudo apt-get install libfmt-dev -y
-  fi
+  #else
+  #   sudo apt-get install libfmt-dev -y
+  #fi
   echo "::endgroup::"
 }
 
 function install-spdlog() {
   echo "::group::Installing spdlog"
 
-  if [[ "$lsb_codename" == "bionic" || $lsb_codename == "buster" ]]; then
+  #if [[ "$lsb_codename" == "bionic" || "$lsb_codename" == "buster" || "$lsb_codename" == "hirsute" ]]; then
     sudo bash scripts/install-spdlog.sh
-  else
-    sudo apt-get install libspdlog-dev -y
-  fi
+  #else
+  #  sudo apt-get install libspdlog-dev -y
+  #fi
   echo "::endgroup::"
 }
 
@@ -61,16 +61,22 @@ function upload_to_artifactory() {
 export DEBIAN_FRONTEND=noninteractive
 lsb_codename=$(lsb_release -c --short)
 lsb_distro=$(lsb_release -i --short)
+lsb_rel=$(lsb_release -r --short)
 
 install-gcc
 install-cmake
 
+echo "Running $0 $1"
+
 libduktape="libduktape205"
 if [[ "$lsb_codename" == "bionic" ]]; then
   libduktape="libduktape202"
-elif [ $lsb_codename == "buster" ]; then
+elif [ "$lsb_codename" == "buster" ]; then
   libduktape="libduktape203"
+elif [ "$lsb_codename" == "sid" -o "$1" == "debian:testing" -o "$1" == "debian:unstable" ]; then
+  libduktape="libduktape206"
 fi
+echo "Selecting $libduktape for $lsb_distro $lsb_codename"
 
 libmysqlclient="libmysqlclient-dev"
 if [ "$lsb_distro" == "Debian" ]; then
