@@ -77,13 +77,13 @@ static constexpr bool IS_CDS_ITEM_EXTERNAL_URL(unsigned int type) { return type
 class CdsObject {
 protected:
     /// \brief ID of the object in the content directory
-    int id;
+    int id { INVALID_OBJECT_ID };
 
     /// \brief ID of the referenced object
-    int refID;
+    int refID { INVALID_OBJECT_ID };
 
     /// \brief ID of the object's parent
-    int parentID;
+    int parentID { INVALID_OBJECT_ID };
 
     /// \brief dc:title
     std::string title;
@@ -96,22 +96,26 @@ protected:
 
     /// \brief Last modification time in the file system.
     /// In seconds since UNIX epoch.
-    std::chrono::seconds mtime;
+    std::chrono::seconds mtime {};
+
+    /// \brief Last update time in database
+    /// In seconds since UNIX epoch.
+    std::chrono::seconds utime {};
 
     /// \brief File size on disk (in bytes).
-    off_t sizeOnDisk;
+    off_t sizeOnDisk {};
 
     /// \brief virtual object flag
-    bool virt;
+    bool virt {};
 
     /// \brief type of the object: item, container, etc.
     unsigned int objectType;
 
     /// \brief field which can hold various flags for the object
-    unsigned int objectFlags;
+    unsigned int objectFlags { OBJECT_FLAG_RESTRICTED };
 
     /// \brief flag that allows to sort objects within a container
-    int sortPriority;
+    int sortPriority {};
 
     std::map<std::string, std::string> metadata;
     std::map<std::string, std::string> auxdata;
@@ -121,8 +125,6 @@ protected:
     std::shared_ptr<CdsObject> parent;
 
 public:
-    /// \brief Constructor. Sets the default values.
-    explicit CdsObject();
     virtual ~CdsObject() = default;
 
     /// \brief Set the object ID.
@@ -149,7 +151,7 @@ public:
 
     /// \brief Set the parent ID of the object.
     void setParentID(int parentID) { this->parentID = parentID; }
-    void setParent(std::shared_ptr<CdsObject>& parent) { this->parent = parent; }
+    void setParent(const std::shared_ptr<CdsObject>& parent) { this->parent = parent; }
 
     /// \brief Retrieve the objects parent ID.
     int getParentID() const { return parentID; }
@@ -157,43 +159,41 @@ public:
 
     /// \brief Set the restricted flag.
     void setRestricted(bool restricted) { changeFlag(OBJECT_FLAG_RESTRICTED, restricted); }
-
     /// \brief Query the restricted flag.
     bool isRestricted() const { return getFlag(OBJECT_FLAG_RESTRICTED); }
 
     /// \brief Set the object title (dc:title)
     void setTitle(const std::string& title) { this->title = title; }
-
     /// \brief Retrieve the title.
     std::string getTitle() const { return title; }
 
     /// \brief set the upnp:class
     void setClass(const std::string& upnpClass) { this->upnpClass = upnpClass; }
-
     /// \brief Retrieve class
     std::string getClass() const { return upnpClass; }
 
     /// \brief Set the physical location of the media (usually an absolute path)
     void setLocation(const fs::path& location) { this->location = location; }
-
     /// \brief Retrieve media location.
     fs::path getLocation() const { return location; }
 
     /// \brief Set modification time of the media file.
     void setMTime(std::chrono::seconds mtime) { this->mtime = mtime; }
-
     /// \brief Retrieve the file modification time (in seconds since UNIX epoch).
     std::chrono::seconds getMTime() const { return mtime; }
 
+    /// \brief Set update time of the database entry.
+    void setUTime(std::chrono::seconds utime) { this->utime = utime; }
+    /// \brief Retrieve the database entry update time (in seconds since UNIX epoch).
+    std::chrono::seconds getUTime() const { return utime; }
+
     /// \brief Set file size.
     void setSizeOnDisk(off_t sizeOnDisk) { this->sizeOnDisk = sizeOnDisk; }
-
     /// \brief Retrieve the file size (in bytes).
     off_t getSizeOnDisk() const { return sizeOnDisk; }
 
     /// \brief Set the virtual flag.
     void setVirtual(bool virt) { this->virt = virt; }
-
     /// \brief Query the virtual flag.
     bool isVirtual() const { return virt; }
 
@@ -292,7 +292,7 @@ public:
     size_t getResourceCount() const { return resources.size(); }
 
     /// \brief Query resources
-    std::vector<std::shared_ptr<CdsResource>> getResources() const
+    const std::vector<std::shared_ptr<CdsResource>>& getResources() const
     {
         return resources;
     }
@@ -325,15 +325,10 @@ public:
     }
 
     /// \brief Add resource tag
-    void addResource(const std::shared_ptr<CdsResource>& resource)
+    void addResource(std::shared_ptr<CdsResource> resource)
     {
-        resources.push_back(resource);
-    }
-
-    /// \brief Insert resource tag at index
-    void insertResource(size_t index, const std::shared_ptr<CdsResource>& resource)
-    {
-        resources.insert(resources.begin() + index, resource);
+        resource->setResId(resources.size());
+        resources.push_back(move(resource));
     }
 
     /// \brief Copies all object properties to another object.
@@ -347,14 +342,14 @@ public:
     /// The difference between setting this flag to true or false is following:
     /// exactly=true checks all fields, also internal ones, exactly=false checks
     /// only the fields that will be visible in DIDL-Lite
-    virtual bool equals(const std::shared_ptr<CdsObject>& obj, bool exactly = false);
+    virtual bool equals(const std::shared_ptr<CdsObject>& obj, bool exactly = false) const;
 
     /// \brief Checks if current object has the same resources as obj
     /// \param obj object to check against
-    bool resourcesEqual(const std::shared_ptr<CdsObject>& obj);
+    bool resourcesEqual(const std::shared_ptr<CdsObject>& obj) const;
 
     /// \brief Checks if the minimum required parameters for the object have been set and are valid.
-    virtual void validate();
+    virtual void validate() const;
 
     static std::shared_ptr<CdsObject> createObject(unsigned int objectType);
 
@@ -365,22 +360,22 @@ public:
 class CdsItem : public CdsObject {
 protected:
     /// \brief mime-type of the media.
-    std::string mimeType;
+    std::string mimeType { MIMETYPE_DEFAULT };
 
     /// \brief number of part, e.g. disk or season
-    int partNumber;
+    int partNumber {};
 
     /// \brief number of track e.g. track on disk or episode of season
-    int trackNumber;
+    int trackNumber {};
 
     /// \brief unique service ID
     std::string serviceID;
 
-    std::chrono::milliseconds bookMarkPos;
+    std::chrono::milliseconds bookMarkPos {};
 
 public:
     /// \brief Constructor, sets the object type and default upnp:class (object.item)
-    explicit CdsItem();
+    CdsItem();
 
     /// \brief Set mime-type information of the media.
     void setMimeType(const std::string& mimeType) { this->mimeType = mimeType; }
@@ -408,10 +403,10 @@ public:
     /// \brief Checks if current object is equal to obj.
     ///
     /// See description for CdsObject::equals() for details.
-    bool equals(const std::shared_ptr<CdsObject>& obj, bool exactly = false) override;
+    bool equals(const std::shared_ptr<CdsObject>& obj, bool exactly = false) const override;
 
     /// \brief Checks if the minimum required parameters for the object have been set and are valid.
-    void validate() override;
+    void validate() const override;
 
     /// \brief Set the unique service ID.
     void setServiceID(const std::string& serviceID) { this->serviceID = serviceID; }
@@ -430,7 +425,7 @@ public:
 class CdsItemExternalURL : public CdsItem {
 public:
     /// \brief Constructor, sets the object type.
-    explicit CdsItemExternalURL();
+    CdsItemExternalURL();
     bool isPureItem() const override { return false; }
     bool isExternalItem() const override { return true; }
 
@@ -439,7 +434,7 @@ public:
     void setURL(const std::string& URL) { this->location = URL; }
 
     /// \brief Get the URL of the item.
-    std::string getURL() const { return location.string(); }
+    std::string getURL() const { return location; }
     /// \brief Copies all object properties to another object.
     /// \param obj target object (clone)
     //void copyTo(std::shared_ptr<CdsObject> obj) override;
@@ -450,24 +445,24 @@ public:
     //int equals(std::shared_ptr<CdsObject> obj, bool exactly=false) override;
 
     /// \brief Checks if the minimum required parameters for the object have been set and are valid.
-    void validate() override;
+    void validate() const override;
 };
 
 /// \brief A container in the content directory.
 class CdsContainer final : public CdsObject {
 protected:
     /// \brief container update id.
-    int updateID;
+    int updateID {};
 
     /// \brief childCount attribute
-    int childCount;
+    int childCount { -1 };
 
     /// \brief whether this container is an autoscan start point.
-    int autoscanType;
+    int autoscanType { OBJECT_AUTOSCAN_NONE };
 
 public:
     /// \brief Constructor, initializes default values for the flags and sets the object type.
-    explicit CdsContainer();
+    CdsContainer();
     bool isContainer() const override { return true; }
 
     /// \brief Set the searchable flag.
@@ -501,10 +496,10 @@ public:
     /// \brief Checks if current object is equal to obj.
     ///
     /// See description for CdsObject::equals() for details.
-    bool equals(const std::shared_ptr<CdsObject>& obj, bool exactly = false) override;
+    bool equals(const std::shared_ptr<CdsObject>& obj, bool exactly = false) const override;
 
     /// \brief Checks if the minimum required parameters for the object have been set and are valid.
-    void validate() override;
+    void validate() const override;
 };
 
 #endif // __CDS_OBJECTS_H__
