@@ -52,6 +52,7 @@
 class CdsResource {
 protected:
     int handlerType;
+    int resId { -1 };
     std::map<std::string, std::string> attributes;
     std::map<std::string, std::string> parameters;
     std::map<std::string, std::string> options;
@@ -68,6 +69,8 @@ public:
         std::map<std::string, std::string> parameters,
         std::map<std::string, std::string> options);
 
+    int getResId() const { return resId; }
+    void setResId(int rId) { resId = rId; }
     /// \brief Adds a resource attribute.
     ///
     /// This maps to an attribute of the <res> tag in the DIDL-Lite XML.
@@ -93,13 +96,13 @@ public:
     ///
     /// \param name parameter name
     /// \param value parameter value
-    void addParameter(const std::string& name, std::string value);
+    void addParameter(std::string name, std::string value);
 
     /// \brief Add an option to the resource.
     ///
     /// The options are internal, they do not appear in the URL or in the
     /// XML but can be used for any purpose.
-    void addOption(const std::string& name, std::string value);
+    void addOption(std::string name, std::string value);
 
     int getHandlerType() const;
     std::map<std::string, std::string> getAttributes() const;
@@ -108,9 +111,9 @@ public:
     std::string getAttribute(resource_attributes_t res) const;
     std::string getParameter(const std::string& name) const;
     std::string getOption(const std::string& name) const;
-    bool isMetaResource(const char* rct) const
+    bool isMetaResource(const char* rct, int ht = -1) const
     {
-        return ((handlerType == CH_ID3 || handlerType == CH_MP4 || handlerType == CH_FLAC || handlerType == CH_FANART || handlerType == CH_CONTAINERART) && getParameter(RESOURCE_CONTENT_TYPE) == rct) || (handlerType == CH_EXTURL && getOption(RESOURCE_CONTENT_TYPE) == rct);
+        return ((handlerType == CH_ID3 || handlerType == CH_MP4 || handlerType == CH_FLAC || handlerType == CH_FANART || handlerType == CH_CONTAINERART || handlerType == ht) && getParameter(RESOURCE_CONTENT_TYPE) == rct) || (handlerType == CH_EXTURL && getOption(RESOURCE_CONTENT_TYPE) == rct);
     }
 
     bool equals(const std::shared_ptr<CdsResource>& other) const;
@@ -119,6 +122,7 @@ public:
     /// \brief urlencode into string
     std::string encode();
     static std::shared_ptr<CdsResource> decode(const std::string& serial);
+    void decode(const std::string& options, const std::string& parameters);
 };
 
 #endif // __CDS_RESOURCE_H__
