@@ -25,33 +25,42 @@
 
 #include "client_config.h" // API
 
+#include <numeric>
+
 #include "content/content_manager.h"
 #include "util/upnp_clients.h"
 #include "util/upnp_quirks.h"
 
 ClientConfig::ClientConfig()
-    : clientInfo(std::make_shared<ClientInfo>())
 {
-    clientInfo->matchType = ClientMatchType::None;
-    clientInfo->type = ClientType::Unknown;
-    clientInfo->flags = 0;
+    auto cInfo = ClientInfo {
+        "Unknown",
+        ClientType::Unknown,
+        QUIRK_FLAG_NONE,
+        ClientMatchType::None,
+        "",
+    };
+    clientInfo = std::make_unique<ClientInfo>(std::move(cInfo));
 }
 
-ClientConfig::ClientConfig(int flags, const std::string& ip, const std::string& userAgent)
-    : clientInfo(std::make_shared<ClientInfo>())
+ClientConfig::ClientConfig(int flags, std::string_view ip, std::string_view userAgent)
 {
-    clientInfo->type = ClientType::Unknown;
+    auto cInfo = ClientInfo();
+    cInfo.type = ClientType::Unknown;
     if (!ip.empty()) {
-        clientInfo->matchType = ClientMatchType::IP;
-        clientInfo->match = ip;
+        cInfo.matchType = ClientMatchType::IP;
+        cInfo.match = ip;
     } else if (!userAgent.empty()) {
-        clientInfo->matchType = ClientMatchType::UserAgent;
-        clientInfo->match = userAgent;
+        cInfo.matchType = ClientMatchType::UserAgent;
+        cInfo.match = userAgent;
     } else {
-        clientInfo->matchType = ClientMatchType::None;
+        cInfo.matchType = ClientMatchType::None;
     }
-    clientInfo->flags = flags;
-    clientInfo->name = fmt::format("Manual Setup for{}{}", !ip.empty() ? " IP " + ip : "", !userAgent.empty() ? " UserAgent " + userAgent : "");
+    cInfo.flags = flags;
+    auto sIP = ip.empty() ? "" : fmt::format(" IP {}", ip);
+    auto sUA = userAgent.empty() ? "" : fmt::format(" UserAgent {}", userAgent);
+    cInfo.name = fmt::format("Manual Setup for{}{}", sIP, sUA);
+    clientInfo = std::make_unique<ClientInfo>(std::move(cInfo));
 }
 
 void ClientConfigList::add(const std::shared_ptr<ClientConfig>& client, size_t index)
@@ -208,6 +217,12 @@ int ClientConfig::remapFlag(const std::string& flag)
     return stoiString(flag, 0, 0);
 }
 
+int ClientConfig::makeFlags(const std::string& optValue)
+{
+    std::vector<std::string> flagsVector = splitString(optValue, '|', false);
+    return std::accumulate(flagsVector.begin(), flagsVector.end(), 0, [](auto flg, auto&& i) { return flg | ClientConfig::remapFlag(i); });
+}
+
 std::string ClientConfig::mapFlags(QuirkFlags flags)
 {
     if (!flags)
@@ -232,7 +247,7 @@ std::string ClientConfig::mapFlags(QuirkFlags flags)
         myFlags.push_back(fmt::format("{:#04x}", flags));
     }
 
-    return join(myFlags, '|');
+    return fmt::format("{}", fmt::join(myFlags, "|"));
 }
 
 void ClientConfig::copyTo(const std::shared_ptr<ClientConfig>& copy) const
