@@ -59,7 +59,7 @@ public:
     std::vector<std::shared_ptr<ClientConfig>> getArrayCopy();
 
 protected:
-    size_t origSize;
+    size_t origSize {};
     std::map<size_t, std::shared_ptr<ClientConfig>> indexMap;
 
     std::recursive_mutex mutex;
@@ -78,22 +78,22 @@ public:
     /// \param flags quirks flags
     /// \param ip ip address
     /// \param userAgent user agent
-    ClientConfig(int flags, const std::string& ip, const std::string& userAgent);
+    ClientConfig(int flags, std::string_view ip, std::string_view userAgent);
 
-    std::shared_ptr<ClientInfo> getClientInfo() { return clientInfo; }
+    const std::unique_ptr<ClientInfo>& getClientInfo() const { return clientInfo; }
 
     int getFlags() const { return clientInfo->flags; }
     void setFlags(int flags) { this->clientInfo->flags = flags; }
 
     std::string getIp() const { return (this->clientInfo->matchType == ClientMatchType::IP) ? this->clientInfo->match : ""; }
-    void setIp(const std::string& ip)
+    void setIp(std::string_view ip)
     {
         this->clientInfo->matchType = ClientMatchType::IP;
         this->clientInfo->match = ip;
     }
 
     std::string getUserAgent() const { return (this->clientInfo->matchType == ClientMatchType::UserAgent) ? this->clientInfo->match : ""; }
-    void setUserAgent(const std::string& userAgent)
+    void setUserAgent(std::string_view userAgent)
     {
         this->clientInfo->matchType = ClientMatchType::UserAgent;
         this->clientInfo->match = userAgent;
@@ -107,6 +107,8 @@ public:
     static std::string_view mapMatchType(ClientMatchType matchType);
     static ClientType remapClientType(const std::string& clientType);
     static int remapFlag(const std::string& flag);
+    static int makeFlags(const std::string& optValue);
+
     static std::string mapFlags(QuirkFlags flags);
 
     void setOrig(bool orig) { this->isOrig = orig; }
@@ -114,8 +116,8 @@ public:
     bool getOrig() const { return isOrig; }
 
 protected:
-    bool isOrig { false };
-    std::shared_ptr<ClientInfo> clientInfo;
+    bool isOrig {};
+    std::unique_ptr<ClientInfo> clientInfo;
 };
 
 #endif
