@@ -30,15 +30,17 @@
 #include <vector>
 namespace fs = std::filesystem;
 
-// forward declaration
-class AutoscanList;
+// forward declarations
 class AutoscanDirectory;
+class AutoscanList;
 class ClientConfigList;
 class ConfigOption;
 class Database;
 class DirectoryConfigList;
+class DynamicContentList;
 class TranscodingProfileList;
 
+#define CFG_MIN CFG_SERVER_PORT
 enum config_option_t {
     CFG_SERVER_PORT = 0,
     CFG_SERVER_IP,
@@ -83,6 +85,7 @@ enum config_option_t {
     CFG_SERVER_STORAGE_SQLITE_BACKUP_ENABLED,
     CFG_SERVER_STORAGE_SQLITE_BACKUP_INTERVAL,
     CFG_SERVER_STORAGE_SQLITE_INIT_SQL_FILE,
+    CFG_SERVER_STORAGE_SQLITE_UPGRADE_FILE,
     CFG_SERVER_STORAGE_MYSQL_ENABLED,
 #ifdef HAVE_MYSQL
     CFG_SERVER_STORAGE_MYSQL_HOST,
@@ -92,6 +95,7 @@ enum config_option_t {
     CFG_SERVER_STORAGE_MYSQL_PASSWORD,
     CFG_SERVER_STORAGE_MYSQL_DATABASE,
     CFG_SERVER_STORAGE_MYSQL_INIT_SQL_FILE,
+    CFG_SERVER_STORAGE_MYSQL_UPGRADE_FILE,
 #endif
 #if defined(HAVE_FFMPEG) && defined(HAVE_FFMPEGTHUMBNAILER)
     CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED,
@@ -152,6 +156,7 @@ enum config_option_t {
     CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST,
     CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST,
     CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST,
+    CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST,
 #ifdef HAVE_LIBEXIF
     CFG_IMPORT_LIBOPTS_EXIF_AUXDATA_TAGS_LIST,
     CFG_IMPORT_LIBOPTS_EXIF_CHARSET,
@@ -202,15 +207,33 @@ enum config_option_t {
     CFG_IMPORT_RESOURCES_CONTAINERART_LOCATION,
     CFG_IMPORT_RESOURCES_CONTAINERART_PARENTCOUNT,
     CFG_IMPORT_RESOURCES_CONTAINERART_MINDEPTH,
+    CFG_IMPORT_RESOURCES_FANART_DIR_LIST,
+    CFG_IMPORT_RESOURCES_SUBTITLE_DIR_LIST,
+    CFG_IMPORT_RESOURCES_RESOURCE_DIR_LIST,
+    CFG_IMPORT_RESOURCES_CONTAINERART_DIR_LIST,
     CFG_TRANSCODING_MIMETYPE_PROF_MAP_ALLOW_UNUSED,
     CFG_TRANSCODING_PROFILES_PROFILE_ALLOW_UNUSED,
     CFG_VIRTUAL_URL,
     CFG_IMPORT_SYSTEM_DIRECTORIES,
+    CFG_IMPORT_VISIBLE_DIRECTORIES,
     CFG_UPNP_ALBUM_PROPERTIES,
     CFG_UPNP_ARTIST_PROPERTIES,
+    CFG_UPNP_GENRE_PROPERTIES,
+    CFG_UPNP_PLAYLIST_PROPERTIES,
     CFG_UPNP_TITLE_PROPERTIES,
+    CFG_UPNP_ALBUM_NAMESPACES,
+    CFG_UPNP_ARTIST_NAMESPACES,
+    CFG_UPNP_GENRE_NAMESPACES,
+    CFG_UPNP_PLAYLIST_NAMESPACES,
+    CFG_UPNP_TITLE_NAMESPACES,
     CFG_THREAD_SCOPE_SYSTEM,
     CFG_IMPORT_READABLE_NAMES,
+#ifdef SOPCAST
+    CFG_IMPORT_SOPCAST_MIMETYE_LIST,
+#endif
+    CFG_SERVER_DYNAMIC_CONTENT_LIST_ENABLED,
+    CFG_SERVER_DYNAMIC_CONTENT_LIST,
+    CFG_IMPORT_RESOURCES_ORDER,
 
     CFG_MAX,
 
@@ -234,7 +257,9 @@ enum config_option_t {
     ATTR_IMPORT_LAYOUT_MAPPING_FROM,
     ATTR_IMPORT_LAYOUT_MAPPING_TO,
     ATTR_IMPORT_RESOURCES_ADD_FILE,
+    ATTR_IMPORT_RESOURCES_ADD_DIR,
     ATTR_IMPORT_RESOURCES_NAME,
+    ATTR_IMPORT_RESOURCES_EXT,
     ATTR_IMPORT_LIBOPTS_AUXDATA_DATA,
     ATTR_IMPORT_LIBOPTS_AUXDATA_TAG,
     ATTR_TRANSCODING_MIMETYPE_PROF_MAP,
@@ -245,6 +270,7 @@ enum config_option_t {
     ATTR_TRANSCODING_PROFILES_PROFLE_ENABLED,
     ATTR_TRANSCODING_PROFILES_PROFLE_TYPE,
     ATTR_TRANSCODING_PROFILES_PROFLE_NAME,
+    ATTR_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS,
     ATTR_TRANSCODING_PROFILES_PROFLE_MIMETYPE,
     ATTR_TRANSCODING_PROFILES_PROFLE_RES,
     ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC,
@@ -292,6 +318,17 @@ enum config_option_t {
     ATTR_UPNP_PROPERTIES_PROPERTY,
     ATTR_UPNP_PROPERTIES_UPNPTAG,
     ATTR_UPNP_PROPERTIES_METADATA,
+    ATTR_UPNP_NAMESPACE_PROPERTY,
+    ATTR_UPNP_NAMESPACE_KEY,
+    ATTR_UPNP_NAMESPACE_URI,
+    ATTR_IMPORT_RESOURCES_HANDLER,
+
+    ATTR_DYNAMIC_CONTAINER,
+    ATTR_DYNAMIC_CONTAINER_LOCATION,
+    ATTR_DYNAMIC_CONTAINER_IMAGE,
+    ATTR_DYNAMIC_CONTAINER_TITLE,
+    ATTR_DYNAMIC_CONTAINER_FILTER,
+    ATTR_DYNAMIC_CONTAINER_SORT,
 };
 
 class Config {
@@ -350,6 +387,10 @@ public:
     /// \brief returns a config option of type TranscodingProfileList
     /// \param option to retrieve
     virtual std::shared_ptr<TranscodingProfileList> getTranscodingProfileListOption(config_option_t option) const = 0;
+
+    /// \brief returns a config option of type DynamicContentList
+    /// \param option to retrieve
+    virtual std::shared_ptr<DynamicContentList> getDynamicContentListOption(config_option_t option) const = 0;
 };
 
 #endif // __CONFIG_H__
