@@ -148,6 +148,38 @@ static std::vector<std::string> excludes_fullpath {
     "/var",
 };
 
+/// \brief default values for CFG_IMPORT_RESOURCES_FANART_FILE_LIST
+static std::vector<std::string> defaultFanArtFile {
+    // "%title%.jpg",
+    // "%filename%.jpg",
+    // "folder.jpg",
+    // "poster.jpg",
+    // "cover.jpg",
+    // "albumartsmall.jpg",
+    // "%album%.jpg",
+};
+
+/// \brief default values for CFG_IMPORT_RESOURCES_CONTAINERART_FILE_LIST
+static std::vector<std::string> defaultContainerArtFile {
+    // "folder.jpg",
+    // "poster.jpg",
+    // "cover.jpg",
+    // "albumartsmall.jpg",
+};
+
+/// \brief default values for CFG_IMPORT_RESOURCES_SUBTITLE_FILE_LIST
+static std::vector<std::string> defaultSubtitleFile {
+    // "%title%.srt",
+    // "%filename%.srt"
+};
+
+/// \brief default values for CFG_IMPORT_RESOURCES_RESOURCE_FILE_LIST
+static std::vector<std::string> defaultResourceFile {
+    // "%filename%.srt",
+    // "cover.jpg",
+    // "%album%.jpg",
+};
+
 /// \brief default values for CFG_SERVER_UI_ITEMS_PER_PAGE_DROPDOWN
 static std::vector<std::string> defaultItemsPerPage {
     "10",
@@ -178,6 +210,16 @@ static std::map<std::string, std::string> mt_ct_defaults {
     { "audio/x-dsd", CONTENT_TYPE_DSD },
 };
 
+/// \brief default values for CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST
+static std::map<std::string, std::string> ct_dlna_defaults {
+    { CONTENT_TYPE_MP4, UPNP_DLNA_PROFILE_AVC_MP4_EU },
+    { CONTENT_TYPE_MKV, UPNP_DLNA_PROFILE_MKV },
+    { CONTENT_TYPE_AVI, UPNP_DLNA_PROFILE_AVI },
+    { CONTENT_TYPE_MPEG, UPNP_DLNA_PROFILE_MPEG_PS_PAL },
+    { CONTENT_TYPE_MP3, UPNP_DLNA_PROFILE_MP3 },
+    { CONTENT_TYPE_PCM, UPNP_DLNA_PROFILE_LPCM },
+};
+
 /// \brief default values for CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST
 static std::map<std::string, std::string> mt_upnp_defaults {
     { "audio/*", UPNP_CLASS_MUSIC_TRACK },
@@ -195,6 +237,8 @@ static std::map<std::string, std::string> ext_mt_defaults {
     { "flv", "video/x-flv" },
     { "m2ts", "video/mp2t" }, // LibMagic fails to identify MPEG2 Transport Streams
     { "m3u", "audio/x-mpegurl" },
+    { "m3u8", "audio/x-mpegurl" },
+    { "m4a", "audio/mp4" }, // LibMagic identifies this as audio/x-m4a, preventing TagLib from parsing it
     { "mka", "audio/x-matroska" },
     { "mkv", "video/x-matroska" },
     { "mp3", "audio/mpeg" },
@@ -217,6 +261,16 @@ static std::map<std::string, std::string> ext_mt_defaults {
     { "wvx", "video/x-ms-wvx" },
 };
 
+#ifdef SOPCAST
+/// \brief default values for CFG_IMPORT_SOPCAST_MIMETYE_LIST
+static std::map<std::string, std::string> sc_mt_defaults {
+    { "wmv", "video/sopcast-x-ms-wmv" },
+    { "mp3", "audio/sopcast-mpeg" },
+    { "wma", "audio/sopcast-x-ms-wma" },
+    { "*", "application/sopcast-stream" }, // default value
+};
+#endif
+
 /// \brief default values for ATTR_TRANSCODING_MIMETYPE_PROF_MAP
 static std::map<std::string, std::string> tr_mt_defaults {
     { "video/x-flv", "vlcmpeg" },
@@ -246,6 +300,16 @@ static std::map<std::string, std::string> upnp_artist_prop_defaults {
     { "upnp:genre", "M_GENRE" },
 };
 
+/// \brief default values for CFG_UPNP_GENRE_PROPERTIES
+static std::map<std::string, std::string> upnp_genre_prop_defaults {
+    { "upnp:genre", "M_GENRE" },
+};
+
+/// \brief default values for CFG_UPNP_PLAYLIST_PROPERTIES
+static std::map<std::string, std::string> upnp_playlist_prop_defaults {
+    { "dc:date", "M_UPNP_DATE" },
+};
+
 /// \brief configure all known options
 const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions = {
     std::make_shared<ConfigIntSetup>(CFG_SERVER_PORT,
@@ -348,6 +412,9 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigPathSetup>(CFG_SERVER_STORAGE_MYSQL_INIT_SQL_FILE,
         "/server/storage/mysql/init-sql-file", "config-server.html#storage",
         "", true), // This should really be "dataDir / mysql.sql"
+    std::make_shared<ConfigPathSetup>(CFG_SERVER_STORAGE_MYSQL_UPGRADE_FILE,
+        "/server/storage/mysql/upgrade-file", "config-server.html#storage",
+        "", true),
 #else
     std::make_shared<ConfigBoolSetup>(CFG_SERVER_STORAGE_MYSQL_ENABLED,
         "/server/storage/mysql/attribute::enabled", "config-server.html#storage",
@@ -385,6 +452,9 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigPathSetup>(CFG_SERVER_STORAGE_SQLITE_INIT_SQL_FILE,
         "/server/storage/sqlite3/init-sql-file", "config-server.html#storage",
         "", true), // This should really be "dataDir / sqlite3.sql"
+    std::make_shared<ConfigPathSetup>(CFG_SERVER_STORAGE_SQLITE_UPGRADE_FILE,
+        "/server/storage/sqlite3/upgrade-file", "config-server.html#storage",
+        "", true),
 
     std::make_shared<ConfigBoolSetup>(CFG_SERVER_UI_ENABLED,
         "/server/ui/attribute::enabled", "config-server.html#ui",
@@ -457,13 +527,17 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         "/import/mappings/extension-mimetype/attribute::case-sensitive", "config-import.html#extension-mimetype",
         DEFAULT_CASE_SENSITIVE_EXTENSION_MAPPINGS),
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST,
-        "/import/mappings/mimetype-upnpclass", "config-import.html#mime-type-upnpclass",
+        "/import/mappings/mimetype-upnpclass", "config-import.html#mimetype-upnpclass",
         ATTR_IMPORT_MAPPINGS_MIMETYPE_MAP, ATTR_IMPORT_MAPPINGS_MIMETYPE_FROM, ATTR_IMPORT_MAPPINGS_MIMETYPE_TO,
         false, false, true, std::move(mt_upnp_defaults)),
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST,
-        "/import/mappings/mimetype-contenttype", "config-import.html#mime-type-upnpclass",
+        "/import/mappings/mimetype-contenttype", "config-import.html#mimetype-contenttype",
         ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_TREAT, ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_MIMETYPE, ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_AS,
         false, false, true, std::move(mt_ct_defaults)),
+    std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST,
+        "/import/mappings/contenttype-dlnaprofile", "config-import.html#contenttype-dlnaprofile",
+        ATTR_IMPORT_MAPPINGS_MIMETYPE_MAP, ATTR_IMPORT_MAPPINGS_MIMETYPE_FROM, ATTR_IMPORT_MAPPINGS_MIMETYPE_TO,
+        false, false, true, std::move(ct_dlna_defaults)),
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_LAYOUT_MAPPING,
         "/import/layout", "config-import.html#layout",
         ATTR_IMPORT_LAYOUT_MAPPING_PATH, ATTR_IMPORT_LAYOUT_MAPPING_FROM, ATTR_IMPORT_LAYOUT_MAPPING_TO),
@@ -524,6 +598,7 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         "/import/scripting/virtual-layout/structured-layout/attribute::div-char", "config-import.html#scripting",
         ""),
 #endif // JS
+
     std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_SCRIPTING_IMPORT_GENRE_MAP,
         "/import/scripting/virtual-layout/genre-map", "config-import.html#layout",
         ATTR_IMPORT_LAYOUT_GENRE, ATTR_IMPORT_LAYOUT_MAPPING_FROM, ATTR_IMPORT_LAYOUT_MAPPING_TO),
@@ -558,11 +633,19 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         DEFAULT_RESOURCES_CASE_SENSITIVE),
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_RESOURCES_FANART_FILE_LIST,
         "/import/resources/fanart", "config-import.html#resources",
-        ATTR_IMPORT_RESOURCES_ADD_FILE, ATTR_IMPORT_RESOURCES_NAME),
+        ATTR_IMPORT_RESOURCES_ADD_FILE, ATTR_IMPORT_RESOURCES_NAME,
+        false, false, std::move(defaultFanArtFile)),
+    std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_RESOURCES_FANART_DIR_LIST,
+        "/import/resources/fanart", "config-import.html#resources",
+        ATTR_IMPORT_RESOURCES_ADD_DIR, ATTR_IMPORT_RESOURCES_NAME, ATTR_IMPORT_RESOURCES_EXT),
 
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_RESOURCES_CONTAINERART_FILE_LIST,
         "/import/resources/container", "config-import.html#container",
-        ATTR_IMPORT_RESOURCES_ADD_FILE, ATTR_IMPORT_RESOURCES_NAME),
+        ATTR_IMPORT_RESOURCES_ADD_FILE, ATTR_IMPORT_RESOURCES_NAME,
+        false, false, std::move(defaultContainerArtFile)),
+    std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_RESOURCES_CONTAINERART_DIR_LIST,
+        "/import/resources/container", "config-import.html#container",
+        ATTR_IMPORT_RESOURCES_ADD_DIR, ATTR_IMPORT_RESOURCES_NAME, ATTR_IMPORT_RESOURCES_EXT),
     std::make_shared<ConfigPathSetup>(CFG_IMPORT_RESOURCES_CONTAINERART_LOCATION,
         "/import/resources/container/attribute::location", "config-import.html#container",
         ""),
@@ -575,14 +658,30 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
 
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_RESOURCES_SUBTITLE_FILE_LIST,
         "/import/resources/subtitle", "config-import.html#resources",
-        ATTR_IMPORT_RESOURCES_ADD_FILE, ATTR_IMPORT_RESOURCES_NAME),
+        ATTR_IMPORT_RESOURCES_ADD_FILE, ATTR_IMPORT_RESOURCES_NAME,
+        false, false, std::move(defaultSubtitleFile)),
+    std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_RESOURCES_SUBTITLE_DIR_LIST,
+        "/import/resources/subtitle", "config-import.html#resources",
+        ATTR_IMPORT_RESOURCES_ADD_DIR, ATTR_IMPORT_RESOURCES_NAME, ATTR_IMPORT_RESOURCES_EXT),
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_RESOURCES_RESOURCE_FILE_LIST,
         "/import/resources/resource", "config-import.html#resources",
-        ATTR_IMPORT_RESOURCES_ADD_FILE, ATTR_IMPORT_RESOURCES_NAME),
+        ATTR_IMPORT_RESOURCES_ADD_FILE, ATTR_IMPORT_RESOURCES_NAME,
+        false, false, std::move(defaultResourceFile)),
+    std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_RESOURCES_RESOURCE_DIR_LIST,
+        "/import/resources/resource", "config-import.html#resources",
+        ATTR_IMPORT_RESOURCES_ADD_DIR, ATTR_IMPORT_RESOURCES_NAME, ATTR_IMPORT_RESOURCES_EXT),
+
+    std::make_shared<ConfigArraySetup>(CFG_IMPORT_RESOURCES_ORDER,
+        "/import/resources/order", "config-import.html#resources-order",
+        ATTR_IMPORT_RESOURCES_HANDLER, ATTR_IMPORT_RESOURCES_NAME),
+
     std::make_shared<ConfigArraySetup>(CFG_IMPORT_SYSTEM_DIRECTORIES,
         "/import/system-directories", "config-import.html#system-directories",
         ATTR_IMPORT_SYSTEM_DIR_ADD_PATH, ATTR_IMPORT_RESOURCES_NAME, true, true,
         std::move(excludes_fullpath)),
+    std::make_shared<ConfigArraySetup>(CFG_IMPORT_VISIBLE_DIRECTORIES,
+        "/import/visible-directories", "config-import.html#visible-directories",
+        ATTR_IMPORT_SYSTEM_DIR_ADD_PATH, ATTR_IMPORT_RESOURCES_NAME),
 
 #if defined(HAVE_FFMPEG) && defined(HAVE_FFMPEGTHUMBNAILER)
     std::make_shared<ConfigBoolSetup>(CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED,
@@ -650,6 +749,10 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigIntSetup>(CFG_ONLINE_CONTENT_SOPCAST_PURGE_AFTER,
         "/import/online-content/SopCast/attribute::purge-after", "config-online.html#sopcast",
         0),
+    std::make_shared<ConfigDictionarySetup>(CFG_IMPORT_SOPCAST_MIMETYE_LIST,
+        "/import/online-content/SopCast/mimetype-mappings", "config-online.html#sopcast",
+        ATTR_IMPORT_MAPPINGS_MIMETYPE_MAP, ATTR_IMPORT_MAPPINGS_MIMETYPE_FROM, ATTR_IMPORT_MAPPINGS_MIMETYPE_TO,
+        false, false, false, std::move(sc_mt_defaults)),
 #endif
 #ifdef ATRAILERS
     std::make_shared<ConfigBoolSetup>(CFG_ONLINE_CONTENT_ATRAILERS_ENABLED,
@@ -769,6 +872,9 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC_4CC,
         "fourcc", "config-transcode.html#profiles",
         ""),
+    std::make_shared<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS,
+        "attribute::client-flags", "config-transcode.html#profiles",
+        ""),
     std::make_shared<ConfigBoolSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_ENABLED,
         "attribute::enabled", "config-transcode.html#profiles"),
     std::make_shared<ConfigBoolSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_ACCURL,
@@ -886,6 +992,10 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         "attribute::name", "config-import.html#resources",
         ""),
 
+    std::make_shared<ConfigStringSetup>(ATTR_IMPORT_RESOURCES_EXT,
+        "attribute::ext", "config-import.html#resources",
+        ""),
+
     std::make_shared<ConfigStringSetup>(ATTR_IMPORT_LAYOUT_MAPPING_FROM,
         "attribute::from", "config-import.html#layout",
         ""),
@@ -911,6 +1021,14 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         "/server/upnp/artist-properties", "config-server.html#upnp",
         ATTR_UPNP_PROPERTIES_PROPERTY, ATTR_UPNP_PROPERTIES_UPNPTAG, ATTR_UPNP_PROPERTIES_METADATA,
         false, false, true, std::move(upnp_artist_prop_defaults)),
+    std::make_shared<ConfigDictionarySetup>(CFG_UPNP_GENRE_PROPERTIES,
+        "/server/upnp/genre-properties", "config-server.html#upnp",
+        ATTR_UPNP_PROPERTIES_PROPERTY, ATTR_UPNP_PROPERTIES_UPNPTAG, ATTR_UPNP_PROPERTIES_METADATA,
+        false, false, true, std::move(upnp_genre_prop_defaults)),
+    std::make_shared<ConfigDictionarySetup>(CFG_UPNP_PLAYLIST_PROPERTIES,
+        "/server/upnp/playlist-properties", "config-server.html#upnp",
+        ATTR_UPNP_PROPERTIES_PROPERTY, ATTR_UPNP_PROPERTIES_UPNPTAG, ATTR_UPNP_PROPERTIES_METADATA,
+        false, false, true, std::move(upnp_playlist_prop_defaults)),
     std::make_shared<ConfigDictionarySetup>(CFG_UPNP_TITLE_PROPERTIES,
         "/server/upnp/title-properties", "config-server.html#upnp",
         ATTR_UPNP_PROPERTIES_PROPERTY, ATTR_UPNP_PROPERTIES_UPNPTAG, ATTR_UPNP_PROPERTIES_METADATA,
@@ -920,6 +1038,52 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
     std::make_shared<ConfigStringSetup>(ATTR_UPNP_PROPERTIES_METADATA,
         "attribute::meta-data", "config-server.html#upnp"),
 
+    std::make_shared<ConfigDictionarySetup>(CFG_UPNP_ALBUM_NAMESPACES,
+        "/server/upnp/album-properties", "config-server.html#upnp",
+        ATTR_UPNP_NAMESPACE_PROPERTY, ATTR_UPNP_NAMESPACE_KEY, ATTR_UPNP_NAMESPACE_URI,
+        false, false, false),
+    std::make_shared<ConfigDictionarySetup>(CFG_UPNP_ARTIST_NAMESPACES,
+        "/server/upnp/artist-properties", "config-server.html#upnp",
+        ATTR_UPNP_NAMESPACE_PROPERTY, ATTR_UPNP_NAMESPACE_KEY, ATTR_UPNP_NAMESPACE_URI,
+        false, false, false),
+    std::make_shared<ConfigDictionarySetup>(CFG_UPNP_GENRE_NAMESPACES,
+        "/server/upnp/genre-properties", "config-server.html#upnp",
+        ATTR_UPNP_NAMESPACE_PROPERTY, ATTR_UPNP_NAMESPACE_KEY, ATTR_UPNP_NAMESPACE_URI,
+        false, false, false),
+    std::make_shared<ConfigDictionarySetup>(CFG_UPNP_PLAYLIST_NAMESPACES,
+        "/server/upnp/playlist-properties", "config-server.html#upnp",
+        ATTR_UPNP_NAMESPACE_PROPERTY, ATTR_UPNP_NAMESPACE_KEY, ATTR_UPNP_NAMESPACE_URI,
+        false, false, false),
+    std::make_shared<ConfigDictionarySetup>(CFG_UPNP_TITLE_NAMESPACES,
+        "/server/upnp/title-properties", "config-server.html#upnp",
+        ATTR_UPNP_NAMESPACE_PROPERTY, ATTR_UPNP_NAMESPACE_KEY, ATTR_UPNP_NAMESPACE_URI,
+        false, false, false),
+    std::make_shared<ConfigStringSetup>(ATTR_UPNP_NAMESPACE_KEY,
+        "attribute::xmlns", "config-server.html#upnp"),
+    std::make_shared<ConfigStringSetup>(ATTR_UPNP_NAMESPACE_URI,
+        "attribute::uri", "config-server.html#upnp"),
+
+    std::make_shared<ConfigDynamicContentSetup>(CFG_SERVER_DYNAMIC_CONTENT_LIST,
+        "/server/containers", "config-server.html#containers"),
+    std::make_shared<ConfigBoolSetup>(CFG_SERVER_DYNAMIC_CONTENT_LIST_ENABLED,
+        "/server/containers/attribute::enabled", "config-server.html#containers",
+        true, false),
+    std::make_shared<ConfigPathSetup>(ATTR_DYNAMIC_CONTAINER_LOCATION,
+        "attribute::location", "config-server.html#location",
+        "/Auto", true, false, true),
+    std::make_shared<ConfigPathSetup>(ATTR_DYNAMIC_CONTAINER_IMAGE,
+        "attribute::image", "config-server.html#image",
+        "", true, false),
+    std::make_shared<ConfigStringSetup>(ATTR_DYNAMIC_CONTAINER_TITLE,
+        "attribute::title", "config-server.html#title",
+        ""),
+    std::make_shared<ConfigStringSetup>(ATTR_DYNAMIC_CONTAINER_FILTER,
+        "filter", "config-server.html#filter",
+        true, "last_updated > \"@last31\""),
+    std::make_shared<ConfigStringSetup>(ATTR_DYNAMIC_CONTAINER_SORT,
+        "attribute::sort", "config-server.html#sort",
+        ""),
+
     // simpleOptions
 
     std::make_shared<ConfigSetup>(ATTR_SERVER_UI_ITEMS_PER_PAGE_DROPDOWN_OPTION,
@@ -932,6 +1096,8 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         "map", ""),
     std::make_shared<ConfigSetup>(ATTR_IMPORT_RESOURCES_ADD_FILE,
         "add-file", ""),
+    std::make_shared<ConfigSetup>(ATTR_IMPORT_RESOURCES_ADD_DIR,
+        "add-dir", ""),
     std::make_shared<ConfigSetup>(ATTR_IMPORT_LIBOPTS_AUXDATA_DATA,
         "add-data", ""),
     std::make_shared<ConfigSetup>(ATTR_TRANSCODING_MIMETYPE_PROF_MAP_TRANSCODE,
@@ -944,20 +1110,31 @@ const std::vector<std::shared_ptr<ConfigSetup>> ConfigDefinition::complexOptions
         "genre", ""),
     std::make_shared<ConfigSetup>(ATTR_IMPORT_SYSTEM_DIR_ADD_PATH,
         "add-path", ""),
+    std::make_shared<ConfigSetup>(ATTR_DYNAMIC_CONTAINER,
+        "container", ""),
+    std::make_shared<ConfigSetup>(ATTR_IMPORT_RESOURCES_HANDLER,
+        "handler", ""),
 
     std::make_shared<ConfigSetup>(ATTR_UPNP_PROPERTIES_PROPERTY,
         "upnp-property", ""),
+    std::make_shared<ConfigSetup>(ATTR_UPNP_NAMESPACE_PROPERTY,
+        "upnp-namespace", ""),
 };
 
 /// \brief define parent options for path search
-const std::map<config_option_t, std::vector<config_option_t>> ConfigDefinition::parentOptions = {
+const std::map<config_option_t, std::vector<config_option_t>> ConfigDefinition::parentOptions {
     { ATTR_TRANSCODING_PROFILES_PROFLE_ENABLED, { CFG_TRANSCODING_PROFILE_LIST } },
+    { ATTR_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS, { CFG_TRANSCODING_PROFILE_LIST } },
     { ATTR_TRANSCODING_PROFILES_PROFLE_ACCURL, { CFG_TRANSCODING_PROFILE_LIST } },
     { ATTR_TRANSCODING_PROFILES_PROFLE_TYPE, { CFG_TRANSCODING_PROFILE_LIST } },
 
-    { ATTR_UPNP_PROPERTIES_PROPERTY, { CFG_UPNP_ALBUM_PROPERTIES, CFG_UPNP_ARTIST_PROPERTIES, CFG_UPNP_TITLE_PROPERTIES } },
-    { ATTR_UPNP_PROPERTIES_UPNPTAG, { CFG_UPNP_ALBUM_PROPERTIES, CFG_UPNP_ARTIST_PROPERTIES, CFG_UPNP_TITLE_PROPERTIES } },
-    { ATTR_UPNP_PROPERTIES_METADATA, { CFG_UPNP_ALBUM_PROPERTIES, CFG_UPNP_ARTIST_PROPERTIES, CFG_UPNP_TITLE_PROPERTIES } },
+    { ATTR_UPNP_PROPERTIES_PROPERTY, { CFG_UPNP_ALBUM_PROPERTIES, CFG_UPNP_GENRE_PROPERTIES, CFG_UPNP_ARTIST_PROPERTIES, CFG_UPNP_TITLE_PROPERTIES, CFG_UPNP_PLAYLIST_PROPERTIES } },
+    { ATTR_UPNP_PROPERTIES_UPNPTAG, { CFG_UPNP_ALBUM_PROPERTIES, CFG_UPNP_GENRE_PROPERTIES, CFG_UPNP_ARTIST_PROPERTIES, CFG_UPNP_TITLE_PROPERTIES, CFG_UPNP_PLAYLIST_PROPERTIES } },
+    { ATTR_UPNP_PROPERTIES_METADATA, { CFG_UPNP_ALBUM_PROPERTIES, CFG_UPNP_GENRE_PROPERTIES, CFG_UPNP_ARTIST_PROPERTIES, CFG_UPNP_TITLE_PROPERTIES, CFG_UPNP_PLAYLIST_PROPERTIES } },
+
+    { ATTR_UPNP_NAMESPACE_PROPERTY, { CFG_UPNP_ALBUM_NAMESPACES, CFG_UPNP_GENRE_NAMESPACES, CFG_UPNP_ARTIST_NAMESPACES, CFG_UPNP_TITLE_NAMESPACES, CFG_UPNP_PLAYLIST_NAMESPACES } },
+    { ATTR_UPNP_NAMESPACE_KEY, { CFG_UPNP_ALBUM_NAMESPACES, CFG_UPNP_GENRE_NAMESPACES, CFG_UPNP_ARTIST_NAMESPACES, CFG_UPNP_TITLE_NAMESPACES, CFG_UPNP_PLAYLIST_NAMESPACES } },
+    { ATTR_UPNP_NAMESPACE_URI, { CFG_UPNP_ALBUM_NAMESPACES, CFG_UPNP_GENRE_NAMESPACES, CFG_UPNP_ARTIST_NAMESPACES, CFG_UPNP_TITLE_NAMESPACES, CFG_UPNP_PLAYLIST_NAMESPACES } },
 
     { ATTR_AUTOSCAN_DIRECTORY_LOCATION, { CFG_IMPORT_AUTOSCAN_TIMED_LIST,
 #ifdef HAVE_INOTIFY
@@ -996,15 +1173,33 @@ const std::map<config_option_t, std::vector<config_option_t>> ConfigDefinition::
     { ATTR_DIRECTORIES_TWEAK_CASE_SENSITIVE, { CFG_IMPORT_DIRECTORIES_LIST } },
     { ATTR_DIRECTORIES_TWEAK_FOLLOW_SYMLINKS, { CFG_IMPORT_DIRECTORIES_LIST } },
 
+    { ATTR_DYNAMIC_CONTAINER, { CFG_SERVER_DYNAMIC_CONTENT_LIST } },
+    { ATTR_DYNAMIC_CONTAINER_LOCATION, { CFG_SERVER_DYNAMIC_CONTENT_LIST } },
+    { ATTR_DYNAMIC_CONTAINER_IMAGE, { CFG_SERVER_DYNAMIC_CONTENT_LIST } },
+    { ATTR_DYNAMIC_CONTAINER_TITLE, { CFG_SERVER_DYNAMIC_CONTENT_LIST } },
+    { ATTR_DYNAMIC_CONTAINER_FILTER, { CFG_SERVER_DYNAMIC_CONTENT_LIST } },
+    { ATTR_DYNAMIC_CONTAINER_SORT, { CFG_SERVER_DYNAMIC_CONTENT_LIST } },
+
     { ATTR_TRANSCODING_MIMETYPE_PROF_MAP_MIMETYPE, {} },
 
-    { ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_MIMETYPE, { CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST } },
-    { ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_TREAT, { CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST } },
-    { ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_AS, { CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST } },
-    { ATTR_IMPORT_MAPPINGS_MIMETYPE_FROM, { CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST, CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST, CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST } },
-    { ATTR_IMPORT_MAPPINGS_MIMETYPE_TO, { CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST, CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST, CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST } },
+    { ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_MIMETYPE, { CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST, CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST } },
+    { ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_TREAT, { CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST, CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST } },
+    { ATTR_IMPORT_MAPPINGS_M2CTYPE_LIST_AS, { CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST, CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST } },
+    { ATTR_IMPORT_MAPPINGS_MIMETYPE_FROM, { CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST, CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST, CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST, CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST,
+#ifdef SOPCAST
+                                              CFG_IMPORT_SOPCAST_MIMETYE_LIST
+#endif
+                                          } },
+    { ATTR_IMPORT_MAPPINGS_MIMETYPE_TO, { CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST, CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST, CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST, CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST,
+#ifdef SOPCAST
+                                            CFG_IMPORT_SOPCAST_MIMETYE_LIST
+#endif
+                                        } },
 
-    { ATTR_IMPORT_RESOURCES_NAME, { CFG_IMPORT_RESOURCES_FANART_FILE_LIST, CFG_IMPORT_RESOURCES_CONTAINERART_FILE_LIST, CFG_IMPORT_RESOURCES_RESOURCE_FILE_LIST, CFG_IMPORT_RESOURCES_SUBTITLE_FILE_LIST, CFG_IMPORT_SYSTEM_DIRECTORIES } },
+    { ATTR_IMPORT_RESOURCES_NAME, { CFG_IMPORT_RESOURCES_FANART_FILE_LIST, CFG_IMPORT_RESOURCES_CONTAINERART_FILE_LIST, CFG_IMPORT_RESOURCES_RESOURCE_FILE_LIST, CFG_IMPORT_RESOURCES_SUBTITLE_FILE_LIST, //
+                                      CFG_IMPORT_RESOURCES_FANART_DIR_LIST, CFG_IMPORT_RESOURCES_CONTAINERART_DIR_LIST, CFG_IMPORT_RESOURCES_RESOURCE_DIR_LIST, CFG_IMPORT_RESOURCES_SUBTITLE_DIR_LIST, //
+                                      CFG_IMPORT_SYSTEM_DIRECTORIES, CFG_IMPORT_RESOURCES_ORDER } },
+    { ATTR_IMPORT_RESOURCES_EXT, { CFG_IMPORT_RESOURCES_FANART_DIR_LIST, CFG_IMPORT_RESOURCES_CONTAINERART_DIR_LIST, CFG_IMPORT_RESOURCES_RESOURCE_DIR_LIST, CFG_IMPORT_RESOURCES_SUBTITLE_DIR_LIST } },
 
     { ATTR_IMPORT_LAYOUT_MAPPING_FROM, { CFG_IMPORT_LAYOUT_MAPPING, CFG_IMPORT_SCRIPTING_IMPORT_GENRE_MAP } },
     { ATTR_IMPORT_LAYOUT_MAPPING_TO, { CFG_IMPORT_LAYOUT_MAPPING, CFG_IMPORT_SCRIPTING_IMPORT_GENRE_MAP } },
@@ -1014,6 +1209,44 @@ const std::map<config_option_t, std::vector<config_option_t>> ConfigDefinition::
 #endif
 };
 
+/// \brief define option dependencies for automatic loading
+const std::map<config_option_t, config_option_t> ConfigDefinition::dependencyMap = {
+    { CFG_SERVER_STORAGE_SQLITE_DATABASE_FILE, CFG_SERVER_STORAGE_SQLITE_ENABLED },
+    { CFG_SERVER_STORAGE_SQLITE_SYNCHRONOUS, CFG_SERVER_STORAGE_SQLITE_ENABLED },
+    { CFG_SERVER_STORAGE_SQLITE_RESTORE, CFG_SERVER_STORAGE_SQLITE_ENABLED },
+    { CFG_SERVER_STORAGE_SQLITE_BACKUP_ENABLED, CFG_SERVER_STORAGE_SQLITE_ENABLED },
+    { CFG_SERVER_STORAGE_SQLITE_BACKUP_INTERVAL, CFG_SERVER_STORAGE_SQLITE_ENABLED },
+    { CFG_SERVER_STORAGE_SQLITE_INIT_SQL_FILE, CFG_SERVER_STORAGE_SQLITE_ENABLED },
+    { CFG_SERVER_STORAGE_SQLITE_UPGRADE_FILE, CFG_SERVER_STORAGE_SQLITE_ENABLED },
+#ifdef HAVE_MYSQL
+    { CFG_SERVER_STORAGE_MYSQL_HOST, CFG_SERVER_STORAGE_MYSQL },
+    { CFG_SERVER_STORAGE_MYSQL_DATABASE, CFG_SERVER_STORAGE_MYSQL },
+    { CFG_SERVER_STORAGE_MYSQL_USERNAME, CFG_SERVER_STORAGE_MYSQL },
+    { CFG_SERVER_STORAGE_MYSQL_PORT, CFG_SERVER_STORAGE_MYSQL },
+    { CFG_SERVER_STORAGE_MYSQL_SOCKET, CFG_SERVER_STORAGE_MYSQL },
+    { CFG_SERVER_STORAGE_MYSQL_PASSWORD, CFG_SERVER_STORAGE_MYSQL },
+    { CFG_SERVER_STORAGE_MYSQL_INIT_SQL_FILE, CFG_SERVER_STORAGE_MYSQL },
+    { CFG_SERVER_STORAGE_MYSQL_UPGRADE_FILE, CFG_SERVER_STORAGE_MYSQL },
+#endif
+#ifdef HAVE_CURL
+    { CFG_EXTERNAL_TRANSCODING_CURL_BUFFER_SIZE, CFG_TRANSCODING_TRANSCODING_ENABLED },
+    { CFG_EXTERNAL_TRANSCODING_CURL_FILL_SIZE, CFG_TRANSCODING_TRANSCODING_ENABLED },
+#endif
+#if defined(HAVE_FFMPEG) && defined(HAVE_FFMPEGTHUMBNAILER)
+    { CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_THUMBSIZE, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED },
+    { CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_SEEK_PERCENTAGE, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED },
+    { CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_FILMSTRIP_OVERLAY, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED },
+    { CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_WORKAROUND_BUGS, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED },
+    { CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_QUALITY, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED },
+    { CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR_ENABLED, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED },
+    { CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR, CFG_SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED },
+#endif
+#if defined(HAVE_LASTFMLIB)
+    { CFG_SERVER_EXTOPTS_LASTFM_USERNAME, CFG_SERVER_EXTOPTS_LASTFM_ENABLED },
+    { CFG_SERVER_EXTOPTS_LASTFM_PASSWORD, CFG_SERVER_EXTOPTS_LASTFM_ENABLED },
+#endif
+};
+
 const char* ConfigDefinition::mapConfigOption(config_option_t option)
 {
     auto co = std::find_if(complexOptions.begin(), complexOptions.end(), [&](auto&& c) { return c->option == option; });
@@ -1023,6 +1256,11 @@ const char* ConfigDefinition::mapConfigOption(config_option_t option)
     return "";
 }
 
+bool ConfigDefinition::isDependent(config_option_t option)
+{
+    return (dependencyMap.find(option) != dependencyMap.end());
+}
+
 std::shared_ptr<ConfigSetup> ConfigDefinition::findConfigSetup(config_option_t option, bool save)
 {
     auto co = std::find_if(complexOptions.begin(), complexOptions.end(), [&](auto&& s) { return s->option == option; });
@@ -1034,7 +1272,7 @@ std::shared_ptr<ConfigSetup> ConfigDefinition::findConfigSetup(config_option_t o
     if (save)
         return nullptr;
 
-    throw_std_runtime_error("Error in config code: {} tag not found", option);
+    throw_std_runtime_error("Error in config code: {} tag not found. CFG_MAX={}", option, CFG_MAX);
 }
 
 std::shared_ptr<ConfigSetup> ConfigDefinition::findConfigSetupByPath(const std::string& key, bool save, const std::shared_ptr<ConfigSetup>& parent)
@@ -1045,7 +1283,7 @@ std::shared_ptr<ConfigSetup> ConfigDefinition::findConfigSetupByPath(const std::
         return *co;
     }
 
-    if (parent != nullptr) {
+    if (parent) {
         auto attrKey = key.substr(parent->getUniquePath().length());
         if (attrKey.find_first_of(']') != std::string::npos) {
             attrKey = attrKey.substr(attrKey.find_first_of(']') + 1);
