@@ -25,6 +25,7 @@
 
 #include "config_generator.h"
 
+#include <sstream>
 #include <string>
 
 #include "config/config_definition.h"
@@ -40,16 +41,16 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::init()
     return generated[""];
 }
 
-std::shared_ptr<pugi::xml_node> ConfigGenerator::getNode(const std::string& tag)
+std::shared_ptr<pugi::xml_node> ConfigGenerator::getNode(const std::string& tag) const
 {
     log_debug("reading '{}' -> {}", tag, generated.find(tag) == generated.end());
-    return generated[tag];
+    return generated.at(tag);
 }
 
 std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(const std::string& tag, const std::string& value, bool makeLastChild)
 {
     auto split = splitString(tag, '/');
-    std::shared_ptr<pugi::xml_node> result = nullptr;
+    std::shared_ptr<pugi::xml_node> result;
     if (!split.empty()) {
         std::string parent;
         std::string nodeKey;
@@ -96,7 +97,7 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(config_option_t option
     return setValue(cs->xpath, value.empty() ? cs->getDefaultValue() : value);
 }
 
-std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(std::shared_ptr<pugi::xml_node>& parent, config_option_t option, const std::string& value)
+std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(const std::shared_ptr<pugi::xml_node>& parent, config_option_t option, const std::string& value)
 {
     auto cs = std::string(ConfigDefinition::mapConfigOption(option));
     if (cs.substr(0, ConfigDefinition::ATTRIBUTE.size()) == ConfigDefinition::ATTRIBUTE) {
@@ -117,7 +118,7 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(config_option_t option
 std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(config_option_t option, const std::string& key, const std::string& value)
 {
     auto cs = std::dynamic_pointer_cast<ConfigDictionarySetup>(ConfigDefinition::findConfigSetup(option));
-    if (cs == nullptr)
+    if (!cs)
         return nullptr;
 
     auto nodeKey = ConfigDefinition::mapConfigOption(cs->nodeOption);
@@ -130,7 +131,7 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(config_option_t option
 std::shared_ptr<pugi::xml_node> ConfigGenerator::setDictionary(config_option_t option)
 {
     auto cs = std::dynamic_pointer_cast<ConfigDictionarySetup>(ConfigDefinition::findConfigSetup(option));
-    if (cs == nullptr)
+    if (!cs)
         return nullptr;
 
     auto nodeKey = ConfigDefinition::mapConfigOption(cs->nodeOption);
@@ -162,10 +163,10 @@ std::string ConfigGenerator::generate(const fs::path& userHome, const fs::path&
     config->append_attribute("xsi:schemaLocation") = fmt::format("{}{} {}{}.xsd", XML_XMLNS, CONFIG_XML_VERSION, XML_XMLNS, CONFIG_XML_VERSION).c_str();
 
     auto docinfo = config->append_child(pugi::node_comment);
-    docinfo.set_value("\n\
-     See http://gerbera.io or read the docs for more\n\
-     information on creating and using config.xml configuration files.\n\
-    ");
+    docinfo.set_value(R"(
+     See http://gerbera.io or read the docs for more
+     information on creating and using config.xml configuration files.
+    )");
 
     generateServer(userHome, configDir, dataDir);
     generateImport(dataDir, magicFile);
@@ -185,25 +186,27 @@ void ConfigGenerator::generateServer(const fs::path& userHome, const fs::path& c
     generateUdn();
 
     fs::path homepath = userHome / configDir;
-    setValue(CFG_SERVER_HOME, homepath.string());
+    setValue(CFG_SERVER_HOME, homepath);
 
     fs::path webRoot = dataDir / DEFAULT_WEB_DIR;
-    setValue(CFG_SERVER_WEBROOT, webRoot.string());
+    setValue(CFG_SERVER_WEBROOT, webRoot);
 
     auto aliveinfo = server->append_child(pugi::node_comment);
-    aliveinfo.set_value(fmt::format("\n\
-        How frequently (in seconds) to send ssdp:alive advertisements.\n\
-        Minimum alive value accepted is: {}\n\n\
-        The advertisement will be sent every (A/2)-30 seconds,\n\
-        and will have a cache-control max-age of A where A is\n\
-        the value configured here. Ex: A value of 62 will result\n\
-        in an SSDP advertisement being sent every second.\n\
-    ",
+    aliveinfo.set_value(fmt::format(R"(
+        How frequently (in seconds) to send ssdp:alive advertisements.
+        Minimum alive value accepted is: {}
+
+        The advertisement will be sent every (A/2)-30 seconds,
+        and will have a cache-control max-age of A where A is
+        the value configured here. Ex: A value of 62 will result
+        in an SSDP advertisement being sent every second.
+    )",
         ALIVE_INTERVAL_MIN)
                             .c_str());
     setValue(CFG_SERVER_ALIVE_INTERVAL);
 
     generateDatabase();
+    generateDynamics();
     generateExtendedRuntime();
 }
 
@@ -217,6 +220,27 @@ void ConfigGenerator::generateUi()
     setValue(CFG_SERVER_UI_ACCOUNT_LIST, ATTR_SERVER_UI_ACCOUNT_LIST_ACCOUNT, ATTR_SERVER_UI_ACCOUNT_LIST_PASSWORD, DEFAULT_ACCOUNT_PASSWORD);
 }
 
+void ConfigGenerator::generateDynamics()
+{
+    setValue(CFG_SERVER_DYNAMIC_CONTENT_LIST_ENABLED);
+    setDictionary(CFG_SERVER_DYNAMIC_CONTENT_LIST);
+
+    auto&& containersTag = ConfigDefinition::mapConfigOption(CFG_SERVER_DYNAMIC_CONTENT_LIST);
+    auto&& containerTag = ConfigDefinition::mapConfigOption(ATTR_DYNAMIC_CONTAINER);
+
+    auto container = setValue(fmt::format("{}/{}/", containersTag, containerTag), "", true);
+    setValue(container, ATTR_DYNAMIC_CONTAINER_LOCATION, "/LastAdded");
+    setValue(container, ATTR_DYNAMIC_CONTAINER_TITLE, "Recently Added");
+    setValue(container, ATTR_DYNAMIC_CONTAINER_SORT, "-last_updated");
+    setValue(container, ATTR_DYNAMIC_CONTAINER_FILTER, R"(upnp:class derivedfrom "object.item" and last_updated > "@last7")");
+
+    container = setValue(fmt::format("{}/{}/", containersTag, containerTag), "", true);
+    setValue(container, ATTR_DYNAMIC_CONTAINER_LOCATION, "/LastModified");
+    setValue(container, ATTR_DYNAMIC_CONTAINER_TITLE, "Recently Modified");
+    setValue(container, ATTR_DYNAMIC_CONTAINER_SORT, "-last_modified");
+    setValue(container, ATTR_DYNAMIC_CONTAINER_FILTER, R"(upnp:class derivedfrom "object.item" and last_modified > "@last7")");
+}
+
 void ConfigGenerator::generateDatabase()
 {
     setValue(CFG_SERVER_STORAGE_SQLITE_ENABLED);
@@ -259,7 +283,7 @@ void ConfigGenerator::generateImport(const fs::path& prefixDir, const fs::path&
 
 #ifdef HAVE_MAGIC
     if (!magicFile.empty()) {
-        setValue(CFG_IMPORT_MAGIC_FILE, magicFile.string());
+        setValue(CFG_IMPORT_MAGIC_FILE, magicFile);
     }
 #endif
 
@@ -300,6 +324,7 @@ void ConfigGenerator::generateMappings()
 
     setDictionary(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_UPNP_CLASS_LIST);
     setDictionary(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST);
+    setDictionary(CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST);
 }
 
 void ConfigGenerator::generateOnlineContent()
