@@ -44,17 +44,18 @@ namespace fs = std::filesystem;
 #include "config.h"
 
 // forward declaration
-class AutoscanList;
 class AutoscanDirectory;
-class ClientConfigList;
+class AutoscanList;
 class ClientConfig;
-class ConfigSetup;
-class DirectoryConfigList;
-enum class ScanMode;
-enum class ClientType;
+class ClientConfigList;
 class ConfigOption;
+class ConfigSetup;
 class Database;
+class DirectoryConfigList;
+class DynamicContentList;
 class TranscodingProfileList;
+enum class ClientType;
+enum class ScanMode;
 
 class ConfigManager : public Config, public std::enable_shared_from_this<Config> {
 public:
@@ -111,6 +112,10 @@ public:
     /// \param option to retrieve
     std::shared_ptr<DirectoryConfigList> getDirectoryTweakOption(config_option_t option) const override;
 
+    /// \brief returns a config option of type DynamicContentList
+    /// \param option to retrieve
+    std::shared_ptr<DynamicContentList> getDynamicContentListOption(config_option_t option) const override;
+
     /// \brief returns a config option of type TranscodingProfileList
     /// \param option to retrieve
     std::shared_ptr<TranscodingProfileList> getTranscodingProfileListOption(config_option_t option) const override;
@@ -144,7 +149,7 @@ protected:
 
     std::unique_ptr<pugi::xml_document> xmlDoc;
 
-    std::unique_ptr<std::vector<std::shared_ptr<ConfigOption>>> options;
+    std::vector<std::shared_ptr<ConfigOption>> options { CFG_MAX };
 
     std::shared_ptr<ConfigOption> setOption(const pugi::xml_node& root, config_option_t option, const std::map<std::string, std::string>* arguments = nullptr);
 
