@@ -174,7 +174,7 @@ bool ConfigPathSetup::checkPathValue(std::string& optValue, std::string& pathVal
     if (rawCheck && !rawCheck(optValue)) {
         return false;
     }
-    pathValue.assign(resolvePath(optValue).string());
+    pathValue.assign(resolvePath(optValue));
     return !(notEmpty && pathValue.empty());
 }
 
@@ -211,7 +211,7 @@ bool ConfigPathSetup::checkAgentPath(std::string& optValue)
 /// \param mustExist file/directory must exist
 fs::path ConfigPathSetup::resolvePath(fs::path path) const
 {
-    if (!resolveEmpty && path.string().empty()) {
+    if (!resolveEmpty && path.empty()) {
         return path;
     }
     if (path.is_absolute() || (Home.is_relative() && path.is_relative()))
@@ -538,7 +538,7 @@ bool ConfigArraySetup::createOptionFromNode(const pugi::xml_node& element, std::
                 throw_std_runtime_error("Invalid array {} value {} empty '{}'", element.path(), xpath, attrValue);
             }
             if (!attrValue.empty())
-                result.push_back(attrValue);
+                result.push_back(std::move(attrValue));
         }
     }
     return true;
@@ -625,7 +625,7 @@ std::vector<std::string> ConfigArraySetup::getXmlContent(const pugi::xml_node& o
     if (result.empty()) {
         log_debug("{} assigning {} default values", xpath, defaultEntries.size());
         useDefault = true;
-        result.assign(defaultEntries.begin(), defaultEntries.end());
+        result = defaultEntries;
     }
     if (notEmpty && result.empty()) {
         throw_std_runtime_error("Invalid array {} empty '{}'", xpath, optValue);
@@ -641,7 +641,7 @@ bool ConfigArraySetup::checkArrayValue(const std::string& value, std::vector<std
             return false;
         }
         if (!attrValue.empty())
-            result.push_back(attrValue);
+            result.push_back(std::move(attrValue));
     }
     return true;
 }
@@ -670,7 +670,7 @@ bool ConfigArraySetup::InitPlayedItemsMark(const pugi::xml_node& value, std::vec
                 return false;
             }
 
-            result.push_back(mark_content);
+            result.push_back(std::move(mark_content));
         }
     }
     return true;
@@ -687,7 +687,9 @@ bool ConfigArraySetup::InitItemsPerPage(const pugi::xml_node& value, std::vector
                 log_error("Error in config file: incorrect <{}> value for <{}>", node_name, value.name());
                 return false;
             }
-            result.emplace_back(child.text().as_string());
+
+            auto str = std::string(child.text().as_string());
+            result.push_back(std::move(str));
         }
     }
     return true;
@@ -811,9 +813,13 @@ std::string ConfigDictionarySetup::getItemPath(int index, config_option_t propOp
 {
     auto opt = ConfigDefinition::ensureAttribute(propOption);
 
-    return index >= 0 //
-        ? fmt::format("{}/{}[{}]/{}", xpath, ConfigDefinition::mapConfigOption(nodeOption), index, opt) //
-        : fmt::format("{}/{}", xpath, ConfigDefinition::mapConfigOption(nodeOption));
+    if (index > ITEM_PATH_ROOT)
+        return fmt::format("{}/{}[{}]/{}", xpath, ConfigDefinition::mapConfigOption(nodeOption), index, opt);
+    if (index == ITEM_PATH_ROOT)
+        return fmt::format("{}/{}", xpath, ConfigDefinition::mapConfigOption(nodeOption));
+    if (index == ITEM_PATH_NEW)
+        return fmt::format("{}/{}[_]/{}", xpath, ConfigDefinition::mapConfigOption(nodeOption), opt);
+    return fmt::format("{}", xpath);
 }
 
 std::map<std::string, std::string> ConfigDictionarySetup::getXmlContent(const pugi::xml_node& optValue)
@@ -831,9 +837,7 @@ std::map<std::string, std::string> ConfigDictionarySetup::getXmlContent(const pu
     if (result.empty()) {
         log_debug("{} assigning {} default values", xpath, defaultEntries.size());
         useDefault = true;
-        for (auto&& entry : defaultEntries) {
-            result.insert(entry); // this should be an insert without a loop, but Debian 10 doesn't compile.
-        }
+        result = defaultEntries;
     }
     if (notEmpty && result.empty()) {
         throw_std_runtime_error("Invalid dictionary {} empty '{}'", xpath, optValue);
@@ -849,10 +853,14 @@ std::shared_ptr<ConfigOption> ConfigDictionarySetup::newOption(const std::map<st
 
 std::string ConfigAutoscanSetup::getItemPath(int index, config_option_t propOption, config_option_t propOption2, config_option_t propOption3, config_option_t propOption4) const
 {
-    return index >= 0 //
-        ? fmt::format("{}/{}/{}[{}]/{}", xpath, AutoscanDirectory::mapScanmode(scanMode), ConfigDefinition::mapConfigOption(ATTR_AUTOSCAN_DIRECTORY), index, ConfigDefinition::ensureAttribute(propOption)) //
-        : index > -2 ? fmt::format("{}/{}/{}", xpath, AutoscanDirectory::mapScanmode(scanMode), ConfigDefinition::mapConfigOption(ATTR_AUTOSCAN_DIRECTORY)) //
-                     : fmt::format("{}/{}", xpath, ConfigDefinition::mapConfigOption(ATTR_AUTOSCAN_DIRECTORY));
+    if (index > ITEM_PATH_ROOT)
+        return fmt::format("{}/{}/{}[{}]/{}", xpath, AutoscanDirectory::mapScanmode(scanMode), ConfigDefinition::mapConfigOption(ATTR_AUTOSCAN_DIRECTORY), index, ConfigDefinition::ensureAttribute(propOption));
+    if (index == ITEM_PATH_ROOT)
+        return fmt::format("{}/{}/{}", xpath, AutoscanDirectory::mapScanmode(scanMode), ConfigDefinition::mapConfigOption(ATTR_AUTOSCAN_DIRECTORY));
+    if (index == ITEM_PATH_NEW)
+        return fmt::format("{}/{}/{}[_]/{}", xpath, AutoscanDirectory::mapScanmode(scanMode), ConfigDefinition::mapConfigOption(ATTR_AUTOSCAN_DIRECTORY), ConfigDefinition::ensureAttribute(propOption));
+
+    return fmt::format("{}/{}", xpath, ConfigDefinition::mapConfigOption(ATTR_AUTOSCAN_DIRECTORY));
 }
 
 /// \brief Creates an array of AutoscanDirectory objects from a XML nodeset.
@@ -902,7 +910,7 @@ bool ConfigAutoscanSetup::createOptionFromNode(const pugi::xml_node& element, st
     return true;
 }
 
-bool ConfigAutoscanSetup::updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, std::shared_ptr<AutoscanDirectory>& entry, std::string& optValue, const std::string& status) const
+bool ConfigAutoscanSetup::updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, const std::shared_ptr<AutoscanDirectory>& entry, std::string& optValue, const std::string& status) const
 {
     auto index = getItemPath(i, ATTR_AUTOSCAN_DIRECTORY_LOCATION);
     if (optItem == getUniquePath() && status != STATUS_CHANGED) {
@@ -911,7 +919,7 @@ bool ConfigAutoscanSetup::updateItem(size_t i, const std::string& optItem, const
 
     if (optItem == index) {
         if (entry->getOrig())
-            config->setOrigValue(index, entry->getLocation().string());
+            config->setOrigValue(index, entry->getLocation());
         auto pathValue = optValue;
         if (ConfigDefinition::findConfigSetup<ConfigPathSetup>(ATTR_AUTOSCAN_DIRECTORY_LOCATION)->checkPathValue(optValue, pathValue)) {
             entry->setLocation(pathValue);
@@ -1377,7 +1385,7 @@ bool ConfigTranscodingSetup::updateDetail(const std::string& optItem, std::strin
             index = getItemPath(i, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_AGENT, ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_COMMAND);
             if (optItem == index) {
                 if (ConfigDefinition::findConfigSetup<ConfigStringSetup>(ATTR_TRANSCODING_PROFILES_PROFLE_AGENT_COMMAND)->checkValue(optValue)) {
-                    config->setOrigValue(index, entry->getCommand().string());
+                    config->setOrigValue(index, entry->getCommand());
                     entry->setCommand(optValue);
                     log_debug("New Transcoding Detail {} {}", index, config->getTranscodingProfileListOption(option)->getByName(entry->getName(), true)->getCommand().string());
                     return true;
@@ -1556,8 +1564,14 @@ std::shared_ptr<ConfigOption> ConfigClientSetup::newOption(const pugi::xml_node&
 
 std::string ConfigClientSetup::getItemPath(int index, config_option_t propOption, config_option_t propOption2, config_option_t propOption3, config_option_t propOption4) const
 {
-    if (index < 0) {
-        return fmt::to_string(ConfigDefinition::mapConfigOption(ATTR_CLIENTS_CLIENT));
+    if (index == ITEM_PATH_ROOT) {
+        return ConfigDefinition::mapConfigOption(ATTR_CLIENTS_CLIENT);
+    }
+    if (index == ITEM_PATH_NEW) {
+        if (propOption != CFG_MAX) {
+            return fmt::format("{}[_]/{}", ConfigDefinition::mapConfigOption(ATTR_CLIENTS_CLIENT), ConfigDefinition::ensureAttribute(propOption));
+        }
+        return fmt::format("{}[_]", ConfigDefinition::mapConfigOption(ATTR_CLIENTS_CLIENT));
     }
     if (propOption != CFG_MAX) {
         return fmt::format("{}[{}]/{}", ConfigDefinition::mapConfigOption(ATTR_CLIENTS_CLIENT), index, ConfigDefinition::ensureAttribute(propOption));
@@ -1642,7 +1656,7 @@ bool ConfigDirectorySetup::updateItem(size_t i, const std::string& optItem, cons
     auto index = getItemPath(i, ATTR_DIRECTORIES_TWEAK_LOCATION);
     if (optItem == index) {
         if (entry->getOrig())
-            config->setOrigValue(index, entry->getLocation().string());
+            config->setOrigValue(index, entry->getLocation());
         auto pathValue = optValue;
         if (ConfigDefinition::findConfigSetup<ConfigPathSetup>(ATTR_DIRECTORIES_TWEAK_LOCATION)->checkPathValue(optValue, pathValue)) {
             entry->setLocation(pathValue);
@@ -1785,7 +1799,7 @@ std::shared_ptr<ConfigOption> ConfigDirectorySetup::newOption(const pugi::xml_no
 std::string ConfigDirectorySetup::getItemPath(int index, config_option_t propOption, config_option_t propOption2, config_option_t propOption3, config_option_t propOption4) const
 {
     if (index < 0) {
-        return fmt::to_string(ConfigDefinition::mapConfigOption(ATTR_DIRECTORIES_TWEAK));
+        return ConfigDefinition::mapConfigOption(ATTR_DIRECTORIES_TWEAK);
     }
     if (propOption != CFG_MAX) {
         return fmt::format("{}[{}]/{}", ConfigDefinition::mapConfigOption(ATTR_DIRECTORIES_TWEAK), index, ConfigDefinition::ensureAttribute(propOption));
@@ -1815,7 +1829,7 @@ bool ConfigDynamicContentSetup::createOptionFromNode(const pugi::xml_node& eleme
             auto cs = ConfigDefinition::findConfigSetup<ConfigStringSetup>(ATTR_DYNAMIC_CONTAINER_TITLE);
             cont->setTitle(cs->getXmlContent(child));
             if (cont->getTitle().empty()) {
-                cont->setTitle(location.filename().string());
+                cont->setTitle(location.filename());
             }
             cs = ConfigDefinition::findConfigSetup<ConfigStringSetup>(ATTR_DYNAMIC_CONTAINER_SORT);
             cont->setSort(cs->getXmlContent(child));
@@ -1847,7 +1861,7 @@ bool ConfigDynamicContentSetup::updateItem(size_t i, const std::string& optItem,
     auto index = getItemPath(i, ATTR_DYNAMIC_CONTAINER_LOCATION);
     if (optItem == index) {
         if (entry->getOrig())
-            config->setOrigValue(index, entry->getLocation().string());
+            config->setOrigValue(index, entry->getLocation());
         auto pathValue = optValue;
         if (ConfigDefinition::findConfigSetup<ConfigPathSetup>(ATTR_DYNAMIC_CONTAINER_LOCATION)->checkPathValue(optValue, pathValue)) {
             entry->setLocation(pathValue);
@@ -1949,9 +1963,15 @@ std::shared_ptr<ConfigOption> ConfigDynamicContentSetup::newOption(const pugi::x
 
 std::string ConfigDynamicContentSetup::getItemPath(int index, config_option_t propOption, config_option_t propOption2, config_option_t propOption3, config_option_t propOption4) const
 {
-    if (index < 0) {
+    if (index == ITEM_PATH_ROOT) {
         return fmt::format("{}/{}", xpath, ConfigDefinition::mapConfigOption(ATTR_DYNAMIC_CONTAINER));
     }
+    if (index == ITEM_PATH_NEW) {
+        if (propOption != CFG_MAX) {
+            return fmt::format("{}/{}[_]/{}", xpath, ConfigDefinition::mapConfigOption(ATTR_DYNAMIC_CONTAINER), ConfigDefinition::ensureAttribute(propOption));
+        }
+        return fmt::format("{}/{}[_]", xpath, ConfigDefinition::mapConfigOption(ATTR_DYNAMIC_CONTAINER));
+    }
     if (propOption != CFG_MAX) {
         return fmt::format("{}/{}[{}]/{}", xpath, ConfigDefinition::mapConfigOption(ATTR_DYNAMIC_CONTAINER), index, ConfigDefinition::ensureAttribute(propOption));
     }
