@@ -40,14 +40,21 @@
 
 class ConfigOption;
 class DirectoryTweak;
+class DynamicContent;
 enum class ScanMode;
 
+#define ITEM_PATH_ROOT -1
+#define ITEM_PATH_NEW -2
+#define ITEM_PATH_PREFIX -3
+
 using StringCheckFunction = bool (*)(std::string& value);
 using ArrayInitFunction = bool (*)(const pugi::xml_node& value, std::vector<std::string>& result, const char* node_name);
 using DictionaryInitFunction = bool (*)(const pugi::xml_node& value, std::map<std::string, std::string>& result);
 using IntCheckFunction = bool (*)(int value);
 using IntMinFunction = bool (*)(int value, int minValue);
 
+using ConfigOptionIterator = EnumIterator<config_option_t, config_option_t::CFG_MIN, config_option_t::CFG_MAX>;
+
 class ConfigValue {
 public:
     std::string key;
@@ -92,6 +99,8 @@ protected:
     }
 
 public:
+    virtual ~ConfigSetup() = default;
+
     static constexpr auto ROOT_NAME = std::string_view("config");
 
     pugi::xpath_node_set getXmlTree(const pugi::xml_node& element) const;
@@ -121,8 +130,6 @@ public:
     {
     }
 
-    virtual ~ConfigSetup() = default;
-
     void setDefaultValue(const std::string& defaultValue)
     {
         this->defaultValue.assign(defaultValue);
@@ -138,7 +145,7 @@ public:
 
     bool checkValue(std::string& optValue) const
     {
-        return (rawCheck != nullptr && !rawCheck(optValue)) ? false : true;
+        return !(rawCheck && !rawCheck(optValue));
     }
     const char* getHelp() const { return help; }
     std::shared_ptr<ConfigOption> getValue() const { return optionValue; }
@@ -166,7 +173,7 @@ public:
     virtual std::string getItemPath(int index = 0, config_option_t propOption = CFG_MAX, config_option_t propOption2 = CFG_MAX, config_option_t propOption3 = CFG_MAX, config_option_t propOption4 = CFG_MAX) const { return xpath; }
 
     virtual std::string getUniquePath() const { return xpath; }
-    virtual std::string getCurrentValue() const { return optionValue == nullptr ? "" : optionValue->getOption(); }
+    virtual std::string getCurrentValue() const { return optionValue ? optionValue->getOption() : ""; }
 };
 
 class ConfigStringSetup : public ConfigSetup {
@@ -218,7 +225,7 @@ public:
 
     void makeOption(const pugi::xml_node& root, const std::shared_ptr<Config>& config, const std::map<std::string, std::string>* arguments = nullptr) override
     {
-        if (arguments != nullptr && arguments->find("notEmpty") != arguments->end()) {
+        if (arguments && arguments->find("notEmpty") != arguments->end()) {
             notEmpty = arguments->find("notEmpty")->second == "true";
         }
         newOption(ConfigSetup::getXmlContent(root, true));
@@ -305,7 +312,7 @@ class ConfigIntSetup : public ConfigSetup {
 protected:
     IntCheckFunction valueCheck = nullptr;
     IntMinFunction minCheck = nullptr;
-    int minValue;
+    int minValue {};
 
 public:
     ConfigIntSetup(config_option_t option, const char* xpath, const char* help)
@@ -372,7 +379,7 @@ public:
 
     int checkIntValue(std::string& sVal, const std::string& pathName = "") const;
 
-    std::string getCurrentValue() const override { return optionValue == nullptr ? "" : fmt::format("{}", optionValue->getIntOption()); }
+    std::string getCurrentValue() const override { return optionValue ? fmt::to_string(optionValue->getIntOption()) : ""; }
 
     static bool CheckSqlLiteSyncValue(std::string& value);
 
@@ -423,7 +430,7 @@ public:
 
     std::shared_ptr<ConfigOption> newOption(bool optValue);
 
-    std::string getCurrentValue() const override { return optionValue == nullptr ? "" : (optionValue->getBoolOption() ? "true" : "false"); }
+    std::string getCurrentValue() const override { return optionValue ? (optionValue->getBoolOption() ? "true" : "false") : ""; }
 
     static bool CheckSqlLiteRestoreValue(std::string& value);
 
@@ -437,7 +444,7 @@ protected:
     bool notEmpty = false;
     bool itemNotEmpty = false;
     ArrayInitFunction initArray = nullptr;
-    std::vector<std::string> defaultEntries = {};
+    std::vector<std::string> defaultEntries;
 
     /// \brief Creates an array of strings from an XML nodeset.
     /// \param element starting element of the nodeset.
@@ -452,7 +459,7 @@ protected:
     /// <some-section>
     ///
     /// This function will create an array like that: ["data", "otherdata"]
-    bool createArrayFromNode(const pugi::xml_node& element, std::vector<std::string>& result) const;
+    bool createOptionFromNode(const pugi::xml_node& element, std::vector<std::string>& result) const;
 
     bool updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, const std::shared_ptr<ArrayOption>& value, const std::string& optValue, const std::string& status = "") const;
 
@@ -461,11 +468,11 @@ public:
     config_option_t attrOption = CFG_MAX;
 
     ConfigArraySetup(config_option_t option, const char* xpath, const char* help, config_option_t nodeOption,
-        ArrayInitFunction init = nullptr, bool notEmpty = false, const std::vector<std::string>& defaultEntries = {})
+        ArrayInitFunction init = nullptr, bool notEmpty = false, std::vector<std::string> defaultEntries = {})
         : ConfigSetup(option, xpath, help)
         , notEmpty(notEmpty)
         , initArray(init)
-        , defaultEntries(defaultEntries)
+        , defaultEntries(std::move(defaultEntries))
         , nodeOption(nodeOption)
     {
     }
@@ -495,7 +502,7 @@ public:
 
     std::shared_ptr<ConfigOption> newOption(const std::vector<std::string>& optValue);
 
-    std::string getCurrentValue() const override { return ""; }
+    std::string getCurrentValue() const override { return {}; }
 
     static bool InitPlayedItemsMark(const pugi::xml_node& value, std::vector<std::string>& result, const char* node_name);
 
@@ -508,7 +515,7 @@ protected:
     bool itemNotEmpty = false;
     DictionaryInitFunction initDict = nullptr;
     bool tolower = false;
-    std::map<std::string, std::string> defaultEntries = {};
+    std::map<std::string, std::string> defaultEntries;
 
     /// \brief Creates a dictionary from an XML nodeset.
     /// \param element starting element of the nodeset.
@@ -525,32 +532,32 @@ protected:
     ///
     /// This function will create a dictionary with the following
     /// key:value paris: "1":"2", "3":"4"
-    bool createDictionaryFromNode(const pugi::xml_node& optValue, std::map<std::string, std::string>& result) const;
+    bool createOptionFromNode(const pugi::xml_node& optValue, std::map<std::string, std::string>& result) const;
 
     bool updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, const std::shared_ptr<DictionaryOption>& value, const std::string& optKey, const std::string& optValue, const std::string& status = "") const;
 
 public:
-    config_option_t nodeOption;
-    config_option_t keyOption;
-    config_option_t valOption;
+    config_option_t nodeOption {};
+    config_option_t keyOption {};
+    config_option_t valOption {};
 
     explicit ConfigDictionarySetup(config_option_t option, const char* xpath, const char* help, DictionaryInitFunction init = nullptr,
-        bool notEmpty = false, bool itemNotEmpty = false, bool required = false, const std::map<std::string, std::string>& defaultEntries = {})
+        bool notEmpty = false, bool itemNotEmpty = false, bool required = false, std::map<std::string, std::string> defaultEntries = {})
         : ConfigSetup(option, xpath, help, required && defaultEntries.empty())
         , notEmpty(notEmpty)
         , itemNotEmpty(itemNotEmpty)
         , initDict(init)
-        , defaultEntries(defaultEntries)
+        , defaultEntries(std::move(defaultEntries))
     {
     }
 
     explicit ConfigDictionarySetup(config_option_t option, const char* xpath, const char* help,
         config_option_t nodeOption, config_option_t keyOption, config_option_t valOption,
-        bool notEmpty = false, bool itemNotEmpty = false, bool required = false, const std::map<std::string, std::string>& defaultEntries = {})
+        bool notEmpty = false, bool itemNotEmpty = false, bool required = false, std::map<std::string, std::string> defaultEntries = {})
         : ConfigSetup(option, xpath, help, required && defaultEntries.empty())
         , notEmpty(notEmpty)
         , itemNotEmpty(itemNotEmpty)
-        , defaultEntries(defaultEntries)
+        , defaultEntries(std::move(defaultEntries))
         , nodeOption(nodeOption)
         , keyOption(keyOption)
         , valOption(valOption)
@@ -569,7 +576,7 @@ public:
 
     std::shared_ptr<ConfigOption> newOption(const std::map<std::string, std::string>& optValue);
 
-    std::string getCurrentValue() const override { return ""; }
+    std::string getCurrentValue() const override { return {}; }
 };
 
 class ConfigAutoscanSetup : public ConfigSetup {
@@ -580,9 +587,9 @@ protected:
     /// \brief Creates an array of AutoscanDirectory objects from a XML nodeset.
     /// \param element starting element of the nodeset.
     /// \param scanmode add only directories with the specified scanmode to the array
-    bool createAutoscanListFromNode(const pugi::xml_node& element, std::shared_ptr<AutoscanList>& result);
+    bool createOptionFromNode(const pugi::xml_node& element, std::shared_ptr<AutoscanList>& result);
 
-    bool updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, std::shared_ptr<AutoscanDirectory>& entry, std::string& optValue, const std::string& status = "") const;
+    bool updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, const std::shared_ptr<AutoscanDirectory>& entry, std::string& optValue, const std::string& status = "") const;
 
 public:
     ConfigAutoscanSetup(config_option_t option, const char* xpath, const char* help, ScanMode scanmode)
@@ -603,7 +610,7 @@ public:
 
     std::shared_ptr<ConfigOption> newOption(const pugi::xml_node& optValue);
 
-    std::string getCurrentValue() const override { return ""; }
+    std::string getCurrentValue() const override { return {}; }
 };
 
 class ConfigTranscodingSetup : public ConfigSetup {
@@ -613,7 +620,7 @@ protected:
     /// \brief Creates an array of TranscodingProfile objects from an XML
     /// nodeset.
     /// \param element starting element of the nodeset.
-    static bool createTranscodingProfileListFromNode(const pugi::xml_node& element, std::shared_ptr<TranscodingProfileList>& result);
+    static bool createOptionFromNode(const pugi::xml_node& element, std::shared_ptr<TranscodingProfileList>& result);
 
 public:
     ConfigTranscodingSetup(config_option_t option, const char* xpath, const char* help)
@@ -631,7 +638,7 @@ public:
 
     std::shared_ptr<ConfigOption> newOption(const pugi::xml_node& optValue);
 
-    std::string getCurrentValue() const override { return ""; }
+    std::string getCurrentValue() const override { return {}; }
 };
 
 class ConfigClientSetup : public ConfigSetup {
@@ -640,7 +647,7 @@ protected:
 
     /// \brief Creates an array of ClientConfig objects from a XML nodeset.
     /// \param element starting element of the nodeset.
-    static bool createClientConfigListFromNode(const pugi::xml_node& element, std::shared_ptr<ClientConfigList>& result);
+    static bool createOptionFromNode(const pugi::xml_node& element, std::shared_ptr<ClientConfigList>& result);
 
     bool updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, std::shared_ptr<ClientConfig>& entry, std::string& optValue, const std::string& status = "") const;
 
@@ -660,14 +667,14 @@ public:
 
     std::shared_ptr<ConfigOption> newOption(const pugi::xml_node& optValue);
 
-    std::string getCurrentValue() const override { return ""; }
+    std::string getCurrentValue() const override { return {}; }
 };
 
 class ConfigDirectorySetup : public ConfigSetup {
 protected:
-    /// \brief Creates an array of ClientConfig objects from a XML nodeset.
+    /// \brief Creates an array of DirectoryTweak objects from a XML nodeset.
     /// \param element starting element of the nodeset.
-    static bool createDirectoryTweakListFromNode(const pugi::xml_node& element, std::shared_ptr<DirectoryConfigList>& result);
+    static bool createOptionFromNode(const pugi::xml_node& element, std::shared_ptr<DirectoryConfigList>& result);
 
     bool updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, std::shared_ptr<DirectoryTweak>& entry, std::string& optValue, const std::string& status = "") const;
 
@@ -687,7 +694,35 @@ public:
 
     std::shared_ptr<ConfigOption> newOption(const pugi::xml_node& optValue);
 
-    std::string getCurrentValue() const override { return ""; }
+    std::string getCurrentValue() const override { return {}; }
+};
+
+/// \brief Setup of dynamic content reader
+class ConfigDynamicContentSetup : public ConfigSetup {
+protected:
+    /// \brief Creates an array of DynamicContent objects from a XML nodeset.
+    /// \param element starting element of the nodeset.
+    static bool createOptionFromNode(const pugi::xml_node& element, std::shared_ptr<DynamicContentList>& result);
+
+    bool updateItem(size_t i, const std::string& optItem, const std::shared_ptr<Config>& config, std::shared_ptr<DynamicContent>& entry, std::string& optValue, const std::string& status = "") const;
+
+public:
+    ConfigDynamicContentSetup(config_option_t option, const char* xpath, const char* help)
+        : ConfigSetup(option, xpath, help)
+    {
+    }
+
+    std::string getTypeString() const override { return "List"; }
+
+    void makeOption(const pugi::xml_node& root, const std::shared_ptr<Config>& config, const std::map<std::string, std::string>* arguments = nullptr) override;
+
+    bool updateDetail(const std::string& optItem, std::string& optValue, const std::shared_ptr<Config>& config, const std::map<std::string, std::string>* arguments = nullptr) override;
+
+    std::string getItemPath(int index = 0, config_option_t propOption = CFG_MAX, config_option_t propOption2 = CFG_MAX, config_option_t propOption3 = CFG_MAX, config_option_t propOption4 = CFG_MAX) const override;
+
+    std::shared_ptr<ConfigOption> newOption(const pugi::xml_node& optValue);
+
+    std::string getCurrentValue() const override { return {}; }
 };
 
 #endif // __CONFIG_SETUP_H__
