@@ -54,7 +54,6 @@ AutoscanInotify::AutoscanInotify(std::shared_ptr<ContentManager> content)
         }
     }
 
-    watches = std::make_unique<std::unordered_map<int, std::shared_ptr<Wd>>>();
     shutdownFlag = true;
     events = IN_CLOSE_WRITE | IN_CREATE | IN_MOVED_FROM | IN_MOVED_TO | IN_DELETE | IN_DELETE_SELF | IN_MOVE_SELF | IN_UNMOUNT;
 }
@@ -70,7 +69,7 @@ AutoscanInotify::~AutoscanInotify()
         thread_.join();
         log_debug("inotify thread died.");
         inotify = nullptr;
-        watches->clear();
+        watches.clear();
     }
 }
 
@@ -81,10 +80,11 @@ void AutoscanInotify::run()
     if (shutdownFlag) {
         shutdownFlag = false;
         inotify = std::make_unique<Inotify>();
-        thread_ = std::thread { &AutoscanInotify::threadProc, this };
+        thread_ = std::thread([this] { threadProc(); });
     }
 }
 
+/// \brief main proc for thread
 void AutoscanInotify::threadProc()
 {
     std::error_code ec;
@@ -92,6 +92,7 @@ void AutoscanInotify::threadProc()
         try {
             std::unique_lock<std::mutex> lock(mutex);
 
+            //  remove old dirs
             while (!unmonitorQueue.empty()) {
                 auto adir = unmonitorQueue.front();
                 unmonitorQueue.pop();
@@ -103,6 +104,7 @@ void AutoscanInotify::threadProc()
                     lock.lock();
                     continue;
                 }
+                // read dir
                 auto dirEnt = fs::directory_entry(location, ec);
 
                 if (adir->getRecursive()) {
@@ -116,12 +118,14 @@ void AutoscanInotify::threadProc()
                 lock.lock();
             }
 
+            // monitor new dir
             while (!monitorQueue.empty()) {
                 auto adir = monitorQueue.front();
                 monitorQueue.pop();
 
                 lock.unlock();
 
+                // read dir
                 fs::path location = adir->getLocation();
                 if (location.empty()) {
                     lock.lock();
@@ -130,6 +134,7 @@ void AutoscanInotify::threadProc()
 
                 auto dirEnt = fs::directory_entry(location, ec);
                 if (!ec) {
+                    // handle dir recursively
                     if (adir->getRecursive()) {
                         log_debug("Adding recursive watch: {}", location.c_str());
                         monitorUnmonitorRecursive(dirEnt, false, adir, true, config->getBoolOption(CFG_IMPORT_FOLLOW_SYMLINKS));
@@ -157,39 +162,42 @@ void AutoscanInotify::threadProc()
                 std::string name = event->name;
                 log_debug("inotify event: {} 0x{:x} {}", wd, mask, name.c_str());
 
-                std::shared_ptr<Wd> wdObj = nullptr;
+                std::shared_ptr<Wd> wdObj;
                 try {
-                    wdObj = watches->at(wd);
+                    wdObj = watches.at(wd);
                 } catch (const std::out_of_range& ex) {
                     inotify->removeWatch(wd);
                     continue;
                 }
 
                 fs::path path = wdObj->getPath();
+                // file is not gone
                 if (!(mask & (IN_DELETE_SELF | IN_MOVE_SELF | IN_UNMOUNT)))
                     path /= name;
 
                 std::shared_ptr<AutoscanDirectory> adir;
                 auto watchAs = getAppropriateAutoscan(wdObj, path);
-                if (watchAs != nullptr)
+                if (watchAs)
                     adir = watchAs->getAutoscanDirectory();
-                else
-                    adir = nullptr;
 
+                // file is renamed
                 if (mask & IN_MOVE_SELF) {
                     checkMoveWatches(wd, wdObj);
                 }
 
+                // file is deleted
                 if (mask & (IN_DELETE_SELF | IN_MOVE_SELF | IN_UNMOUNT)) {
                     recheckNonexistingMonitors(wd, wdObj);
                 }
 
+                // file is directory
                 if (mask & IN_ISDIR) {
                     if (mask & (IN_CREATE | IN_MOVED_TO)) {
                         recheckNonexistingMonitors(wd, wdObj);
                     }
 
-                    if (adir != nullptr && adir->getRecursive()) {
+                    if (adir && adir->getRecursive()) {
+                        // dir created
                         if (mask & IN_CREATE) {
                             if (adir->getHidden() || name.at(0) != '.') {
                                 log_debug("Detected new dir, adding to inotify: {}", path.c_str());
@@ -206,15 +214,18 @@ void AutoscanInotify::threadProc()
                     }
                 }
 
-                if (adir != nullptr && mask & (IN_DELETE | IN_DELETE_SELF | IN_MOVE_SELF | IN_CLOSE_WRITE | IN_MOVED_FROM | IN_MOVED_TO | IN_UNMOUNT | IN_CREATE)) {
+                // changed
+                if (adir && mask & (IN_DELETE | IN_DELETE_SELF | IN_MOVE_SELF | IN_CLOSE_WRITE | IN_MOVED_FROM | IN_MOVED_TO | IN_UNMOUNT | IN_CREATE)) {
+                    // not new
                     if (!(mask & (IN_MOVED_TO | IN_CREATE))) {
                         log_debug("deleting {}", path.c_str());
 
+                        // deleted
                         if (mask & (IN_DELETE_SELF | IN_MOVE_SELF | IN_UNMOUNT)) {
                             if (mask & IN_MOVE_SELF)
                                 inotify->removeWatch(wd);
                             auto watch = getStartPoint(wdObj);
-                            if (watch != nullptr) {
+                            if (watch) {
                                 if (adir->persistent()) {
                                     monitorNonexisting(path, watch->getAutoscanDirectory());
                                     content->handlePeristentAutoscanRemove(adir);
@@ -226,6 +237,7 @@ void AutoscanInotify::threadProc()
                         if (objectID != INVALID_OBJECT_ID)
                             content->removeObject(adir, objectID, !(mask & IN_MOVED_TO));
                     }
+                    // new file
                     if (mask & (IN_CLOSE_WRITE | IN_MOVED_TO | IN_CREATE)) {
                         log_debug("Adding {}", path.c_str());
                         auto dirEnt = fs::directory_entry(path, ec);
@@ -250,7 +262,7 @@ void AutoscanInotify::threadProc()
                 if (mask & IN_IGNORED) {
                     removeWatchMoves(wd);
                     removeDescendants(wd);
-                    watches->erase(wd);
+                    watches.erase(wd);
                 }
             }
         } catch (const std::runtime_error& e) {
@@ -298,12 +310,12 @@ int AutoscanInotify::addMoveWatch(const fs::path& path, int removeWd, int parent
 {
     int wd = inotify->addWatch(path, events);
     if (wd >= 0) {
-        bool alreadyThere = false;
-
-        std::shared_ptr<Wd> wdObj = nullptr;
+        std::shared_ptr<Wd> wdObj;
         try {
-            wdObj = watches->at(wd);
+            //find
+            wdObj = watches.at(wd);
 
+            //alreadyThere
             int parentWdSet = wdObj->getParentWd();
             if (parentWdSet >= 0) {
                 if (parentWd != parentWdSet) {
@@ -312,27 +324,22 @@ int AutoscanInotify::addMoveWatch(const fs::path& path, int removeWd, int parent
                 }
             } else
                 wdObj->setParentWd(parentWd);
-
-            //find
-            //alreadyThere =...
-            //FIXME: not finished?
-
         } catch (const std::out_of_range& ex) {
+            // add new wstch
             wdObj = std::make_shared<Wd>(path, wd, parentWd);
-            watches->emplace(wd, wdObj);
+            watches.emplace(wd, wdObj);
         }
 
-        if (!alreadyThere) {
-            auto watch = std::make_shared<WatchMove>(removeWd);
-            wdObj->addWatch(watch);
-        }
+        // add move watch
+        auto watch = std::make_shared<WatchMove>(removeWd);
+        wdObj->addWatch(move(watch));
     }
     return wd;
 }
 
 void AutoscanInotify::monitorNonexisting(const fs::path& path, const std::shared_ptr<AutoscanDirectory>& adir)
 {
-    auto pathAr = splitString(path, DIR_SEPARATOR);
+    auto pathAr = splitString(path.string(), DIR_SEPARATOR);
     recheckNonexistingMonitor(-1, pathAr, adir);
 }
 
@@ -356,7 +363,7 @@ void AutoscanInotify::recheckNonexistingMonitor(int curWd, const std::vector<std
         //        log_debug("checking {}: {}", path.c_str(), pathExists);
         if (pathExists) {
             if (curWd != -1)
-                removeNonexistingMonitor(curWd, watches->at(curWd), pathAr);
+                removeNonexistingMonitor(curWd, watches.at(curWd), pathAr);
             if (first) {
                 monitorDirectory(path, adir, true);
                 content->handlePersistentAutoscanRecreate(adir);
@@ -372,7 +379,7 @@ void AutoscanInotify::recheckNonexistingMonitor(int curWd, const std::vector<std
 
 void AutoscanInotify::checkMoveWatches(int wd, const std::shared_ptr<Wd>& wdObj)
 {
-    auto wdWatches = wdObj->getWdWatches();
+    auto&& wdWatches = wdObj->getWdWatches();
     for (auto it = wdWatches->begin(); it != wdWatches->end(); /*++it*/) {
         auto& watchToCheck = *it;
         if (watchToCheck->getType() == WatchType::Move) {
@@ -386,7 +393,7 @@ void AutoscanInotify::checkMoveWatches(int wd, const std::shared_ptr<Wd>& wdObj)
             auto watchMv = std::static_pointer_cast<WatchMove>(watchToCheck);
             int removeWd = watchMv->getRemoveWd();
             try {
-                auto wdToRemove = watches->at(removeWd);
+                auto wdToRemove = watches.at(removeWd);
 
                 recheckNonexistingMonitors(removeWd, wdToRemove);
 
@@ -395,8 +402,8 @@ void AutoscanInotify::checkMoveWatches(int wd, const std::shared_ptr<Wd>& wdObj)
 
                 inotify->removeWatch(removeWd);
                 auto watchToRemove = getStartPoint(wdToRemove);
-                if (watchToRemove != nullptr) {
-                    std::shared_ptr<AutoscanDirectory> adir = watchToRemove->getAutoscanDirectory();
+                if (watchToRemove) {
+                    auto adir = watchToRemove->getAutoscanDirectory();
                     if (adir->persistent()) {
                         monitorNonexisting(path, adir);
                         content->handlePeristentAutoscanRemove(adir);
@@ -415,7 +422,7 @@ void AutoscanInotify::checkMoveWatches(int wd, const std::shared_ptr<Wd>& wdObj)
 
 void AutoscanInotify::recheckNonexistingMonitors(int wd, const std::shared_ptr<Wd>& wdObj)
 {
-    auto wdWatches = wdObj->getWdWatches();
+    auto&& wdWatches = wdObj->getWdWatches();
     for (auto&& watch : *wdWatches) {
         if (watch->getType() == WatchType::Autoscan) {
             auto watchAs = std::static_pointer_cast<WatchAutoscan>(watch);
@@ -429,7 +436,7 @@ void AutoscanInotify::recheckNonexistingMonitors(int wd, const std::shared_ptr<W
 
 void AutoscanInotify::removeNonexistingMonitor(int wd, const std::shared_ptr<Wd>& wdObj, const std::vector<std::string>& pathAr)
 {
-    auto wdWatches = wdObj->getWdWatches();
+    auto&& wdWatches = wdObj->getWdWatches();
     for (auto it = wdWatches->begin(); it != wdWatches->end(); /*++it*/) {
         auto& watch = *it;
         if (watch->getType() == WatchType::Autoscan) {
@@ -437,7 +444,7 @@ void AutoscanInotify::removeNonexistingMonitor(int wd, const std::shared_ptr<Wd>
             if (watchAs->getNonexistingPathArray() == pathAr) {
                 if (wdWatches->size() == 1) {
                     // should be done automatically, because removeWatch triggers an IGNORED event
-                    //watches->remove(wd);
+                    //watches.remove(wd);
 
                     inotify->removeWatch(wd);
                     ++it;
@@ -503,29 +510,29 @@ int AutoscanInotify::monitorDirectory(const fs::path& path, const std::shared_pt
         if (startPoint)
             parentWd = watchPathForMoves(path, wd);
 
-        std::shared_ptr<Wd> wdObj = nullptr;
+        std::shared_ptr<Wd> wdObj;
         try {
-            wdObj = watches->at(wd);
+            wdObj = watches.at(wd);
             if (parentWd >= 0 && wdObj->getParentWd() < 0) {
                 wdObj->setParentWd(parentWd);
             }
 
-            if (pathArray == nullptr)
-                alreadyWatching = (getAppropriateAutoscan(wdObj, adir) != nullptr);
+            if (!pathArray)
+                alreadyWatching = getAppropriateAutoscan(wdObj, adir) != nullptr;
 
             // should we check for already existing "nonexisting" watches?
             // ...
         } catch (const std::out_of_range& ex) {
             wdObj = std::make_shared<Wd>(path, wd, parentWd);
-            watches->emplace(wd, wdObj);
+            watches.emplace(wd, wdObj);
         }
 
         if (!alreadyWatching) {
             auto watch = std::make_shared<WatchAutoscan>(startPoint, adir);
-            if (pathArray != nullptr) {
+            if (pathArray) {
                 watch->setNonexistingPathArray(*pathArray);
             }
-            wdObj->addWatch(watch);
+            wdObj->addWatch(move(watch));
 
             if (!startPoint) {
                 int startPointWd = inotify->addWatch(adir->getLocation(), events);
@@ -551,19 +558,19 @@ void AutoscanInotify::unmonitorDirectory(const fs::path& path, const std::shared
         return;
     }
 
-    auto wdObj = watches->at(wd);
-    if (wdObj == nullptr) {
+    auto wdObj = watches.at(wd);
+    if (!wdObj) {
         log_error("wd not found in watches!? ({}, {})", wd, path.c_str());
         return;
     }
 
     auto watchAs = getAppropriateAutoscan(wdObj, adir);
-    if (watchAs == nullptr) {
+    if (!watchAs) {
         log_debug("autoscan not found in watches? ({}, {})", wd, path.c_str());
     } else {
         if (wdObj->getWdWatches()->size() == 1) {
             // should be done automatically, because removeWatch triggers an IGNORED event
-            //watches->remove(wd);
+            //watches.remove(wd);
 
             inotify->removeWatch(wd);
         } else {
@@ -574,7 +581,7 @@ void AutoscanInotify::unmonitorDirectory(const fs::path& path, const std::shared
 
 std::shared_ptr<AutoscanInotify::WatchAutoscan> AutoscanInotify::getAppropriateAutoscan(const std::shared_ptr<Wd>& wdObj, const std::shared_ptr<AutoscanDirectory>& adir)
 {
-    auto wdWatches = wdObj->getWdWatches();
+    auto&& wdWatches = wdObj->getWdWatches();
     for (auto&& watch : *wdWatches) {
         if (watch->getType() == WatchType::Autoscan) {
             auto watchAs = std::static_pointer_cast<WatchAutoscan>(watch);
@@ -591,14 +598,14 @@ std::shared_ptr<AutoscanInotify::WatchAutoscan> AutoscanInotify::getAppropriateA
 std::shared_ptr<AutoscanInotify::WatchAutoscan> AutoscanInotify::getAppropriateAutoscan(const std::shared_ptr<Wd>& wdObj, const fs::path& path)
 {
     fs::path pathBestMatch;
-    std::shared_ptr<WatchAutoscan> bestMatch = nullptr;
-    auto wdWatches = wdObj->getWdWatches();
+    std::shared_ptr<WatchAutoscan> bestMatch;
+    auto&& wdWatches = wdObj->getWdWatches();
     for (auto&& watch : *wdWatches) {
         if (watch->getType() == WatchType::Autoscan) {
             auto watchAs = std::static_pointer_cast<WatchAutoscan>(watch);
             if (watchAs->getNonexistingPathArray().empty()) {
                 fs::path testLocation = watchAs->getAutoscanDirectory()->getLocation();
-                if (startswith(path, testLocation)) {
+                if (startswith(path.string(), testLocation.string())) {
                     if (!pathBestMatch.empty()) {
                         if (pathBestMatch.string().length() < testLocation.string().length()) {
                             pathBestMatch = testLocation;
@@ -620,14 +627,14 @@ void AutoscanInotify::removeWatchMoves(int wd)
     bool first = true;
     int checkWd = wd;
     do {
-        std::shared_ptr<Wd> wdObj = nullptr;
+        std::shared_ptr<Wd> wdObj;
         try {
-            wdObj = watches->at(checkWd);
+            wdObj = watches.at(checkWd);
         } catch (const std::out_of_range& ex) {
             break;
         }
 
-        auto wdWatches = wdObj->getWdWatches();
+        auto&& wdWatches = wdObj->getWdWatches();
         if (wdWatches->empty())
             break;
 
@@ -656,7 +663,7 @@ void AutoscanInotify::removeWatchMoves(int wd)
 
 bool AutoscanInotify::removeFromWdObj(const std::shared_ptr<Wd>& wdObj, const std::shared_ptr<Watch>& toRemove)
 {
-    auto wdWatches = wdObj->getWdWatches();
+    auto&& wdWatches = wdObj->getWdWatches();
     for (auto it = wdWatches->begin(); it != wdWatches->end(); /*++it*/) {
         auto& watch = *it;
         if (watch == toRemove) {
@@ -674,7 +681,7 @@ bool AutoscanInotify::removeFromWdObj(const std::shared_ptr<Wd>& wdObj, const st
 
 std::shared_ptr<AutoscanInotify::WatchAutoscan> AutoscanInotify::getStartPoint(const std::shared_ptr<Wd>& wdObj)
 {
-    auto wdWatches = wdObj->getWdWatches();
+    auto&& wdWatches = wdObj->getWdWatches();
     for (auto&& watch : *wdWatches) {
         if (watch->getType() == WatchType::Autoscan) {
             auto watchAs = std::static_pointer_cast<WatchAutoscan>(watch);
@@ -688,34 +695,34 @@ std::shared_ptr<AutoscanInotify::WatchAutoscan> AutoscanInotify::getStartPoint(c
 void AutoscanInotify::addDescendant(int startPointWd, int addWd, const std::shared_ptr<AutoscanDirectory>& adir)
 {
     //    log_debug("called for {}, (adir->path={}); adding {}", startPointWd, adir->getLocation().c_str(), addWd);
-    std::shared_ptr<Wd> wdObj = nullptr;
+    std::shared_ptr<Wd> wdObj;
     try {
-        wdObj = watches->at(startPointWd);
+        wdObj = watches.at(startPointWd);
     } catch (const std::out_of_range& ex) {
         return;
     }
-    if (wdObj == nullptr)
+    if (!wdObj)
         return;
 
     //   log_debug("found wdObj");
     auto watch = getAppropriateAutoscan(wdObj, adir);
-    if (watch == nullptr)
+    if (!watch)
         return;
-    //    log_debug("adding descendant");
+    // log_debug("adding descendant");
     watch->addDescendant(addWd);
-    //    log_debug("added descendant to {} (adir->path={}): {}; now: {}", startPointWd, adir->getLocation().c_str(), addWd, watch->getDescendants()->toCSV().c_str());
+    // log_debug("added descendant to {} (adir->path={}): {}; now: {}", startPointWd, adir->getLocation(), addWd, fmt::join(*(watch->getDescendants()), ","));
 }
 
 void AutoscanInotify::removeDescendants(int wd)
 {
-    std::shared_ptr<Wd> wdObj = nullptr;
+    std::shared_ptr<Wd> wdObj;
     try {
-        wdObj = watches->at(wd);
+        wdObj = watches.at(wd);
     } catch (const std::out_of_range& ex) {
         return;
     }
 
-    auto wdWatches = wdObj->getWdWatches();
+    auto&& wdWatches = wdObj->getWdWatches();
     for (auto&& watch : *wdWatches) {
         if (watch->getType() == WatchType::Autoscan) {
             auto watchAs = std::static_pointer_cast<WatchAutoscan>(watch);
