@@ -93,8 +93,8 @@ private:
     class Watch {
     public:
         explicit Watch(WatchType type)
+            : type(type)
         {
-            this->type = type;
         }
         WatchType getType() const { return type; }
 
@@ -143,7 +143,7 @@ private:
     class Wd {
     public:
         Wd(fs::path path, int wd, int parentWd)
-            : wdWatches(std::make_shared<std::vector<std::shared_ptr<Watch>>>())
+            : wdWatches(std::make_unique<std::vector<std::shared_ptr<Watch>>>())
             , path(std::move(path))
             , parentWd(parentWd)
             , wd(wd)
@@ -154,17 +154,17 @@ private:
         int getParentWd() const { return parentWd; }
         void setParentWd(int parentWd) { this->parentWd = parentWd; }
 
-        std::shared_ptr<std::vector<std::shared_ptr<Watch>>> getWdWatches() const { return wdWatches; }
-        void addWatch(const std::shared_ptr<Watch>& w) { wdWatches->push_back(w); }
+        const std::unique_ptr<std::vector<std::shared_ptr<Watch>>>& getWdWatches() { return wdWatches; }
+        void addWatch(std::shared_ptr<Watch> w) { wdWatches->push_back(move(w)); }
 
     private:
-        std::shared_ptr<std::vector<std::shared_ptr<Watch>>> wdWatches;
+        std::unique_ptr<std::vector<std::shared_ptr<Watch>>> wdWatches;
         fs::path path;
         int parentWd;
         int wd;
     };
 
-    std::unique_ptr<std::unordered_map<int, std::shared_ptr<Wd>>> watches;
+    std::unordered_map<int, std::shared_ptr<Wd>> watches;
 
     void monitorUnmonitorRecursive(const fs::directory_entry& startPath, bool unmonitor, const std::shared_ptr<AutoscanDirectory>& adir, bool startPoint, bool followSymlinks);
     int monitorDirectory(const fs::path& path, const std::shared_ptr<AutoscanDirectory>& adir, bool startPoint, const std::vector<std::string>* pathArray = nullptr);
