@@ -32,7 +32,6 @@
 #include "content_manager.h" // API
 
 #include <cerrno>
-#include <chrono>
 #include <cstring>
 #include <regex>
 
@@ -81,21 +80,17 @@ ContentManager::ContentManager(const std::shared_ptr<Context>& context,
     , session_manager(context->getSessionManager())
     , context(context)
     , timer(std::move(timer))
-    , layout_enabled(false)
-    , working(false)
-    , shutdownFlag(false)
-    , taskID(1)
+#ifdef HAVE_JS
+    , scripting_runtime(std::make_shared<ScriptingRuntime>())
+#endif
+#ifdef HAVE_LASTFMLIB
+    , last_fm(std::make_shared<LastFm>(context))
+#endif
 {
     update_manager = std::make_shared<UpdateManager>(config, database, server);
 #ifdef ONLINE_SERVICES
     task_processor = std::make_shared<TaskProcessor>(config);
 #endif
-#ifdef HAVE_JS
-    scripting_runtime = std::make_shared<ScriptingRuntime>();
-#endif
-#ifdef HAVE_LASTFMLIB
-    last_fm = std::make_shared<LastFm>(context);
-#endif
 
     mimetype_contenttype_map = config->getDictionaryOption(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST);
 }
@@ -121,7 +116,7 @@ void ContentManager::run()
     auto config_timed_list = config->getAutoscanListOption(CFG_IMPORT_AUTOSCAN_TIMED_LIST);
     for (size_t i = 0; i < config_timed_list->size(); i++) {
         auto dir = config_timed_list->get(i);
-        if (dir != nullptr) {
+        if (dir) {
             fs::path path = dir->getLocation();
             if (fs::is_directory(path)) {
                 dir->setObjectID(ensurePathExistence(path));
@@ -140,7 +135,7 @@ void ContentManager::run()
         auto config_inotify_list = config->getAutoscanListOption(CFG_IMPORT_AUTOSCAN_INOTIFY_LIST);
         for (size_t i = 0; i < config_inotify_list->size(); i++) {
             auto dir = config_inotify_list->get(i);
-            if (dir != nullptr) {
+            if (dir) {
                 fs::path path = dir->getLocation();
                 if (fs::is_directory(path)) {
                     dir->setObjectID(ensurePathExistence(path));
@@ -232,8 +227,8 @@ void ContentManager::run()
     if (config->getBoolOption(CFG_IMPORT_AUTOSCAN_USE_INOTIFY)) {
         /// \todo change this (we need a new autoscan architecture)
         for (size_t i = 0; i < autoscan_inotify->size(); i++) {
-            std::shared_ptr<AutoscanDirectory> adir = autoscan_inotify->get(i);
-            if (adir == nullptr) {
+            auto adir = autoscan_inotify->get(i);
+            if (!adir) {
                 continue;
             }
 
@@ -246,7 +241,7 @@ void ContentManager::run()
 #endif
 
     for (size_t i = 0; i < autoscan_timed->size(); i++) {
-        std::shared_ptr<AutoscanDirectory> adir = autoscan_timed->get(i);
+        auto adir = autoscan_timed->get(i);
         auto param = std::make_shared<Timer::Parameter>(Timer::Parameter::timer_param_t::IDAutoscan, adir->getScanID());
         log_debug("Adding timed scan with interval {}", adir->getInterval().count());
         timer->addTimerSubscriber(this, adir->getInterval(), param, false);
@@ -279,14 +274,14 @@ void ContentManager::unregisterExecutor(const std::shared_ptr<Executor>& exec)
 
 void ContentManager::timerNotify(std::shared_ptr<Timer::Parameter> parameter)
 {
-    if (parameter == nullptr)
+    if (!parameter)
         return;
 
     if (parameter->whoami() == Timer::Parameter::IDAutoscan) {
-        std::shared_ptr<AutoscanDirectory> adir = autoscan_timed->get(parameter->getID());
+        auto adir = autoscan_timed->get(parameter->getID());
 
         // do not rescan while other scans are still active
-        if (adir == nullptr || adir->getActiveScanCount() > 0 || adir->getTaskCount() > 0)
+        if (!adir || adir->getActiveScanCount() > 0 || adir->getTaskCount() > 0)
             return;
 
         rescanDirectory(adir, adir->getObjectID());
@@ -298,14 +293,6 @@ void ContentManager::timerNotify(std::shared_ptr<Timer::Parameter> parameter)
 #endif // ONLINE_SERVICES
 }
 
-template <typename TP>
-static std::chrono::seconds to_seconds(TP tp)
-{
-    auto asSystemTime = std::chrono::time_point_cast<std::chrono::system_clock::duration>(tp - TP::clock::now()
-        + std::chrono::system_clock::now());
-    return std::chrono::seconds(std::chrono::system_clock::to_time_t(asSystemTime));
-}
-
 void ContentManager::shutdown()
 {
     log_debug("start");
@@ -323,8 +310,8 @@ void ContentManager::shutdown()
         // update modification time for database
         for (size_t i = 0; i < autoscan_inotify->size(); i++) {
             log_debug("AutoScanDir {}", i);
-            std::shared_ptr<AutoscanDirectory> dir = autoscan_inotify->get(i);
-            if (dir != nullptr) {
+            auto dir = autoscan_inotify->get(i);
+            if (dir) {
                 auto dirEnt = fs::directory_entry(dir->getLocation());
                 if (dirEnt.is_directory()) {
                     auto t = to_seconds(dirEnt.last_write_time());
@@ -343,7 +330,7 @@ void ContentManager::shutdown()
     shutdownFlag = true;
 
     for (auto&& exec : process_list) {
-        if (exec != nullptr)
+        if (exec)
             exec->kill();
     }
 
@@ -390,10 +377,10 @@ std::deque<std::shared_ptr<GenericTask>> ContentManager::getTasklist()
 
     // if there is no current task, then the queues are empty
     // and we do not have to allocate the array
-    if (t == nullptr)
+    if (!t)
         return taskList;
 
-    taskList.push_back(t);
+    taskList.push_back(std::move(t));
     std::copy_if(taskQueue1.begin(), taskQueue1.end(), std::back_inserter(taskList), [](auto&& task) { return task->isValid(); });
 
     for (auto&& task : taskQueue2) {
@@ -415,9 +402,9 @@ void ContentManager::addVirtualItem(const std::shared_ptr<CdsObject>& obj, bool
         throw_std_runtime_error("Not a file: {} - {}", path.c_str(), ec.message());
 
     auto pcdir = database->findObjectByPath(path);
-    if (pcdir == nullptr) {
+    if (!pcdir) {
         pcdir = createObjectFromFile(dirEnt, true, allow_fifo);
-        if (pcdir == nullptr) {
+        if (!pcdir) {
             throw_std_runtime_error("Could not add {}", path.c_str());
         }
         if (pcdir->isItem()) {
@@ -434,9 +421,9 @@ std::shared_ptr<CdsObject> ContentManager::createSingleItem(const fs::directory_
     auto obj = checkDatabase ? database->findObjectByPath(dirEnt.path()) : nullptr;
     bool isNew = false;
 
-    if (obj == nullptr) {
+    if (!obj) {
         obj = createObjectFromFile(dirEnt, followSymlinks);
-        if (obj == nullptr) { // object ignored
+        if (!obj) { // object ignored
             log_debug("Link to file or directory ignored: {}", dirEnt.path().c_str());
             return nullptr;
         }
@@ -447,9 +434,9 @@ std::shared_ptr<CdsObject> ContentManager::createSingleItem(const fs::directory_
     } else if (obj->isItem() && processExisting) {
         MetadataHandler::setMetadata(context, std::static_pointer_cast<CdsItem>(obj), dirEnt);
     }
-    if (obj->isItem() && layout != nullptr && (processExisting || isNew)) {
+    if (obj->isItem() && layout && (processExisting || isNew)) {
         try {
-            if (rootPath.empty() && (task != nullptr))
+            if (rootPath.empty() && (task))
                 rootPath = task->getRootPath();
 
             layout->processCdsObject(obj, rootPath);
@@ -458,7 +445,7 @@ std::shared_ptr<CdsObject> ContentManager::createSingleItem(const fs::directory_
             std::string content_type = getValueOrDefault(mimetype_contenttype_map, mimetype);
 
 #ifdef HAVE_JS
-            if ((playlist_parser_script != nullptr) && (content_type == CONTENT_TYPE_PLAYLIST))
+            if ((playlist_parser_script) && (content_type == CONTENT_TYPE_PLAYLIST))
                 playlist_parser_script->processPlaylistObject(obj, task);
 #else
             if (content_type == CONTENT_TYPE_PLAYLIST)
@@ -484,7 +471,7 @@ int ContentManager::_addFile(const fs::directory_entry& dirEnt, fs::path rootPat
 
     // checkDatabase, don't process existing
     auto obj = createSingleItem(dirEnt, rootPath, asSetting.followSymlinks, true, false, false, task);
-    if (obj == nullptr) // object ignored
+    if (!obj) // object ignored
         return INVALID_OBJECT_ID;
 
     if (asSetting.recursive && obj->isContainer()) {
@@ -492,7 +479,7 @@ int ContentManager::_addFile(const fs::directory_entry& dirEnt, fs::path rootPat
     }
 
     if (asSetting.rescanResource && obj->hasResource(CH_RESOURCE)) {
-        auto parentPath = dirEnt.path().parent_path().string();
+        std::string parentPath = dirEnt.path().parent_path();
         updateAttachedResources(asSetting.adir, obj->getLocation(), parentPath, true);
     }
 
@@ -541,8 +528,8 @@ void ContentManager::_removeObject(const std::shared_ptr<AutoscanDirectory>& adi
     bool parentRemoved = false;
     if (rescanResource) {
         auto obj = database->loadObject(objectID);
-        if (obj != nullptr && obj->hasResource(CH_RESOURCE)) {
-            auto parentPath = obj->getLocation().parent_path().string();
+        if (obj && obj->hasResource(CH_RESOURCE)) {
+            auto parentPath = obj->getLocation().parent_path();
             parentRemoved = updateAttachedResources(adir, obj->getLocation(), parentPath, all);
         }
     }
@@ -552,7 +539,7 @@ void ContentManager::_removeObject(const std::shared_ptr<AutoscanDirectory>& adi
 
     if (!parentRemoved) {
         auto changedContainers = database->removeObject(objectID, all);
-        if (changedContainers != nullptr) {
+        if (changedContainers) {
             session_manager->containerChangedUI(changedContainers->ui);
             update_manager->containersChanged(changedContainers->upnp);
         }
@@ -561,10 +548,10 @@ void ContentManager::_removeObject(const std::shared_ptr<AutoscanDirectory>& adi
     // loadAccounting();
 }
 
-int ContentManager::ensurePathExistence(fs::path path)
+int ContentManager::ensurePathExistence(const fs::path& path)
 {
     int updateID;
-    int containerID = database->ensurePathExistence(std::move(path), &updateID);
+    int containerID = database->ensurePathExistence(path, &updateID);
     if (updateID != INVALID_OBJECT_ID) {
         update_manager->containerChanged(updateID);
         session_manager->containerChangedUI(updateID);
@@ -572,11 +559,11 @@ int ContentManager::ensurePathExistence(fs::path path)
     return containerID;
 }
 
-void ContentManager::_rescanDirectory(std::shared_ptr<AutoscanDirectory>& adir, int containerID, const std::shared_ptr<GenericTask>& task)
+void ContentManager::_rescanDirectory(const std::shared_ptr<AutoscanDirectory>& adir, int containerID, const std::shared_ptr<GenericTask>& task)
 {
     log_debug("start");
 
-    if (adir == nullptr)
+    if (!adir)
         throw_std_runtime_error("ID valid but nullptr returned? this should never happen");
 
     fs::path rootpath = adir->getLocation();
@@ -635,17 +622,17 @@ void ContentManager::_rescanDirectory(std::shared_ptr<AutoscanDirectory>& adir,
 
     std::error_code ec;
     auto rootDir = fs::directory_entry(location, ec);
-    fs::directory_iterator dIter;
+    std::unique_ptr<fs::directory_iterator> dIter;
 
     if (!ec && rootDir.exists(ec) && rootDir.is_directory(ec)) {
-        dIter = fs::directory_iterator(location, ec);
+        dIter = std::make_unique<fs::directory_iterator>(location, ec);
         if (ec) {
             log_error("_rescanDirectory: Failed to iterate {}, {}", location.c_str(), ec.message());
         }
     } else {
         log_error("Could not open {}: {}", location.c_str(), ec.message());
     }
-    if (ec) {
+    if (ec || !dIter) {
         if (adir->persistent()) {
             removeObject(adir, containerID, false);
             if (location == adir->getLocation()) {
@@ -675,7 +662,7 @@ void ContentManager::_rescanDirectory(std::shared_ptr<AutoscanDirectory>& adir,
     auto list = database->getObjects(containerID, !asSetting.recursive);
 
     unsigned int thisTaskID;
-    if (task != nullptr) {
+    if (task) {
         thisTaskID = task->getID();
     } else {
         thisTaskID = 0;
@@ -685,15 +672,15 @@ void ContentManager::_rescanDirectory(std::shared_ptr<AutoscanDirectory>& adir,
     auto last_modified_new_max = last_modified_current_max;
     adir->setCurrentLMT(location, std::chrono::seconds::zero());
 
-    std::shared_ptr<CdsObject> firstObject = nullptr;
-    for (auto&& dirEnt : dIter) {
+    std::shared_ptr<CdsObject> firstObject;
+    for (auto&& dirEnt : *dIter) {
         auto&& newPath = dirEnt.path();
         auto&& name = newPath.filename().string();
         if (name[0] == '.' && !asSetting.hidden) {
             continue;
         }
 
-        if ((shutdownFlag) || ((task != nullptr) && !task->isValid()))
+        if ((shutdownFlag) || ((task) && !task->isValid()))
             break;
 
         // it is possible that someone hits remove while the container is being scanned
@@ -707,8 +694,7 @@ void ContentManager::_rescanDirectory(std::shared_ptr<AutoscanDirectory>& adir,
         if (!asSetting.followSymlinks && dirEnt.is_symlink()) {
             int objectID = database->findObjectIDByPath(newPath);
             if (objectID > 0) {
-                if (list != nullptr)
-                    list->erase(objectID);
+                list.erase(objectID);
                 removeObject(adir, objectID, false);
             }
             log_debug("link {} skipped", newPath.c_str());
@@ -724,8 +710,7 @@ void ContentManager::_rescanDirectory(std::shared_ptr<AutoscanDirectory>& adir,
         if (isRegularFile(dirEnt, ec)) {
             int objectID = database->findObjectIDByPath(newPath);
             if (objectID > 0) {
-                if (list != nullptr)
-                    list->erase(objectID);
+                list.erase(objectID);
 
                 // check modification time and update file if chagned
                 if (last_modified_current_max < lwt) {
@@ -759,8 +744,7 @@ void ContentManager::_rescanDirectory(std::shared_ptr<AutoscanDirectory>& adir,
                 last_modified_new_max = lwt;
             if (objectID > 0) {
                 log_debug("rescanSubDirectory {}", newPath.c_str());
-                if (list != nullptr)
-                    list->erase(objectID);
+                list.erase(objectID);
                 // add a task to rescan the directory that was found
                 rescanDirectory(adir, objectID, newPath, task->isCancellable());
             } else {
@@ -796,12 +780,12 @@ void ContentManager::_rescanDirectory(std::shared_ptr<AutoscanDirectory>& adir,
 
     finishScan(adir, location, parentContainer, last_modified_new_max, firstObject);
 
-    if ((shutdownFlag) || ((task != nullptr) && !task->isValid())) {
+    if ((shutdownFlag) || ((task) && !task->isValid())) {
         return;
     }
-    if (list != nullptr && !list->empty()) {
+    if (!list.empty()) {
         auto changedContainers = database->removeObjects(list);
-        if (changedContainers != nullptr) {
+        if (changedContainers) {
             session_manager->containerChangedUI(changedContainers->ui);
             update_manager->containersChanged(changedContainers->upnp);
         }
@@ -835,26 +819,26 @@ void ContentManager::addRecursive(std::shared_ptr<AutoscanDirectory>& adir, cons
 
     // abort loop if either:
     // no valid directory returned, server is about to shutdown, the task is there and was invalidated
-    if (task != nullptr) {
+    if (task) {
         log_debug("IS TASK VALID? [{}], task path: [{}]", task->isValid(), subDir.path().c_str());
     }
 #ifdef HAVE_INOTIFY
-    if (adir == nullptr) {
+    if (!adir) {
         for (size_t i = 0; i < autoscan_inotify->size(); i++) {
             log_debug("AutoDir {}", i);
-            std::shared_ptr<AutoscanDirectory> dir = autoscan_inotify->get(i);
-            if (dir != nullptr && startswith(dir->getLocation(), subDir.path()) && fs::is_directory(dir->getLocation())) {
-                adir = dir;
+            auto dir = autoscan_inotify->get(i);
+            if (dir && startswith(dir->getLocation().string(), subDir.path().string()) && fs::is_directory(dir->getLocation())) {
+                adir = std::move(dir);
             }
         }
     }
 #endif
-    if (adir == nullptr) {
+    if (!adir) {
         for (size_t i = 0; i < autoscan_timed->size(); i++) {
             log_debug("Timed AutoscanDir {}", i);
-            std::shared_ptr<AutoscanDirectory> dir = autoscan_timed->get(i);
-            if (dir != nullptr && startswith(dir->getLocation(), subDir.path()) && fs::is_directory(dir->getLocation())) {
-                adir = dir;
+            auto dir = autoscan_timed->get(i);
+            if (dir && startswith(dir->getLocation().string(), subDir.path().string()) && fs::is_directory(dir->getLocation())) {
+                adir = std::move(dir);
             }
         }
     }
@@ -866,28 +850,28 @@ void ContentManager::addRecursive(std::shared_ptr<AutoscanDirectory>& adir, cons
 
     auto last_modified_current_max = std::chrono::seconds::zero();
     auto last_modified_new_max = last_modified_current_max;
-    if (adir != nullptr) {
+    if (adir) {
         last_modified_current_max = adir->getPreviousLMT(subDir.path(), parentContainer);
         last_modified_new_max = last_modified_current_max;
         adir->setCurrentLMT(subDir.path(), std::chrono::seconds::zero());
     }
 
     bool firstChild = true;
-    std::shared_ptr<CdsObject> firstObject = nullptr;
+    std::shared_ptr<CdsObject> firstObject;
     for (auto&& subDirEnt : dIter) {
         auto&& newPath = subDirEnt.path();
         auto&& name = newPath.filename().string();
         if (name[0] == '.' && !hidden) {
             continue;
         }
-        if ((shutdownFlag) || ((task != nullptr) && !task->isValid()))
+        if ((shutdownFlag) || ((task) && !task->isValid()))
             break;
 
         if (config->getConfigFilename() == newPath)
             continue;
 
         // For the Web UI
-        if (task != nullptr) {
+        if (task) {
             task->setDescription(fmt::format("Importing: {}", newPath.string().c_str()));
         }
 
@@ -896,7 +880,7 @@ void ContentManager::addRecursive(std::shared_ptr<AutoscanDirectory>& adir, cons
             // check database if parent, process existing
             auto obj = createSingleItem(subDirEnt, rootPath, followSymlinks, (parentID > 0), true, firstChild, task);
 
-            if (obj != nullptr) {
+            if (obj) {
                 firstChild = false;
                 auto lwt = to_seconds(subDirEnt.last_write_time(ec));
                 if (last_modified_current_max < lwt) {
@@ -933,7 +917,7 @@ void ContentManager::addRecursive(std::shared_ptr<AutoscanDirectory>& adir, cons
 
 void ContentManager::finishScan(const std::shared_ptr<AutoscanDirectory>& adir, const fs::path& location, std::shared_ptr<CdsContainer>& parent, std::chrono::seconds lmt, const std::shared_ptr<CdsObject>& firstObject)
 {
-    if (adir != nullptr) {
+    if (adir) {
         adir->setCurrentLMT(location, lmt > std::chrono::seconds::zero() ? lmt : std::chrono::seconds(1));
         if (parent && lmt > std::chrono::seconds::zero()) {
             parent->setMTime(lmt);
@@ -1052,11 +1036,11 @@ void ContentManager::updateObject(int objectID, const std::map<std::string, std:
 {
     auto obj = database->loadObject(objectID);
     auto item = std::dynamic_pointer_cast<CdsItem>(obj);
-    if (item != nullptr) {
+    if (item) {
         updateCdsObject(item, parameters);
     } else {
         auto cont = std::dynamic_pointer_cast<CdsContainer>(obj);
-        if (cont != nullptr) {
+        if (cont) {
             updateCdsObject(cont, parameters);
         } else {
             updateCdsObject(obj, parameters);
@@ -1102,7 +1086,7 @@ std::pair<int, bool> ContentManager::addContainerTree(const std::vector<std::sha
 {
     std::string tree;
     int result = INVALID_OBJECT_ID;
-    std::vector<int> createdIds;
+    std::deque<int> createdIds;
     bool isNew = false;
 
     for (auto&& item : chain) {
@@ -1120,9 +1104,15 @@ std::pair<int, bool> ContentManager::addContainerTree(const std::vector<std::sha
             database->addContainerChain(tree, item->getClass(), INVALID_OBJECT_ID, &result, createdIds, item->getMetadata());
             auto container = std::dynamic_pointer_cast<CdsContainer>(database->loadObject(result));
             containerMap[tree] = container;
+            if (item->getMTime() > container->getMTime()) {
+                createdIds.push_back(result); // ensure update
+            }
             isNew = true;
         } else {
             result = containerMap[tree]->getID();
+            if (item->getMTime() > containerMap[tree]->getMTime()) {
+                createdIds.push_back(result);
+            }
         }
         assignFanArt({ containerMap[tree] }, item);
     }
@@ -1136,8 +1126,8 @@ std::pair<int, bool> ContentManager::addContainerTree(const std::vector<std::sha
 
 std::pair<int, bool> ContentManager::addContainerChain(const std::string& chain, const std::string& lastClass, int lastRefID, const std::shared_ptr<CdsObject>& origObj)
 {
-    std::map<std::string, std::string> lastMetadata = origObj != nullptr ? origObj->getMetadata() : std::map<std::string, std::string>();
-    std::vector<int> updateID;
+    auto lastMetadata = origObj ? origObj->getMetadata() : std::map<std::string, std::string> {};
+    std::deque<int> updateID;
     bool isNew = false;
 
     if (chain.empty())
@@ -1158,10 +1148,7 @@ std::pair<int, bool> ContentManager::addContainerChain(const std::string& chain,
 
     constexpr auto unwanted = std::array { M_DESCRIPTION, M_TITLE, M_TRACKNUMBER, M_ARTIST }; // not wanted for container!
     for (auto&& unw : unwanted) {
-        const auto itm = lastMetadata.find(MetadataHandler::getMetaFieldName(unw));
-        if (itm != lastMetadata.end()) {
-            lastMetadata.erase(itm);
-        }
+        lastMetadata.erase(MetadataHandler::getMetaFieldName(unw));
     }
     int containerID = INVALID_OBJECT_ID;
     std::vector<std::shared_ptr<CdsContainer>> containerList;
@@ -1172,12 +1159,12 @@ std::pair<int, bool> ContentManager::addContainerChain(const std::string& chain,
         for (auto&& contId : updateID) {
             auto container = std::dynamic_pointer_cast<CdsContainer>(database->loadObject(contId));
             containerMap[container->getLocation()] = container;
-            containerList.emplace_back(container);
+            containerList.push_back(std::move(container));
         }
         isNew = true;
     } else {
         containerID = containerMap[newChain]->getID();
-        containerList.emplace_back(containerMap[newChain]);
+        containerList.push_back(containerMap[newChain]);
     }
 
     if (!updateID.empty()) {
@@ -1191,14 +1178,20 @@ std::pair<int, bool> ContentManager::addContainerChain(const std::string& chain,
 
 void ContentManager::assignFanArt(const std::vector<std::shared_ptr<CdsContainer>>& containerList, const std::shared_ptr<CdsObject>& origObj)
 {
+    {
+        auto container = containerList.back();
+        if (origObj && container && origObj->getMTime() > container->getMTime()) {
+            container->setMTime(origObj->getMTime());
+            database->updateObject(container, nullptr);
+        }
+    }
     int count = 0;
     for (auto&& container : containerList) {
-        const std::vector<std::shared_ptr<CdsResource>>& resources = container->getResources();
+        auto resources = container->getResources();
         auto fanart = std::find_if(resources.begin(), resources.end(), [=](auto&& res) { return res->isMetaResource(ID3_ALBUM_ART); });
         if (fanart == resources.end()) {
             MetadataHandler::createHandler(context, CH_CONTAINERART)->fillMetadata(container);
-            int containerChanged = INVALID_OBJECT_ID;
-            database->updateObject(container, &containerChanged);
+            database->updateObject(container, nullptr);
             fanart = std::find_if(resources.begin(), resources.end(), [=](auto&& res) { return res->isMetaResource(ID3_ALBUM_ART); });
         }
         auto location = container->getLocation().string();
@@ -1215,9 +1208,9 @@ void ContentManager::assignFanArt(const std::vector<std::shared_ptr<CdsContainer
             }
         }
 
-        if (origObj != nullptr) {
+        if (origObj) {
             if (fanart == resources.end() && (origObj->isContainer() || (count < config->getIntOption(CFG_IMPORT_RESOURCES_CONTAINERART_PARENTCOUNT) && container->getParentID() != CDS_ID_ROOT && std::count(location.begin(), location.end(), '/') > config->getIntOption(CFG_IMPORT_RESOURCES_CONTAINERART_MINDEPTH)))) {
-                const std::vector<std::shared_ptr<CdsResource>>& origResources = origObj->getResources();
+                auto origResources = origObj->getResources();
                 fanart = std::find_if(origResources.begin(), origResources.end(), [=](auto&& res) { return res->isMetaResource(ID3_ALBUM_ART); });
                 if (fanart != origResources.end()) {
                     if ((*fanart)->getAttribute(R_RESOURCE_FILE).empty()) {
@@ -1226,8 +1219,7 @@ void ContentManager::assignFanArt(const std::vector<std::shared_ptr<CdsContainer
                     }
                     container->addResource(*fanart);
                 }
-                int containerChanged = INVALID_OBJECT_ID;
-                database->updateObject(container, &containerChanged);
+                database->updateObject(container, nullptr);
             }
         }
         count++;
@@ -1300,7 +1292,7 @@ std::shared_ptr<CdsObject> ContentManager::createObjectFromFile(const fs::direct
         auto title = dirEnt.path().filename().string();
         if (config->getBoolOption(CFG_IMPORT_READABLE_NAMES) && upnp_class != UPNP_CLASS_ITEM) {
             title = dirEnt.path().stem().string();
-            title = replaceAllString(title, "_", " ");
+            std::replace(title.begin(), title.end(), '_', ' ');
         }
         obj->setTitle(f2i->convert(title));
 
@@ -1329,9 +1321,9 @@ std::shared_ptr<CdsObject> ContentManager::createObjectFromFile(const fs::direct
 
 void ContentManager::initLayout()
 {
-    if (layout == nullptr) {
+    if (!layout) {
         auto lock = threadRunner->lockGuard("initLayout");
-        if (layout == nullptr) {
+        if (!layout) {
             std::string layout_type = config->getOption(CFG_IMPORT_SCRIPTING_VIRTUAL_LAYOUT_TYPE);
             auto self = shared_from_this();
             try {
@@ -1357,7 +1349,7 @@ void ContentManager::initLayout()
 #ifdef HAVE_JS
 void ContentManager::initJS()
 {
-    if (playlist_parser_script == nullptr) {
+    if (!playlist_parser_script) {
         auto self = shared_from_this();
         playlist_parser_script = std::make_unique<PlaylistParserScript>(self, scripting_runtime);
     }
@@ -1406,7 +1398,7 @@ void ContentManager::threadProc()
             taskQueue2.pop_front();
         }
 
-        if (task == nullptr) {
+        if (!task) {
             working = false;
             /* if nothing to do, sleep until awakened */
             threadRunner->wait(lock);
@@ -1487,7 +1479,7 @@ int ContentManager::addFileInternal(
 void ContentManager::fetchOnlineContent(service_type_t serviceType, bool lowPriority, bool cancellable, bool unscheduled_refresh)
 {
     auto service = online_services->getService(serviceType);
-    if (service == nullptr) {
+    if (!service) {
         log_debug("No surch service! {}", serviceType);
         throw_std_runtime_error("Service not found");
     }
@@ -1513,9 +1505,9 @@ void ContentManager::cleanupOnlineServiceObjects(const std::shared_ptr<OnlineSer
         std::chrono::seconds last = {};
         std::string temp;
 
-        for (int object_id : *ids) {
+        for (int object_id : ids) {
             auto obj = database->loadObject(object_id);
-            if (obj == nullptr)
+            if (!obj)
                 continue;
 
             temp = obj->getAuxData(ONLINE_SERVICE_LAST_UPDATE);
@@ -1539,7 +1531,7 @@ void ContentManager::invalidateAddTask(const std::shared_ptr<GenericTask>& t, co
     if (t->getType() == AddFile) {
         auto add_task = std::static_pointer_cast<CMAddFileTask>(t);
         log_debug("comparing, task path: {}, remove path: {}", add_task->getPath().c_str(), path.c_str());
-        if (startswith(add_task->getPath(), path)) {
+        if (startswith(add_task->getPath().string(), path.string())) {
             log_debug("Invalidating task with path {}", add_task->getPath().c_str());
             add_task->invalidate();
         }
@@ -1551,7 +1543,7 @@ void ContentManager::invalidateTask(unsigned int taskID, task_owner_t taskOwner)
     if (taskOwner == ContentManagerTask) {
         auto lock = threadRunner->lockGuard("invalidateTask");
         auto tc = getCurrentTask();
-        if (tc != nullptr) {
+        if (tc) {
             if ((tc->getID() == taskID) || (tc->getParentID() == taskID)) {
                 tc->invalidate();
             }
@@ -1610,7 +1602,7 @@ void ContentManager::removeObject(const std::shared_ptr<AutoscanDirectory>& adir
             if (config->getBoolOption(CFG_IMPORT_AUTOSCAN_USE_INOTIFY)) {
                 rm_list = autoscan_inotify->removeIfSubdir(path);
                 for (size_t i = 0; i < rm_list->size(); i++) {
-                    std::shared_ptr<AutoscanDirectory> dir = rm_list->get(i);
+                    auto dir = rm_list->get(i);
                     inotify->unmonitor(dir);
                 }
             }
@@ -1629,7 +1621,7 @@ void ContentManager::removeObject(const std::shared_ptr<AutoscanDirectory>& adir
             }
 
             auto t = getCurrentTask();
-            if (t != nullptr) {
+            if (t) {
                 invalidateAddTask(t, path);
             }
         }
@@ -1677,9 +1669,9 @@ std::shared_ptr<AutoscanDirectory> ContentManager::getAutoscanDirectory(int obje
 std::shared_ptr<AutoscanDirectory> ContentManager::getAutoscanDirectory(const fs::path& location) const
 {
     // \todo change this when more scanmodes become available
-    std::shared_ptr<AutoscanDirectory> adir = autoscan_timed->get(location);
+    auto adir = autoscan_timed->get(location);
 #if HAVE_INOTIFY
-    if (adir == nullptr)
+    if (!adir)
         adir = autoscan_inotify->get(location);
 #endif
     return adir;
@@ -1700,7 +1692,7 @@ std::vector<std::shared_ptr<AutoscanDirectory>> ContentManager::getAutoscanDirec
 
 void ContentManager::removeAutoscanDirectory(const std::shared_ptr<AutoscanDirectory>& adir)
 {
-    if (adir == nullptr)
+    if (!adir)
         throw_std_runtime_error("can not remove autoscan directory - was not an autoscan");
 
     adir->setTaskCount(-1);
@@ -1750,24 +1742,24 @@ void ContentManager::setAutoscanDirectory(const std::shared_ptr<AutoscanDirector
     original = autoscan_timed->getByObjectID(dir->getObjectID());
 #ifdef HAVE_INOTIFY
     if (config->getBoolOption(CFG_IMPORT_AUTOSCAN_USE_INOTIFY)) {
-        if (original == nullptr)
+        if (!original)
             original = autoscan_inotify->getByObjectID(dir->getObjectID());
     }
 #endif
 
-    if (original != nullptr)
+    if (original)
         dir->setDatabaseID(original->getDatabaseID());
 
     database->checkOverlappingAutoscans(dir);
 
     // adding a new autoscan directory
-    if (original == nullptr) {
+    if (!original) {
         if (dir->getObjectID() == CDS_ID_FS_ROOT)
             dir->setLocation(FS_ROOT_DIRECTORY);
         else {
             log_debug("objectID: {}", dir->getObjectID());
             auto obj = database->loadObject(dir->getObjectID());
-            if (obj == nullptr || !obj->isContainer() || obj->isVirtual())
+            if (!obj || !obj->isContainer() || obj->isVirtual())
                 throw_std_runtime_error("tried to remove an illegal object (id) from the list of the autoscan directories");
 
             log_debug("location: {}", obj->getLocation().c_str());
@@ -1871,29 +1863,29 @@ void ContentManager::triggerPlayHook(const std::shared_ptr<CdsObject>& obj)
 }
 
 CMAddFileTask::CMAddFileTask(std::shared_ptr<ContentManager> content,
-    fs::directory_entry dirEnt, fs::path rootpath, AutoScanSetting& asSetting, bool cancellable)
+    fs::directory_entry dirEnt, fs::path rootpath, AutoScanSetting asSetting, bool cancellable)
     : GenericTask(ContentManagerTask)
     , content(std::move(content))
     , dirEnt(std::move(dirEnt))
     , rootpath(std::move(rootpath))
-    , asSetting(asSetting)
+    , asSetting(std::move(asSetting))
 {
     this->cancellable = cancellable;
     this->taskType = AddFile;
-    if (this->asSetting.adir != nullptr)
+    if (this->asSetting.adir)
         this->asSetting.adir->incTaskCount();
 }
 
-fs::path CMAddFileTask::getPath() { return dirEnt.path(); }
+fs::path CMAddFileTask::getPath() const { return dirEnt.path(); }
 
-fs::path CMAddFileTask::getRootPath() { return rootpath; }
+fs::path CMAddFileTask::getRootPath() const { return rootpath; }
 
 void CMAddFileTask::run()
 {
     log_debug("running add file task with path {} recursive: {}", dirEnt.path().c_str(), asSetting.recursive);
     auto self = shared_from_this();
     content->_addFile(dirEnt, rootpath, asSetting, self);
-    if (asSetting.adir != nullptr) {
+    if (asSetting.adir) {
         asSetting.adir->decTaskCount();
         if (asSetting.adir->updateLMT()) {
             log_debug("CMAddFileTask::run: Updating last_modified for autoscan directory {}", asSetting.adir->getLocation().c_str());
@@ -1912,7 +1904,7 @@ CMRemoveObjectTask::CMRemoveObjectTask(std::shared_ptr<ContentManager> content,
     , rescanResource(rescanResource)
 {
     this->taskType = RemoveObject;
-    cancellable = false;
+    this->cancellable = false;
 }
 
 void CMRemoveObjectTask::run()
@@ -1933,7 +1925,7 @@ CMRescanDirectoryTask::CMRescanDirectoryTask(std::shared_ptr<ContentManager> con
 
 void CMRescanDirectoryTask::run()
 {
-    if (adir == nullptr)
+    if (!adir)
         return;
 
     auto self = shared_from_this();
@@ -1963,13 +1955,12 @@ CMFetchOnlineContentTask::CMFetchOnlineContentTask(std::shared_ptr<ContentManage
 
 void CMFetchOnlineContentTask::run()
 {
-    if (this->service == nullptr) {
+    if (!this->service) {
         log_debug("Received invalid service!");
         return;
     }
     try {
-        std::shared_ptr<GenericTask> t(
-            new TPFetchOnlineContentTask(content, task_processor, timer, service, layout, cancellable, unscheduled_refresh));
+        auto t = std::static_pointer_cast<GenericTask>(std::make_shared<TPFetchOnlineContentTask>(content, task_processor, timer, service, layout, cancellable, unscheduled_refresh));
         task_processor->addTask(t);
     } catch (const std::runtime_error& ex) {
         log_error("{}", ex.what());
