@@ -87,9 +87,9 @@ protected:
 
 public:
     CMAddFileTask(std::shared_ptr<ContentManager> content,
-        fs::directory_entry dirEnt, fs::path rootpath, AutoScanSetting& asSetting, bool cancellable = true);
-    fs::path getPath();
-    fs::path getRootPath();
+        fs::directory_entry dirEnt, fs::path rootpath, AutoScanSetting asSetting, bool cancellable = true);
+    fs::path getPath() const;
+    fs::path getRootPath() const;
     void run() override;
 };
 
@@ -189,7 +189,7 @@ public:
     int addFile(const fs::directory_entry& dirEnt, const fs::path& rootpath, AutoScanSetting& asSetting,
         bool async = true, bool lowPriority = false, bool cancellable = true);
 
-    int ensurePathExistence(fs::path path);
+    int ensurePathExistence(const fs::path& path);
     void removeObject(const std::shared_ptr<AutoscanDirectory>& adir, int objectID, bool rescanResource, bool async = true, bool all = false);
 
     /// \brief Updates an object in the database using the given parameters.
@@ -350,7 +350,7 @@ protected:
 
     void _removeObject(const std::shared_ptr<AutoscanDirectory>& adir, int objectID, bool rescanResource, bool all);
 
-    void _rescanDirectory(std::shared_ptr<AutoscanDirectory>& adir, int containerID, const std::shared_ptr<GenericTask>& task = nullptr);
+    void _rescanDirectory(const std::shared_ptr<AutoscanDirectory>& adir, int containerID, const std::shared_ptr<GenericTask>& task = nullptr);
     /* for recursive addition */
     void addRecursive(std::shared_ptr<AutoscanDirectory>& adir, const fs::directory_entry& subDir, bool followSymlinks, bool hidden, const std::shared_ptr<CMAddFileTask>& task);
     std::shared_ptr<CdsObject> createSingleItem(const fs::directory_entry& dirEnt, fs::path& rootPath, bool followSymlinks, bool checkDatabase, bool processExisting, bool firstChild, const std::shared_ptr<CMAddFileTask>& task);
@@ -373,7 +373,7 @@ protected:
     std::unique_ptr<PlaylistParserScript> playlist_parser_script;
 #endif
 
-    bool layout_enabled;
+    bool layout_enabled {};
 
     static void* staticThreadProc(void* arg);
     void threadProc();
@@ -382,14 +382,14 @@ protected:
 
     std::unique_ptr<ThreadRunner<std::condition_variable_any, std::recursive_mutex>> threadRunner;
 
-    bool working;
-    bool shutdownFlag;
+    bool working {};
+    bool shutdownFlag {};
 
     std::deque<std::shared_ptr<GenericTask>> taskQueue1; // priority 1
     std::deque<std::shared_ptr<GenericTask>> taskQueue2; // priority 2
     std::shared_ptr<GenericTask> currentTask;
 
-    unsigned int taskID;
+    unsigned int taskID { 1 };
 
     friend void CMAddFileTask::run();
     friend void CMRemoveObjectTask::run();
