@@ -249,11 +249,10 @@ void BuiltinLayout::addAudio(const std::shared_ptr<CdsObject>& obj, const fs::pa
     if (obj->getID() != INVALID_OBJECT_ID) {
         obj->setRefID(obj->getID());
         add(obj, id);
-    }
-    // the object is not yet in the database (probably we got it from a
-    // playlist script, so we set the ref id after adding - it will be used
-    // for all consequent virtual objects
-    else {
+    } else {
+        // the object is not yet in the database (probably we got it from a
+        // playlist script, so we set the ref id after adding - it will be used
+        // for all consequent virtual objects
         add(obj, id);
         obj->setRefID(obj->getID());
     }
@@ -389,8 +388,8 @@ void BuiltinLayout::addATrailers(const std::shared_ptr<CdsObject>& obj)
 
 BuiltinLayout::BuiltinLayout(std::shared_ptr<ContentManager> content)
     : Layout(std::move(content))
+    , genreMap(config->getDictionaryOption(CFG_IMPORT_SCRIPTING_IMPORT_GENRE_MAP))
 {
-    genreMap = config->getDictionaryOption(CFG_IMPORT_SCRIPTING_IMPORT_GENRE_MAP);
 #ifdef ENABLE_PROFILING
     PROF_INIT_GLOBAL(layout_profiling, "builtin layout");
 #endif
@@ -406,7 +405,7 @@ std::string BuiltinLayout::mapGenre(const std::string& genre)
     return genre;
 }
 
-void BuiltinLayout::processCdsObject(std::shared_ptr<CdsObject> obj, fs::path rootpath)
+void BuiltinLayout::processCdsObject(const std::shared_ptr<CdsObject>& obj, const fs::path& rootpath)
 {
     log_debug("Process CDS Object: {}", obj->getTitle().c_str());
 #ifdef ENABLE_PROFILING
