@@ -34,13 +34,9 @@
 
 #include <memory>
 
+#include "content/scripting/import_script.h"
 #include "layout.h"
 
-// forward declaration
-class ContentManager;
-class ImportScript;
-class ScriptingRuntime;
-
 class JSLayout : public Layout {
 protected:
     std::shared_ptr<ScriptingRuntime> runtime;
@@ -49,12 +45,8 @@ protected:
 public:
     JSLayout(const std::shared_ptr<ContentManager>& content,
         const std::shared_ptr<ScriptingRuntime>& runtime);
-    ~JSLayout() override;
 
-    JSLayout(const JSLayout&) = delete;
-    JSLayout& operator=(const JSLayout&) = delete;
-
-    void processCdsObject(std::shared_ptr<CdsObject> obj, fs::path rootpath) override;
+    void processCdsObject(const std::shared_ptr<CdsObject>& obj, const fs::path& rootpath) override;
 };
 
 #endif // __JS_LAYOUT_H__
