@@ -79,7 +79,7 @@ public:
 
     /// \brief Retrieves user specified content from the service and adds
     /// the items to the database.
-    bool refreshServiceData(std::shared_ptr<Layout> layout) override;
+    bool refreshServiceData(const std::shared_ptr<Layout>& layout) override;
 
     /// \brief Get the human readable name for the service
     std::string getServiceName() const override;
