@@ -44,7 +44,7 @@ static constexpr auto service_prefixes = std::array { '\0', 'Y', 'S', 'W', 'T',
 
 void OnlineServiceList::registerService(const std::shared_ptr<OnlineService>& service)
 {
-    if (service == nullptr)
+    if (!service)
         return;
 
     if (service->getServiceType() >= OS_Max) {
@@ -54,7 +54,7 @@ void OnlineServiceList::registerService(const std::shared_ptr<OnlineService>& se
     service_list.at(service->getServiceType()) = service;
 }
 
-std::shared_ptr<OnlineService> OnlineServiceList::getService(service_type_t service)
+std::shared_ptr<OnlineService> OnlineServiceList::getService(service_type_t service) const
 {
     if (service > OS_Max)
         return nullptr;
@@ -66,10 +66,7 @@ OnlineService::OnlineService(std::shared_ptr<ContentManager> content)
     : config(content->getContext()->getConfig())
     , database(content->getContext()->getDatabase())
     , content(std::move(content))
-    , taskCount(0)
 {
-    refresh_interval = {};
-    purge_interval = {};
 }
 
 char OnlineService::getDatabasePrefix(service_type_t service)
@@ -80,7 +77,7 @@ char OnlineService::getDatabasePrefix(service_type_t service)
     return service_prefixes.at(service);
 }
 
-char OnlineService::getDatabasePrefix()
+char OnlineService::getDatabasePrefix() const
 {
     return getDatabasePrefix(getServiceType());
 }
