@@ -77,16 +77,16 @@ public:
     /// to get. Another call to this function after it returned true will
     /// reset the internal counters and thus make it fetch the content from
     /// the beginning.
-    virtual bool refreshServiceData(std::shared_ptr<Layout> layout) = 0;
+    virtual bool refreshServiceData(const std::shared_ptr<Layout>& layout) = 0;
 
     /// \brief Returns the service type
-    virtual service_type_t getServiceType() = 0;
+    virtual service_type_t getServiceType() const = 0;
 
     /// \brief Returns the service name
     virtual std::string getServiceName() const = 0;
 
     /// \brief Get the database service prefix for a particular service
-    char getDatabasePrefix();
+    char getDatabasePrefix() const;
 
     /// \brief Get the database prefix for a given service type
     static char getDatabasePrefix(service_type_t service);
@@ -108,9 +108,9 @@ public:
     void setTaskCount(int taskCount) { this->taskCount = taskCount; }
 
     /// Parameter that can be used by timerNotify
-    void setTimerParameter(std::shared_ptr<Timer::Parameter> param)
+    void setTimerParameter(const std::shared_ptr<Timer::Parameter>& param)
     {
-        timer_parameter = std::move(param);
+        timer_parameter = param;
     }
 
     std::shared_ptr<Timer::Parameter> getTimerParameter() const { return timer_parameter; }
@@ -132,21 +132,19 @@ protected:
     std::shared_ptr<Database> database;
     std::shared_ptr<ContentManager> content;
 
-    int taskCount;
-    std::chrono::seconds refresh_interval;
-    std::chrono::seconds purge_interval;
+    int taskCount {};
+    std::chrono::seconds refresh_interval {};
+    std::chrono::seconds purge_interval {};
     std::shared_ptr<Timer::Parameter> timer_parameter;
 };
 
 class OnlineServiceList {
 public:
-    OnlineServiceList() = default;
-
     /// \brief Adds a service to the service list.
     void registerService(const std::shared_ptr<OnlineService>& service);
 
     /// \brief Retrieves a service given by the service ID from the list
-    std::shared_ptr<OnlineService> getService(service_type_t service);
+    std::shared_ptr<OnlineService> getService(service_type_t service) const;
 
 protected:
     std::vector<std::shared_ptr<OnlineService>> service_list { OS_Max };
