@@ -33,22 +33,16 @@
 #include "sopcast_content_handler.h" // API
 
 #include "cds_objects.h"
-#include "config/config_manager.h"
-#include "curl_online_service.h"
+#include "config/config.h"
 #include "metadata/metadata_handler.h"
 #include "util/tools.h"
 
-SopCastContentHandler::SopCastContentHandler(const std::shared_ptr<Context>& context)
-    : CurlContentHandler(context)
-{
-}
-
-void SopCastContentHandler::setServiceContent(std::unique_ptr<pugi::xml_document>& service)
+void SopCastContentHandler::setServiceContent(std::unique_ptr<pugi::xml_document> service)
 {
     service_xml = std::move(service);
     auto root = service_xml->document_element();
 
-    if (std::string(root.name()) != "channels")
+    if (std::string_view(root.name()) != "channels")
         throw_std_runtime_error("Invalid XML for SopCast service received");
 
     group_it = root.begin();
@@ -75,13 +69,13 @@ std::shared_ptr<CdsObject> SopCastContentHandler::getNextObject()
         }
         skipGroup = true;
 
-        if (group == nullptr)
+        if (!group)
             continue;
 
         if (group.type() != pugi::node_element)
             continue;
 
-        if (std::string(group.name()) != "group")
+        if (std::string_view(group.name()) != "group")
             continue;
 
         // we know that we have a group
@@ -98,20 +92,19 @@ std::shared_ptr<CdsObject> SopCastContentHandler::getNextObject()
             auto channel = *channel_it;
             ++channel_it;
 
-            if (channel == nullptr)
+            if (!channel)
                 continue;
 
             if (channel.type() != pugi::node_element)
                 continue;
 
-            if (std::string(channel.name()) != "channel")
+            if (std::string_view(channel.name()) != "channel")
                 continue;
 
             // we know that we have a channel
             auto item = getObject(groupName, channel);
-            if (item != nullptr)
+            if (item)
                 return item;
-
         } // for channel
     } // for group
 
@@ -142,27 +135,19 @@ std::shared_ptr<CdsObject> SopCastContentHandler::getObject(const std::string& g
         return nullptr;
     }
 
-    // I wish they had a mimetype setting
-    //auto mappings = config->getDictionaryOption(CFG_IMPORT_MAPPINGS_EXTENSION_TO_MIMETYPE_LIST);
-    //std::string mt = getValueOrDefault(mappings, temp);
-    std::string mt;
-    // map was empty, we have to do construct the mimetype ourselves
-    if (temp == "wmv")
-        mt = "video/sopcast-x-ms-wmv";
-    else if (temp == "mp3")
-        mt = "audio/sopcast-mpeg";
-    else if (temp == "wma")
-        mt = "audio/sopcast-x-ms-wma";
-    else {
+    // use mimetype setting
+    auto mappings = config->getDictionaryOption(CFG_IMPORT_SOPCAST_MIMETYE_LIST);
+    std::string mt = getValueOrDefault(mappings, temp, "*");
+    if (mt == "*") {
+        mt = getValueOrDefault(mappings, "*");
         log_warning("Could not determine mimetype for SopCast channel (stream_type: {})", temp.c_str());
-        mt = "application/sopcast-stream";
     }
 
     resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo(mt, SOPCAST_PROTOCOL));
     item->setMimeType(mt);
 
     auto tmp_el = channel.child("sop_address");
-    if (tmp_el == nullptr) {
+    if (!tmp_el) {
         log_warning("Failed to retrieve SopCast channel URL");
         return nullptr;
     }
@@ -175,7 +160,7 @@ std::shared_ptr<CdsObject> SopCastContentHandler::getObject(const std::string& g
     item->setURL(temp);
 
     tmp_el = channel.child("name");
-    if (tmp_el == nullptr) {
+    if (!tmp_el) {
         log_warning("Failed to retrieve SopCast channel name");
         return nullptr;
     }
@@ -187,7 +172,7 @@ std::shared_ptr<CdsObject> SopCastContentHandler::getObject(const std::string& g
         item->setTitle("Unknown");
 
     tmp_el = channel.child("region");
-    if (tmp_el != nullptr) {
+    if (tmp_el) {
         temp = tmp_el.attribute("en").as_string();
         if (!temp.empty())
             item->setMetadata(M_REGION, temp);
