@@ -26,7 +26,6 @@ public:
     }
 
     void run();
-    virtual ~TaskProcessor() = default;
     void shutdown();
 
     void addTask(const std::shared_ptr<GenericTask>& task);
@@ -38,8 +37,8 @@ protected:
     std::shared_ptr<Config> config;
     std::unique_ptr<StdThreadRunner> threadRunner;
 
-    bool shutdownFlag { false };
-    bool working { false };
+    bool shutdownFlag {};
+    bool working {};
     unsigned int taskID { 1 };
     std::deque<std::shared_ptr<GenericTask>> taskQueue;
     std::shared_ptr<GenericTask> currentTask;
