@@ -48,7 +48,7 @@ static duk_ret_t
 js_readln(duk_context* ctx)
 {
     auto self = dynamic_cast<PlaylistParserScript*>(Script::getContextScript(ctx));
-    if (self == nullptr) {
+    if (!self) {
         return 0;
     }
 
@@ -72,6 +72,9 @@ static duk_ret_t
 js_getCdsObject(duk_context* ctx)
 {
     auto self = dynamic_cast<PlaylistParserScript*>(Script::getContextScript(ctx));
+    if (!self) {
+        return 0;
+    }
 
     if (!duk_is_string(ctx, 0))
         return 0;
@@ -84,7 +87,7 @@ js_getCdsObject(duk_context* ctx)
 
     auto database = self->getDatabase();
     auto obj = database->findObjectByPath(path);
-    if (obj == nullptr) {
+    if (!obj) {
         auto cm = self->getContent();
         std::error_code ec;
         auto dirEnt = fs::directory_entry(path, ec);
@@ -93,7 +96,7 @@ js_getCdsObject(duk_context* ctx)
         } else {
             log_error("Failed to read {}: {}", path.c_str(), ec.message());
         }
-        if (obj == nullptr) { // object ignored
+        if (!obj) { // object ignored
             return 0;
         }
     }
@@ -106,9 +109,6 @@ js_getCdsObject(duk_context* ctx)
 PlaylistParserScript::PlaylistParserScript(std::shared_ptr<ContentManager> content,
     const std::shared_ptr<ScriptingRuntime>& runtime)
     : Script(std::move(content), runtime, "playlist")
-    , currentHandle(nullptr)
-    , currentObjectID(INVALID_OBJECT_ID)
-    , currentLine(nullptr)
 {
     try {
         ScriptingRuntime::AutoLock lock(runtime->getMutex());
@@ -128,12 +128,12 @@ std::string PlaylistParserScript::readln()
     if (!currentHandle)
         throw_std_runtime_error("Readline not yet setup for use");
 
-    if ((currentTask != nullptr) && (!currentTask->isValid()))
-        return "";
+    if ((currentTask) && (!currentTask->isValid()))
+        return {};
 
     while (true) {
-        if (fgets(currentLine, ONE_TEXTLINE_BYTES, currentHandle) == nullptr)
-            return "";
+        if (!fgets(currentLine, ONE_TEXTLINE_BYTES, currentHandle))
+            return {};
 
         ret = trimString(currentLine);
         if (!ret.empty())
@@ -143,7 +143,7 @@ std::string PlaylistParserScript::readln()
 
 void PlaylistParserScript::processPlaylistObject(const std::shared_ptr<CdsObject>& obj, std::shared_ptr<GenericTask> task)
 {
-    if ((currentObjectID != INVALID_OBJECT_ID) || (currentHandle != nullptr) || (currentLine != nullptr)) {
+    if ((currentObjectID != INVALID_OBJECT_ID) || (currentHandle) || (currentLine)) {
         throw_std_runtime_error("recursion not allowed");
     }
 
