@@ -54,36 +54,34 @@
 #include "content/onlineservice/atrailers_content_handler.h"
 #endif
 
-static constexpr std::array<duk_function_list_entry, 9> js_global_functions = { {
-    { "print", js_print, DUK_VARARGS },
-    { "addCdsObject", js_addCdsObject, 3 },
-    { "addContainerTree", js_addContainerTree, 1 },
-    { "copyObject", js_copyObject, 1 },
-    { "f2i", js_f2i, 1 },
-    { "m2i", js_m2i, 1 },
-    { "p2i", js_p2i, 1 },
-    { "j2i", js_j2i, 1 },
-    { nullptr, nullptr, 0 },
-} };
+static constexpr auto js_global_functions = std::array {
+    duk_function_list_entry { "print", js_print, DUK_VARARGS },
+    duk_function_list_entry { "addCdsObject", js_addCdsObject, 3 },
+    duk_function_list_entry { "addContainerTree", js_addContainerTree, 1 },
+    duk_function_list_entry { "copyObject", js_copyObject, 1 },
+    duk_function_list_entry { "f2i", js_f2i, 1 },
+    duk_function_list_entry { "m2i", js_m2i, 1 },
+    duk_function_list_entry { "p2i", js_p2i, 1 },
+    duk_function_list_entry { "j2i", js_j2i, 1 },
+    duk_function_list_entry { nullptr, nullptr, 0 },
+};
 
-std::string Script::getProperty(const std::string& name)
+std::string Script::getProperty(const std::string& name) const
 {
-    std::string ret;
     if (!duk_is_object_coercible(ctx, -1))
-        return "";
+        return {};
     duk_get_prop_string(ctx, -1, name.c_str());
     if (duk_is_null_or_undefined(ctx, -1) || !duk_to_string(ctx, -1)) {
         duk_pop(ctx);
-        return "";
+        return {};
     }
-    ret = duk_get_string(ctx, -1);
+    auto ret = duk_get_string(ctx, -1);
     duk_pop(ctx);
     return ret;
 }
 
-int Script::getBoolProperty(const std::string& name)
+int Script::getBoolProperty(const std::string& name) const
 {
-    int ret;
     if (!duk_is_object_coercible(ctx, -1))
         return -1;
     duk_get_prop_string(ctx, -1, name.c_str());
@@ -91,14 +89,13 @@ int Script::getBoolProperty(const std::string& name)
         duk_pop(ctx);
         return -1;
     }
-    ret = duk_to_boolean(ctx, -1);
+    auto ret = duk_to_boolean(ctx, -1);
     duk_pop(ctx);
     return ret;
 }
 
-int Script::getIntProperty(const std::string& name, int def)
+int Script::getIntProperty(const std::string& name, int def) const
 {
-    int ret;
     if (!duk_is_object_coercible(ctx, -1))
         return def;
     duk_get_prop_string(ctx, -1, name.c_str());
@@ -106,19 +103,19 @@ int Script::getIntProperty(const std::string& name, int def)
         duk_pop(ctx);
         return def;
     }
-    ret = duk_to_int32(ctx, -1);
+    auto ret = duk_to_int32(ctx, -1);
     duk_pop(ctx);
     return ret;
 }
 
-std::vector<std::string> Script::getPropertyNames()
+std::vector<std::string> Script::getPropertyNames() const
 {
     std::vector<std::string> keys;
     duk_enum(ctx, -1, 0);
     while (duk_next(ctx, -1 /*enum_idx*/, 0 /*get_value*/)) {
         /* [ ... enum key ] */
-        auto sym = duk_get_string(ctx, -1);
-        keys.emplace_back(sym);
+        auto sym = std::string(duk_get_string(ctx, -1));
+        keys.push_back(std::move(sym));
         duk_pop(ctx); /* pop_key */
     }
     duk_pop(ctx); // duk_enum
@@ -141,8 +138,7 @@ void Script::setIntProperty(const std::string& name, int value)
 
 Script::Script(std::shared_ptr<ContentManager> content,
     const std::shared_ptr<ScriptingRuntime>& runtime, const std::string& name)
-    : gc_counter(0)
-    , config(content->getContext()->getConfig())
+    : config(content->getContext()->getConfig())
     , database(content->getContext()->getDatabase())
     , content(std::move(content))
     , runtime(runtime)
@@ -229,9 +225,9 @@ Script::Script(std::shared_ptr<ContentManager> content,
     }
 
     duk_push_object(ctx); // config
-    for (int i = 0; i < int(CFG_MAX); i++) {
-        auto scs = ConfigDefinition::findConfigSetup(config_option_t(i), true);
-        if (scs == nullptr)
+    for (auto&& i : ConfigOptionIterator()) {
+        auto scs = ConfigDefinition::findConfigSetup(i, true);
+        if (!scs)
             continue;
         auto value = scs->getCurrentValue();
         if (!value.empty()) {
@@ -277,9 +273,9 @@ Script::Script(std::shared_ptr<ContentManager> content,
             setIntProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_TASKCOUNT), adir->getTaskCount());
             setProperty(ConfigDefinition::removeAttribute(ATTR_AUTOSCAN_DIRECTORY_LMT), fmt::format("{:%Y-%m-%d %H:%M:%S}", fmt::localtime(adir->getPreviousLMT().count())));
 
-            duk_put_prop_string(ctx, -2, fmt::format("{}", adir->getScanID()).c_str());
+            duk_put_prop_string(ctx, -2, fmt::to_string(adir->getScanID()).c_str());
         }
-        autoscanItemPath = ascs->getItemPath(-2);
+        autoscanItemPath = ascs->getItemPath(ITEM_PATH_PREFIX); // prefix
     }
     duk_put_prop_string(ctx, -2, autoscanItemPath.c_str()); // autoscan
 
@@ -323,7 +319,7 @@ Script* Script::getContextScript(duk_context* ctx)
     duk_get_prop_string(ctx, -1, "this");
     auto self = static_cast<Script*>(duk_get_pointer(ctx, -1));
     duk_pop_2(ctx);
-    if (self == nullptr) {
+    if (!self) {
         log_debug("Could not retrieve class instance from global object");
         duk_error(ctx, DUK_ERR_ERROR, "Could not retrieve current script from stash");
     }
@@ -396,12 +392,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
     std::string val;
     int b;
     int i;
-    std::unique_ptr<StringConverter> sc;
-
-    if (this->whoami() == S_PLAYLIST) {
-        sc = StringConverter::p2i(config);
-    } else
-        sc = StringConverter::i2i(config);
+    std::unique_ptr<StringConverter> sc = (this->whoami() == S_PLAYLIST) ? StringConverter::p2i(config) : StringConverter::i2i(config);
 
     int objType = getIntProperty("objectType", -1);
     if (objType == -1) {
@@ -426,14 +417,15 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
     }
 
     i = getIntProperty("mtime", 0);
-    if (i > 0)
+    if (i > 0) {
         obj->setMTime(std::chrono::seconds(i));
+    }
 
     duk_get_prop_string(ctx, -1, "parent");
     if (duk_is_object(ctx, -1)) {
         duk_to_object(ctx, -1);
         auto parent = dukObject2cdsObject(nullptr);
-        if (parent != nullptr) {
+        if (parent) {
             obj->setParent(parent);
             log_debug("dukObject2cdsObject: Parent {}", parent->getClass());
         }
@@ -445,7 +437,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
         val = sc->convert(val);
         obj->setTitle(val);
     } else {
-        if (pcd != nullptr)
+        if (pcd)
             obj->setTitle(pcd->getTitle());
     }
 
@@ -454,7 +446,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
         val = sc->convert(val);
         obj->setClass(val);
     } else {
-        if (pcd != nullptr)
+        if (pcd)
             obj->setClass(pcd->getClass());
     }
 
@@ -493,7 +485,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
     duk_pop(ctx);
 
     // stuff that has not been exported to js
-    if (pcd != nullptr) {
+    if (pcd) {
         obj->setFlags(pcd->getFlags());
         obj->setResources(pcd->getResources());
         obj->setAuxData(pcd->getAuxData());
@@ -567,7 +559,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
         auto item = std::static_pointer_cast<CdsItem>(obj);
         std::shared_ptr<CdsItem> pcd_item;
 
-        if (pcd != nullptr)
+        if (pcd)
             pcd_item = std::static_pointer_cast<CdsItem>(pcd);
 
         val = getProperty("mimetype");
@@ -575,7 +567,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
             val = sc->convert(val);
             item->setMimeType(val);
         } else {
-            if (pcd != nullptr)
+            if (pcd)
                 item->setMimeType(pcd_item->getMimeType());
         }
 
@@ -592,7 +584,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
             val = sc->convert(val);
             item->setMetadata(M_DESCRIPTION, val);
         } else {
-            if (pcd != nullptr)
+            if (pcd)
                 item->setMetadata(M_DESCRIPTION, pcd_item->getMetadata(M_DESCRIPTION));
         }
         if (this->whoami() == S_PLAYLIST) {
@@ -604,7 +596,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
         if (!location.empty())
             obj->setLocation(location);
         else {
-            if (pcd != nullptr)
+            if (pcd)
                 obj->setLocation(pcd->getLocation());
         }
 
@@ -624,7 +616,7 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
                 auto resource = std::make_shared<CdsResource>(CH_DEFAULT);
                 resource->addAttribute(R_PROTOCOLINFO, protocolInfo);
 
-                item->addResource(resource);
+                item->addResource(move(resource));
             }
         }
     }
@@ -676,6 +668,7 @@ void Script::cdsObject2dukObject(const std::shared_ptr<CdsObject>& obj)
         setProperty("location", val);
 
     setIntProperty("mtime", int(obj->getMTime().count()));
+    setIntProperty("utime", int(obj->getUTime().count()));
     setIntProperty("sizeOnDisk", int(obj->getSizeOnDisk()));
     setIntProperty("flags", obj->getFlags());
 
@@ -742,7 +735,7 @@ void Script::cdsObject2dukObject(const std::shared_ptr<CdsObject>& obj)
         if (obj->getResourceCount() > 0) {
             int resCount = 0;
             for (auto&& res : obj->getResources()) {
-                setProperty(fmt::format("{}:handlerType", resCount), fmt::format("{}", res->getHandlerType()));
+                setProperty(fmt::format("{}:handlerType", resCount), fmt::to_string(res->getHandlerType()));
                 auto attributes = res->getAttributes();
                 for (auto&& [key, val] : attributes) {
                     setProperty(resCount == 0 ? key : fmt::format("{}-{}", resCount, key), val);
