@@ -68,17 +68,17 @@ protected:
 
     std::unique_ptr<StdThreadRunner> threadRunner;
 
-    std::unique_ptr<std::unordered_set<int>> objectIDHash;
+    std::unordered_set<int> objectIDHash;
 
-    bool shutdownFlag;
-    int flushPolicy;
+    bool shutdownFlag {};
+    int flushPolicy { FLUSH_SPEC };
 
-    int lastContainerChanged;
+    int lastContainerChanged { INVALID_OBJECT_ID };
 
     static void* staticThreadProc(void* arg);
     void threadProc();
 
-    bool haveUpdates() const { return !objectIDHash->empty(); }
+    bool haveUpdates() const { return !objectIDHash.empty(); }
 };
 
 #endif // __UPDATE_MANAGER_H__
