@@ -36,31 +36,30 @@
 #include "database/sqlite3/sqlite_database.h"
 #include "util/tools.h"
 
-Database::Database(std::shared_ptr<Config> config)
-    : config(std::move(config))
-{
-}
-
-std::shared_ptr<Database> Database::createInstance(const std::shared_ptr<Config>& config, const std::shared_ptr<Timer>& timer)
+std::shared_ptr<Database> Database::createInstance(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime, const std::shared_ptr<Timer>& timer)
 {
     std::string type = config->getOption(CFG_SERVER_STORAGE_DRIVER);
-    std::shared_ptr<Database> database;
-
-    if (type == "sqlite3") {
-        database = std::static_pointer_cast<Database>(std::make_shared<Sqlite3Database>(config, timer));
-    }
+    bool use_transaction = config->getBoolOption(CFG_SERVER_STORAGE_USE_TRANSACTIONS);
+    auto database = [&]() -> std::shared_ptr<Database> {
+        if (type == "sqlite3" && use_transaction) {
+            return std::make_shared<Sqlite3DatabaseWithTransactions>(config, mime, timer);
+        }
+        if (type == "sqlite3") {
+            return std::make_shared<Sqlite3Database>(config, mime, timer);
+        }
 #ifdef HAVE_MYSQL
-    else if (type == "mysql") {
-        database = std::static_pointer_cast<Database>(std::make_shared<MySQLDatabase>(config));
-    }
+        if (type == "mysql" && use_transaction) {
+            return std::make_shared<MySQLDatabaseWithTransactions>(config, mime);
+        }
+        if (type == "mysql") {
+            return std::make_shared<MySQLDatabase>(config, mime);
+        }
 #endif
-    else {
         // other database types...
-        throw_std_runtime_error("Unknown database type: {}", type.c_str());
-    }
+        throw_std_runtime_error("Unknown database type: {}", type);
+    }();
 
     database->init();
-    database->doMetadataMigration();
 
     return database;
 }
