@@ -32,6 +32,7 @@
 #ifdef HAVE_MYSQL
 #include "mysql_database.h"
 
+#include <array>
 #include <cstdlib>
 
 #include <netinet/in.h>
@@ -44,77 +45,18 @@
 //#define MYSQL_SELECT_DEBUG
 //#define MYSQL_EXEC_DEBUG
 
-// updates 1->2
-#define MYSQL_UPDATE_1_2_1 "ALTER TABLE `mt_cds_object` CHANGE `location` `location` BLOB NULL DEFAULT NULL"
-#define MYSQL_UPDATE_1_2_2 "ALTER TABLE `mt_cds_object` CHANGE `metadata` `metadata` BLOB NULL DEFAULT NULL"
-#define MYSQL_UPDATE_1_2_3 "ALTER TABLE `mt_cds_object` CHANGE `auxdata` `auxdata` BLOB NULL DEFAULT NULL"
-#define MYSQL_UPDATE_1_2_4 "ALTER TABLE `mt_cds_object` CHANGE `resources` `resources` BLOB NULL DEFAULT NULL"
-#define MYSQL_UPDATE_1_2_5 "ALTER TABLE `mt_autoscan` CHANGE `location` `location` BLOB NULL DEFAULT NULL"
-
-// updates 2->3
-#define MYSQL_UPDATE_2_3_1 "ALTER TABLE `mt_autoscan` CHANGE `scan_mode` `scan_mode` ENUM( 'timed', 'inotify' ) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL"
-#define MYSQL_UPDATE_2_3_2 "ALTER TABLE `mt_autoscan` DROP INDEX `mt_autoscan_obj_id`, ADD UNIQUE `mt_autoscan_obj_id` ( `obj_id` )"
-#define MYSQL_UPDATE_2_3_3 "ALTER TABLE `mt_autoscan` ADD `path_ids` BLOB AFTER `location`"
-
-// updates 3->4
-#define MYSQL_UPDATE_3_4_1 "ALTER TABLE `mt_cds_object` ADD `service_id` varchar(255) default NULL"
-#define MYSQL_UPDATE_3_4_2 "ALTER TABLE `mt_cds_object` ADD KEY `cds_object_service_id` (`service_id`)"
-
-// updates 4->5
-#define MYSQL_UPDATE_4_5_1 "CREATE TABLE `mt_metadata` ( \
-  `id` int(11) NOT NULL auto_increment, \
-  `item_id` int(11) NOT NULL, \
-  `property_name` varchar(255) NOT NULL, \
-  `property_value` text NOT NULL, \
-  PRIMARY KEY `id` (`id`), \
-  KEY `metadata_item_id` (`item_id`), \
-  CONSTRAINT `mt_metadata_idfk1` FOREIGN KEY (`item_id`) REFERENCES `mt_cds_object` (`id`) ON DELETE CASCADE ON UPDATE CASCADE \
-) ENGINE=MyISAM CHARSET=utf8"
-
-// updates 5->6: add config value table
-#define MYSQL_UPDATE_5_6_1 "CREATE TABLE `grb_config_value` ( \
-  `item` varchar(255) primary key, \
-  `key` varchar(255) NOT NULL, \
-  `item_value` varchar(255) NOT NULL, \
-  `status` varchar(20) NOT NULL) \
-  ENGINE=MyISAM CHARSET=utf8"
-#define MYSQL_UPDATE_5_6_2 "CREATE INDEX grb_config_value_item ON grb_config_value(item)"
-
-// updates 6->7
-#define MYSQL_UPDATE_6_7_1 "DROP TABLE mt_cds_active_item;"
-
-// updates 7->8: part_number
-#define MYSQL_UPDATE_7_8_1 "ALTER TABLE `mt_cds_object` ADD `part_number` int(11) default NULL AFTER `flags`"
-#define MYSQL_UPDATE_7_8_2 "ALTER TABLE `mt_cds_object` DROP KEY `cds_object_track_number`"
-#define MYSQL_UPDATE_7_8_3 "ALTER TABLE `mt_cds_object` ADD KEY `cds_object_track_number` (`part_number`,`track_number`)"
-
-// updates 8->9: bookmark_pos
-#define MYSQL_UPDATE_8_9_1 "ALTER TABLE `mt_cds_object` ADD `bookmark_pos` int(11) unsigned NOT NULL default '0' AFTER `service_id`"
-
-// updates 9->10: last_modified
-#define MYSQL_UPDATE_9_10_1 "ALTER TABLE `mt_cds_object` ADD `last_modified` bigint(20) unsigned default NULL AFTER `bookmark_pos`"
-
+#define MYSQL_SET_VERSION "INSERT INTO `mt_internal_setting` VALUES ('db_version','{}')"
 #define MYSQL_UPDATE_VERSION "UPDATE `mt_internal_setting` SET `value`='{}' WHERE `key`='db_version' AND `value`='{}'"
+#define MYSQL_ADD_RESOURCE_ATTR "ALTER TABLE `grb_cds_resource` ADD COLUMN `{}` varchar(255) default NULL"
 
-static const auto dbUpdates = std::array<std::vector<const char*>, 9> { {
-    { MYSQL_UPDATE_1_2_1, MYSQL_UPDATE_1_2_2, MYSQL_UPDATE_1_2_3, MYSQL_UPDATE_1_2_4, MYSQL_UPDATE_1_2_5 },
-    { MYSQL_UPDATE_2_3_1, MYSQL_UPDATE_2_3_2, MYSQL_UPDATE_2_3_3 },
-    { MYSQL_UPDATE_3_4_1, MYSQL_UPDATE_3_4_2 },
-    { MYSQL_UPDATE_4_5_1 },
-    { MYSQL_UPDATE_5_6_1, MYSQL_UPDATE_5_6_2 },
-    { MYSQL_UPDATE_6_7_1 },
-    { MYSQL_UPDATE_7_8_1, MYSQL_UPDATE_7_8_2, MYSQL_UPDATE_7_8_3 },
-    { MYSQL_UPDATE_8_9_1 },
-    { MYSQL_UPDATE_9_10_1 },
-} };
-
-MySQLDatabase::MySQLDatabase(std::shared_ptr<Config> config)
-    : SQLDatabase(std::move(config))
-    , mysql_connection(false)
-    , mysql_init_key_initialized(false)
+MySQLDatabase::MySQLDatabase(std::shared_ptr<Config> config, std::shared_ptr<Mime> mime)
+    : SQLDatabase(std::move(config), std::move(mime))
 {
     table_quote_begin = '`';
     table_quote_end = '`';
+
+    // if mysql.sql or mysql-upgrade.xml is changed hashies have to be updated, index 0 is used for create script
+    hashies = { 3398516749, 928913698, 1984244483, 2241152998, 1748460509, 2860006966, 974692115, 70310290, 1863649106, 4238128129, 2979337694, 1512596496, 507706380 };
 }
 
 MySQLDatabase::~MySQLDatabase()
@@ -135,7 +77,7 @@ void MySQLDatabase::checkMysqlThreadInit() const
 {
     if (!mysql_connection)
         throw_std_runtime_error("mysql connection is not open or already closed");
-    if (pthread_getspecific(mysql_init_key) == nullptr) {
+    if (!pthread_getspecific(mysql_init_key)) {
         if (mysql_thread_init())
             throw_std_runtime_error("error while calling mysql_thread_init()");
         if (pthread_setspecific(mysql_init_key, reinterpret_cast<void*>(1)))
@@ -145,7 +87,7 @@ void MySQLDatabase::checkMysqlThreadInit() const
 
 void MySQLDatabase::threadCleanup()
 {
-    if (pthread_getspecific(mysql_init_key) != nullptr) {
+    if (pthread_getspecific(mysql_init_key)) {
         mysql_thread_end();
     }
 }
@@ -174,8 +116,6 @@ void MySQLDatabase::init()
         throw_std_runtime_error("mysql_init() failed");
     }
 
-    mysql_init_key_initialized = true;
-
     mysql_options(&db, MYSQL_SET_CHARSET_NAME, "utf8mb4");
 
     bool my_bool_var = true;
@@ -215,20 +155,26 @@ void MySQLDatabase::init()
         auto sqlFilePath = config->getOption(CFG_SERVER_STORAGE_MYSQL_INIT_SQL_FILE);
         log_debug("Loading initialisation SQL from: {}", sqlFilePath.c_str());
         auto sql = readTextFile(sqlFilePath);
+        auto&& myHash = stringHash(sql);
 
-        for (auto&& statement : splitString(sql, ';')) {
-            trimStringInPlace(statement);
-            if (statement.empty()) {
-                continue;
-            }
-            log_debug("executing statement: '{}'", statement);
-            ret = mysql_real_query(&db, statement.c_str(), statement.size());
-            if (ret) {
-                std::string myError = getError(&db);
-                throw DatabaseException(myError, fmt::format("Mysql: error while creating db: {}", myError));
+        if (myHash == hashies[0]) {
+            for (auto&& statement : splitString(sql, ';')) {
+                trimStringInPlace(statement);
+                if (statement.empty()) {
+                    continue;
+                }
+                log_debug("executing statement: '{}'", statement);
+                ret = mysql_real_query(&db, statement.c_str(), statement.size());
+                if (ret) {
+                    std::string myError = getError(&db);
+                    throw DatabaseException(myError, fmt::format("Mysql: error while creating db: {}", myError));
+                }
             }
+            _exec(fmt::format(MYSQL_SET_VERSION, DBVERSION).c_str());
+        } else {
+            log_warning("Wrong hash for create script {}: {} != {}", DBVERSION, myHash, hashies[0]);
+            throw_std_runtime_error("Wrong hash for create script {}", DBVERSION);
         }
-
         dbVersion = getInternalSetting("db_version");
         if (dbVersion.empty()) {
             shutdown();
@@ -236,25 +182,8 @@ void MySQLDatabase::init()
         }
         log_info("Database created successfully!");
     }
-    log_debug("db_version: {}", dbVersion.c_str());
 
-    /* --- database upgrades --- */
-    int version = 1;
-    for (auto&& upgrade : dbUpdates) {
-        if (dbVersion == fmt::to_string(version)) {
-            log_info("Running an automatic database upgrade from database version {} to version {}...", version, version + 1);
-            for (auto&& upgradeCmd : upgrade) {
-                _exec(upgradeCmd);
-            }
-            _exec(fmt::format(MYSQL_UPDATE_VERSION, version + 1, version).c_str());
-            dbVersion = fmt::to_string(version + 1);
-            log_info("Database upgrade to version {} successful.", dbVersion.c_str());
-        }
-        version++;
-    }
-
-    if (dbVersion != fmt::to_string(version))
-        throw_std_runtime_error("The database seems to be from a newer version (database version {})", dbVersion);
+    upgradeDatabase(std::move(dbVersion), hashies, CFG_SERVER_STORAGE_MYSQL_UPGRADE_FILE, MYSQL_UPDATE_VERSION, MYSQL_ADD_RESOURCE_ATTR);
 
     lock.unlock();
 
@@ -266,7 +195,7 @@ std::shared_ptr<Database> MySQLDatabase::getSelf()
     return shared_from_this();
 }
 
-std::string MySQLDatabase::quote(std::string value) const
+std::string MySQLDatabase::quote(const std::string& value) const
 {
     /* note: mysql_real_escape_string returns a maximum of (length * 2 + 1)
      * chars; we need +1 for the first ' - the second ' will be written over
@@ -277,7 +206,7 @@ std::string MySQLDatabase::quote(std::string value) const
     *q = '\'';
     auto size = mysql_real_escape_string(const_cast<MYSQL*>(&db), q + 1, value.c_str(), value.length());
     q[size + 1] = '\'';
-    std::string ret(q, size + 2);
+    auto ret = std::string(q, size + 2);
     delete[] q;
     return ret;
 }
@@ -289,7 +218,7 @@ std::string MySQLDatabase::getError(MYSQL* db)
     return res;
 }
 
-void MySQLDatabase::beginTransaction(const std::string_view& tName)
+void MySQLDatabaseWithTransactions::beginTransaction(const std::string_view& tName)
 {
     log_debug("START TRANSACTION {} {}", tName, inTransaction);
     StdThreadRunner::waitFor(
@@ -301,7 +230,7 @@ void MySQLDatabase::beginTransaction(const std::string_view& tName)
         _exec("START TRANSACTION");
 }
 
-void MySQLDatabase::rollback(const std::string_view& tName)
+void MySQLDatabaseWithTransactions::rollback(const std::string_view& tName)
 {
     log_debug("ROLLBACK {}", tName);
     if (use_transaction && inTransaction && mysql_rollback(&db)) {
@@ -311,7 +240,7 @@ void MySQLDatabase::rollback(const std::string_view& tName)
     inTransaction = false;
 }
 
-void MySQLDatabase::commit(const std::string_view& tName)
+void MySQLDatabaseWithTransactions::commit(const std::string_view& tName)
 {
     log_debug("COMMIT {}", tName);
     SqlAutoLock lock(sqlMutex);
@@ -322,7 +251,7 @@ void MySQLDatabase::commit(const std::string_view& tName)
     inTransaction = false;
 }
 
-std::shared_ptr<SQLResult> MySQLDatabase::select(const char* query, int length)
+std::shared_ptr<SQLResult> MySQLDatabaseWithTransactions::select(const std::string& query)
 {
 #ifdef MYSQL_SELECT_DEBUG
     log_debug("{}", query);
@@ -336,7 +265,7 @@ std::shared_ptr<SQLResult> MySQLDatabase::select(const char* query, int length)
         inTransaction = true;
         myTransaction = true;
     }
-    auto res = mysql_real_query(&db, query, length);
+    auto res = mysql_real_query(&db, query.c_str(), query.size());
     if (res) {
         std::string myError = getError(&db);
         rollback("");
@@ -353,10 +282,31 @@ std::shared_ptr<SQLResult> MySQLDatabase::select(const char* query, int length)
         inTransaction = false;
     }
 
-    return std::static_pointer_cast<SQLResult>(std::make_shared<MysqlResult>(mysql_res));
+    return std::make_shared<MysqlResult>(mysql_res);
 }
 
-int MySQLDatabase::exec(const char* query, int length, bool getLastInsertId)
+std::shared_ptr<SQLResult> MySQLDatabase::select(const std::string& query)
+{
+    log_debug("{}", query);
+
+    checkMysqlThreadInit();
+    SqlAutoLock lock(sqlMutex);
+    auto res = mysql_real_query(&db, query.c_str(), query.size());
+    if (res) {
+        std::string myError = getError(&db);
+        throw DatabaseException(myError, fmt::format("Mysql: mysql_real_query() failed: {}; query: {}", myError, query));
+    }
+
+    MYSQL_RES* mysql_res = mysql_store_result(&db);
+    if (!mysql_res && mysql_field_count(&db)) {
+        std::string myError = getError(&db);
+        throw DatabaseException(myError, fmt::format("Mysql: mysql_store_result() failed: {}; query: {}", myError, query));
+    }
+
+    return std::make_shared<MysqlResult>(mysql_res);
+}
+
+int MySQLDatabase::exec(const std::string& query, bool getLastInsertId)
 {
 #ifdef MYSQL_EXEC_DEBUG
     log_debug("{}", query);
@@ -365,7 +315,7 @@ int MySQLDatabase::exec(const char* query, int length, bool getLastInsertId)
 
     checkMysqlThreadInit();
     SqlAutoLock lock(sqlMutex);
-    auto res = mysql_real_query(&db, query, length);
+    auto res = mysql_real_query(&db, query.c_str(), query.size());
     if (res) {
         std::string myError = getError(&db);
         rollback("");
@@ -383,19 +333,13 @@ void MySQLDatabase::shutdownDriver()
 
 void MySQLDatabase::storeInternalSetting(const std::string& key, const std::string& value)
 {
-    std::string quotedValue = quote(value);
-    std::ostringstream q;
-    q << "INSERT INTO " << QTB << INTERNAL_SETTINGS_TABLE << QTE << " (`key`, `value`) "
-                                                                    "VALUES ("
-      << quote(key) << ", " << quotedValue << ") "
-                                              "ON DUPLICATE KEY UPDATE `value` = "
-      << quotedValue;
-    SQLDatabase::exec(q.str());
+    exec(fmt::format("INSERT INTO `{0}` (`key`, `value`) VALUES ({1}, {2}) ON DUPLICATE KEY UPDATE `value` = {2}",
+        INTERNAL_SETTINGS_TABLE, quote(key), quote(value)));
 }
 
-void MySQLDatabase::_exec(const char* query, int length)
+void MySQLDatabase::_exec(const std::string& query)
 {
-    if (mysql_real_query(&db, query, (length > 0 ? length : strlen(query)))) {
+    if (mysql_real_query(&db, query.c_str(), query.size())) {
         std::string myError = getError(&db);
         throw DatabaseException(myError, fmt::format("Mysql: error while updating db: {}; query: {}", myError, query));
     }
@@ -403,17 +347,11 @@ void MySQLDatabase::_exec(const char* query, int length)
 
 /* MysqlResult */
 
-MysqlResult::MysqlResult(MYSQL_RES* mysql_res)
-    : nullRead(false)
-    , mysql_res(mysql_res)
-{
-}
-
 MysqlResult::~MysqlResult()
 {
     if (mysql_res) {
         if (!nullRead) {
-            while ((mysql_fetch_row(mysql_res)) != nullptr)
+            while ((mysql_fetch_row(mysql_res)))
                 ; // read out data
         }
         mysql_free_result(mysql_res);
@@ -423,7 +361,7 @@ MysqlResult::~MysqlResult()
 
 std::unique_ptr<SQLRow> MysqlResult::nextRow()
 {
-    if (auto mysql_row = mysql_fetch_row(mysql_res); mysql_row != nullptr) {
+    if (auto mysql_row = mysql_fetch_row(mysql_res); mysql_row) {
         return std::make_unique<MysqlRow>(mysql_row);
     }
     nullRead = true;
