@@ -25,20 +25,12 @@
 #include "search_handler.h" // API
 
 #include <algorithm>
-#include <cctype>
-#include <iostream>
-#include <sstream>
 #include <stack>
 
 #include "config/config_manager.h"
 #include "database/sql_database.h"
 #include "util/tools.h"
 
-/* table quote */
-#define TQ(data) this->tabQuote << (data) << this->tabQuote
-/* table quote with dot */
-#define TQD(data1, data2) TQ(data1) << '.' << TQ(data2)
-
 static const std::unordered_map<std::string_view, TokenType> tokenTypes {
     { "(", TokenType::LPAREN },
     { ")", TokenType::RPAREN },
@@ -61,13 +53,6 @@ static const std::unordered_map<std::string_view, TokenType> tokenTypes {
     { "or", TokenType::OR }
 };
 
-static std::string aslowercase(const std::string& src)
-{
-    std::string copy = src;
-    std::transform(copy.begin(), copy.end(), copy.begin(), ::tolower);
-    return copy;
-}
-
 std::unique_ptr<SearchToken> SearchLexer::nextToken()
 {
     for (; currentPos < input.length();) {
@@ -81,7 +66,7 @@ std::unique_ptr<SearchToken> SearchLexer::nextToken()
             auto token = std::string(&ch, 1);
             TokenType tokenType = tokenTypes.at(token);
             currentPos++;
-            return std::make_unique<SearchToken>(tokenType, token);
+            return std::make_unique<SearchToken>(tokenType, std::move(token));
         }
         case '>':
         case '<':
@@ -91,12 +76,12 @@ std::unique_ptr<SearchToken> SearchLexer::nextToken()
                 token.push_back('=');
                 TokenType tokenType = tokenTypes.at(token);
                 currentPos += 2;
-                return std::make_unique<SearchToken>(tokenType, token);
+                return std::make_unique<SearchToken>(tokenType, std::move(token));
             } else {
                 auto token = std::string(&ch, 1);
                 TokenType tokenType = tokenTypes.at(token);
                 currentPos++;
-                return std::make_unique<SearchToken>(tokenType, token);
+                return std::make_unique<SearchToken>(tokenType, std::move(token));
             }
         case '"':
             if (!inQuotes) {
@@ -121,7 +106,7 @@ std::unique_ptr<SearchToken> SearchLexer::nextToken()
             } else {
                 auto tokenStr = nextStringToken(input);
                 if (!tokenStr.empty()) {
-                    std::unique_ptr<SearchToken> token = makeToken(tokenStr);
+                    auto token = makeToken(tokenStr);
                     if (!token->getValue().empty())
                         return token;
                 }
@@ -157,21 +142,23 @@ std::string SearchLexer::nextStringToken(const std::string& input)
     auto startPos = currentPos;
     for (; currentPos < input.length();) {
         auto ch = input[currentPos];
-        if (std::isalnum(ch) || ch == ':' || ch == '@' || ch == '.')
+        if (std::isalnum(ch) || ch == ':' || ch == '@' || ch == '.' || ch == '_')
             currentPos++;
         else
             break;
     }
+    if (startPos == currentPos)
+        throw_std_runtime_error("String expected, found '{}' instead", input[currentPos]);
     return input.substr(startPos, currentPos - startPos);
 }
 
-std::unique_ptr<SearchToken> SearchLexer::makeToken(const std::string& tokenStr)
+std::unique_ptr<SearchToken> SearchLexer::makeToken(std::string tokenStr)
 {
-    auto itr = tokenTypes.find(aslowercase(tokenStr));
+    auto itr = tokenTypes.find(toLower(tokenStr));
     if (itr != tokenTypes.end()) {
-        return std::make_unique<SearchToken>(itr->second, tokenStr);
+        return std::make_unique<SearchToken>(itr->second, std::move(tokenStr));
     }
-    return std::make_unique<SearchToken>(TokenType::PROPERTY, tokenStr);
+    return std::make_unique<SearchToken>(TokenType::PROPERTY, std::move(tokenStr));
 }
 
 void SearchParser::getNextToken()
@@ -192,25 +179,25 @@ std::shared_ptr<ASTNode> SearchParser::parseSearchExpression()
 {
     std::stack<std::shared_ptr<ASTNode>> nodeStack;
     std::stack<TokenType> operatorStack;
-    std::shared_ptr<ASTNode> root = nullptr;
-    std::shared_ptr<ASTNode> expressionNode = nullptr;
+    std::shared_ptr<ASTNode> root;
+    std::shared_ptr<ASTNode> expressionNode;
     TokenType currentOperator = TokenType::INVALID;
     while (currentToken) {
         if (currentToken->getType() == TokenType::PROPERTY) {
             expressionNode = parseRelationshipExpression();
             if (currentOperator == TokenType::AND) {
-                if (nodeStack.top() == nullptr)
+                if (!nodeStack.top())
                     throw_std_runtime_error("Cannot construct ASTAndOperator without lhs");
-                if (expressionNode == nullptr)
+                if (!expressionNode)
                     throw_std_runtime_error("Cannot construct ASTAndOperator without rhs");
                 std::shared_ptr<ASTNode> lhs(nodeStack.top());
                 nodeStack.pop();
                 nodeStack.push(std::make_shared<ASTAndOperator>(sqlEmitter, lhs, expressionNode));
                 operatorStack.pop();
             } else if (currentOperator == TokenType::OR) {
-                if (nodeStack.top() == nullptr)
+                if (!nodeStack.top())
                     throw_std_runtime_error("Cannot construct ASTOrOperator without lhs");
-                if (expressionNode == nullptr)
+                if (!expressionNode)
                     throw_std_runtime_error("Cannot construct ASTOrOperator without rhs");
                 std::shared_ptr<ASTNode> lhs(nodeStack.top());
                 nodeStack.pop();
@@ -256,11 +243,11 @@ std::shared_ptr<ASTNode> SearchParser::parseParenthesis()
     if (currentToken->getType() != TokenType::LPAREN)
         throw_std_runtime_error("Failed to parse search criteria - expecting a ')'");
 
-    std::shared_ptr<ASTNode> currentNode = nullptr;
-    std::shared_ptr<ASTNode> lhsNode = nullptr;
-    std::shared_ptr<ASTNode> rhsNode = nullptr;
+    std::shared_ptr<ASTNode> currentNode;
+    std::shared_ptr<ASTNode> lhsNode;
+    std::shared_ptr<ASTNode> rhsNode;
     getNextToken();
-    while (currentToken != nullptr && currentToken->getType() != TokenType::RPAREN) {
+    while (currentToken && currentToken->getType() != TokenType::RPAREN) {
         // just call parseSearchExpression() at this point?
         if (currentToken->getType() == TokenType::PROPERTY) {
             currentNode = parseRelationshipExpression();
@@ -288,7 +275,7 @@ std::shared_ptr<ASTNode> SearchParser::parseParenthesis()
             getNextToken();
         }
     }
-    if (currentNode == nullptr)
+    if (!currentNode)
         throw_std_runtime_error("Failed to parse search criteria - bad expression between parenthesis");
 
     return std::make_shared<ASTParenthesis>(sqlEmitter, currentNode);
@@ -344,14 +331,6 @@ std::shared_ptr<ASTQuotedString> SearchParser::parseQuotedString()
     return std::make_shared<ASTQuotedString>(sqlEmitter, openQuote, escapedString, closeQuote);
 }
 
-void SearchParser::checkIsExpected(TokenType tokenType, const std::string& tokenTypeDescription)
-{
-    if (currentToken->getType() != tokenType) {
-        std::string errorMsg(std::string("Failed to parse search criteria - expecting ") + tokenTypeDescription);
-        throw_std_runtime_error(errorMsg);
-    }
-}
-
 std::string ASTNode::emitSQL() const
 {
     return sqlEmitter.emitSQL(this);
@@ -394,6 +373,7 @@ std::string ASTQuotedString::emit() const
 
 std::string ASTCompareOperator::emit() const
 {
+    log_error("Emitting for ASTCompareOperator");
     throw_std_runtime_error("Should not get here");
 }
 
@@ -409,6 +389,7 @@ std::string ASTCompareExpression::emit() const
 
 std::string ASTStringOperator::emit() const
 {
+    log_error("Emitting for ASTStringOperator");
     throw_std_runtime_error("Should not get here");
 }
 
@@ -424,7 +405,7 @@ std::string ASTStringExpression::emit() const
 
 std::string ASTExistsOperator::emit() const
 {
-    std::cout << "Emitting for ASTExistsOperator " << std::endl;
+    log_error("Emitting for ASTExistsOperator");
     throw_std_runtime_error("Should not get here");
 }
 
@@ -452,108 +433,84 @@ std::string DefaultSQLEmitter::emitSQL(const ASTNode* node) const
 {
     std::string predicates = node->emit();
     if (!predicates.empty()) {
-        std::ostringstream sql;
-        sql << "FROM " << TQ(CDS_OBJECT_TABLE) << " " << TQ(tableAlias)
-            << " INNER JOIN " << TQ(METADATA_TABLE) << " " << TQ(metaAlias) << " ON " << TQD(tableAlias, "id") << " = " << TQD(metaAlias, "item_id")
-            << " WHERE "
-            << predicates;
-        return sql.str();
+        return predicates;
     }
     throw_std_runtime_error("No SQL generated from AST");
 }
 
 std::string DefaultSQLEmitter::emit(const ASTParenthesis* node, const std::string& bracketedNode) const
 {
-    std::ostringstream sqlFragment;
-    sqlFragment << "(" << bracketedNode << ")";
-    return sqlFragment.str();
+    return fmt::format("({})", bracketedNode);
 }
 
 // format indexes:
-//    0: quote
-//    1: alias for metadata table
-//    2: alias for object table
-//    3: property
-const static std::map<std::string, std::string> propertyLowerStatement = {
-    { "metadata", "{0}{1}{0}.{0}property_name{0}='{3}' AND LOWER({0}{1}{0}.{0}property_value{0})" },
-    { "@refID", "LOWER({0}{2}{0}.{0}ref_id{0})" },
-    { "@parentID", "LOWER({{0}{2}{0}.{0}parent_id{0})" },
-    { "@id", "LOWER({{0}{2}{0}.{0}id{0})" },
-};
-
-// format indexes:
-//    0: quote
-//    1: alias for metadata table
-//    2: alias for object table
-//    3: property
-const static std::map<std::string, std::string> propertyStatement = {
-    { "metadata", "{0}{1}{0}.{0}property_name{0}='{3}' AND {0}{1}{0}.{0}property_value{0}" },
-    { "@refID", "{0}{2}{0}.{0}ref_id{0}" },
-    { "@parentID", "{0}{2}{0}.{0}parent_id{0}" },
-    { "@id", "{0}{2}{0}.{0}id{0}" },
-};
-
-// format indexes:
-//    0: quote
-//    1: alias for metadata table
-//    2: alias for object table
-//    3: property name statement
-//    4: property statement lower case
-//    5: value
-const static std::map<std::string, std::string> logicOperator = {
-    { "contains", "({4} LIKE LOWER('%{5}%') AND {0}{2}{0}.{0}upnp_class{0} IS NOT NULL)" }, // lower
-    { "doesnotcontain", "({4} NOT LIKE LOWER('%{5}%') AND {0}{2}{0}.{0}upnp_class{0} IS NOT NULL)" }, // lower
-    { "startswith", "({4} LIKE LOWER('{5}%') AND {0}{2}{0}.{0}upnp_class{0} IS NOT NULL)" }, // lower
-    { "derivedfrom", "(LOWER({0}{2}{0}.{0}upnp_class{0}) LIKE LOWER('{5}%'))" },
-    //{ "derivedfrom", "{0}{2}{0}.{0}upnp_class{0} LIKE LOWER('{5}%')" },
-    { "exists", "({3} IS {5} AND {0}{2}{0}.{0}upnp_class{0} IS NOT NULL)" },
-    { "@exists", "({3} IS {5})" },
-    { "compare", "({4}LOWER('{5}') AND {0}{2}{0}.{0}upnp_class{0} IS NOT NULL)" }, // lower
-    { "@compare", "({4}LOWER('{5}'))" }, // lower
+//    0: class statement
+//    1: property name statement
+//    2: property statement lower case
+//    3: value
+static const std::map<std::string, std::string> logicOperator {
+    { "contains", "({2} LIKE LOWER('%{3}%') AND {0} IS NOT NULL)" }, // lower
+    { "doesnotcontain", "({2} NOT LIKE LOWER('%{3}%') AND {0} IS NOT NULL)" }, // lower
+    { "startswith", "({2} LIKE LOWER('{3}%') AND {0} IS NOT NULL)" }, // lower
+    { "derivedfrom", "(LOWER({0}) LIKE LOWER('{3}%'))" },
+    //{ "derivedfrom", "{0} LIKE LOWER('{3}%')" },
+    { "exists", "({1} IS {3} AND {0} IS NOT NULL)" },
+    { "@exists", "({1} IS {3})" },
+    { "newer", "({1} {3})" },
+    { "compare", "({2}LOWER('{3}') AND {0} IS NOT NULL)" }, // lower
+    { "@compare", "({2}LOWER('{3}'))" }, // lower
 };
 
 std::pair<std::string, std::string> DefaultSQLEmitter::getPropertyStatement(const std::string& property) const
 {
-    if (property[0] == '@' || property.substr(0, 3) == "res") {
-        if (propertyStatement.find(property) != propertyStatement.end() && propertyLowerStatement.find(property) != propertyLowerStatement.end()) {
-            return {
-                fmt::format(propertyStatement.at(property), tabQuote, metaAlias, tableAlias, property),
-                fmt::format(propertyLowerStatement.at(property), tabQuote, metaAlias, tableAlias, property)
-            };
-        }
-        log_info("Property {} not yet supported. Search may return no result!", property);
+    if (colMapper && colMapper->hasEntry(property)) {
+        return { colMapper->mapQuoted(property), colMapper->mapQuotedLower(property) };
     }
-    return {
-        fmt::format(propertyStatement.at("metadata"), tabQuote, metaAlias, tableAlias, property),
-        fmt::format(propertyLowerStatement.at("metadata"), tabQuote, metaAlias, tableAlias, property)
-    };
+    if (resMapper && resMapper->hasEntry(property)) {
+        return { resMapper->mapQuoted(property), resMapper->mapQuotedLower(property) };
+    }
+    if (metaMapper) {
+        return {
+            fmt::format("{0}='{2}' AND {1}", metaMapper->mapQuoted(META_NAME), metaMapper->mapQuoted(META_VALUE), property),
+            fmt::format("{0}='{2}' AND {1}", metaMapper->mapQuoted(META_NAME), metaMapper->mapQuotedLower(META_VALUE), property)
+        };
+    }
+    log_info("Property {} not yet supported. Search may return no result!", property);
+    return {};
 }
 
 std::string DefaultSQLEmitter::emit(const ASTCompareOperator* node, const std::string& property,
     const std::string& value) const
 {
     auto operatr = node->getValue();
+    auto [prpUpper, prpLower] = getPropertyStatement(property);
+
+    if ((operatr == ">" || operatr == ">=") && value.substr(0, 5) == "@last") {
+        auto dateVal = to_seconds(std::chrono::system_clock::now()).count() - (24 * 60 * 60 * stoiString(value.substr(5)));
+        return fmt::format(logicOperator.at("newer"), "", fmt::format("{} {}", prpUpper, operatr), fmt::format("{} {}", prpLower, operatr), dateVal);
+    }
+
     if (operatr != "=")
         throw_std_runtime_error("Operator '{}' not yet supported", operatr);
 
-    auto prpStmnt = getPropertyStatement(property);
-    return fmt::format(logicOperator.at((property[0] == '@') ? "@compare" : "compare"), tabQuote, metaAlias, tableAlias,
-        fmt::format("{}{}", prpStmnt.first, operatr), fmt::format("{}{}", prpStmnt.second, operatr), value);
+    auto [clsUpper, clcLower] = getPropertyStatement(UPNP_SEARCH_CLASS);
+    return fmt::format(logicOperator.at((property[0] == '@') ? "@compare" : "compare"), clsUpper,
+        fmt::format("{}{}", prpUpper, operatr), fmt::format("{}{}", prpLower, operatr), value);
 }
 
 std::string DefaultSQLEmitter::emit(const ASTStringOperator* node, const std::string& property, const std::string& value) const
 {
-    auto stringOperator = aslowercase(node->getValue());
+    auto stringOperator = toLower(node->getValue());
     if (logicOperator.find(stringOperator) == logicOperator.end()) {
         throw_std_runtime_error("Operation '{}' not yet supported", stringOperator);
     }
-    auto prpStmnt = getPropertyStatement(property);
-    return fmt::format(logicOperator.at(stringOperator), tabQuote, metaAlias, tableAlias, prpStmnt.first, prpStmnt.second, value);
+    auto [prpUpper, prpLower] = getPropertyStatement(property);
+    auto [clsUpper, clsLower] = getPropertyStatement(UPNP_SEARCH_CLASS);
+    return fmt::format(logicOperator.at(stringOperator), clsUpper, prpUpper, prpLower, value);
 }
 
 std::string DefaultSQLEmitter::emit(const ASTExistsOperator* node, const std::string& property, const std::string& value) const
 {
-    std::ostringstream sqlFragment;
     std::string exists;
     if (value == "true") {
         exists = "NOT NULL";
@@ -562,30 +519,27 @@ std::string DefaultSQLEmitter::emit(const ASTExistsOperator* node, const std::st
     } else {
         throw_std_runtime_error("Invalid value '{}' on rhs of 'exists' operator", value);
     }
-    auto prpStmnt = getPropertyStatement(property);
-    return fmt::format(logicOperator.at((property[0] == '@') ? "@exists" : "exists"), tabQuote, metaAlias, tableAlias, prpStmnt.first, prpStmnt.second, exists);
+    auto [prpUpper, prpLower] = getPropertyStatement(property);
+    auto [clsUpper, clsLower] = getPropertyStatement(UPNP_SEARCH_CLASS);
+    return fmt::format(logicOperator.at((property[0] == '@') ? "@exists" : "exists"), clsUpper, prpUpper, prpLower, exists);
 }
 
 std::string DefaultSQLEmitter::emit(const ASTAndOperator* node, const std::string& lhs,
     const std::string& rhs) const
 {
-    std::ostringstream sqlFragment;
-    sqlFragment << lhs << " AND " << rhs;
-    return sqlFragment.str();
+    return fmt::format("{} AND {}", lhs, rhs);
 }
 
 std::string DefaultSQLEmitter::emit(const ASTOrOperator* node, const std::string& lhs,
     const std::string& rhs) const
 {
-    std::ostringstream sqlFragment;
-    sqlFragment << lhs << " OR " << rhs;
-    return sqlFragment.str();
+    return fmt::format("{} OR {}", lhs, rhs);
 }
 
 std::string SortParser::parse()
 {
     if (sortCrit.empty()) {
-        return "";
+        return {};
     }
     std::vector<std::string> sort;
     for (auto&& seg : splitString(sortCrit, ',')) {
@@ -596,12 +550,12 @@ std::string SortParser::parse()
         } else {
             log_warning("Unknown sort direction '{}' in '{}'", seg, sortCrit);
         }
-        auto sortSql = colMapper != nullptr ? colMapper->mapQuoted(seg) : "";
+        auto sortSql = colMapper ? colMapper->mapQuoted(seg) : "";
         if (!sortSql.empty()) {
-            sort.emplace_back(fmt::format("{} {}", sortSql, (desc ? "DESC" : "ASC")));
+            sort.push_back(fmt::format("{} {}", sortSql, (desc ? "DESC" : "ASC")));
         } else {
             log_warning("Unknown sort key '{}' in '{}'", seg, sortCrit);
         }
     }
-    return join(sort, ", ");
+    return fmt::format("{}", fmt::join(sort, ", "));
 }
