@@ -36,6 +36,16 @@
 #include <unordered_map>
 #include <vector>
 
+#define UPNP_SEARCH_CLASS "upnp:class"
+#define UPNP_SEARCH_ID "@id"
+#define UPNP_SEARCH_REFID "@refID"
+#define UPNP_SEARCH_PARENTID "@parentID"
+#define UPNP_SEARCH_LAST_UPDATED "last_updated"
+#define UPNP_SEARCH_LAST_MODIFIED "last_modified"
+#define UPNP_SEARCH_PATH "path"
+#define META_NAME "name"
+#define META_VALUE "value"
+
 class SearchParam;
 
 enum class TokenType {
@@ -56,12 +66,11 @@ enum class TokenType {
 
 class SearchToken {
 public:
-    SearchToken(TokenType type, std::string value)
+    SearchToken(TokenType type, std::string&& value)
         : type(type)
         , value(std::move(value))
     {
     }
-    virtual ~SearchToken() = default;
 
     const TokenType& getType() const { return type; }
     std::string getValue() const { return value; }
@@ -82,16 +91,12 @@ public:
         : input(std::move(input))
     {
     }
-    virtual ~SearchLexer() = default;
 
     std::unique_ptr<SearchToken> nextToken();
 
-    SearchLexer& operator=(const SearchLexer&) = delete;
-    SearchLexer(const SearchLexer&) = delete;
-
 protected:
     std::string nextStringToken(const std::string& input);
-    static std::unique_ptr<SearchToken> makeToken(const std::string& tokenStr);
+    static std::unique_ptr<SearchToken> makeToken(std::string tokenStr);
     std::string getQuotedValue(const std::string& input);
 
     std::string input;
@@ -108,11 +113,11 @@ class SQLEmitter;
 
 class ASTNode {
 public:
+    virtual ~ASTNode() = default;
+
     std::string emitSQL() const;
     virtual std::string emit() const = 0;
 
-    virtual ~ASTNode() = default;
-
 protected:
     explicit ASTNode(const SQLEmitter& emitter)
         : sqlEmitter(emitter)
@@ -355,6 +360,7 @@ protected:
 
 class SQLEmitter {
 public:
+    virtual ~SQLEmitter() = default;
     virtual std::string emitSQL(const ASTNode* node) const = 0;
     virtual std::string emit(const ASTAsterisk* node) const = 0;
     virtual std::string emit(const ASTParenthesis* node, const std::string& bracketedNode) const = 0;
@@ -369,24 +375,30 @@ public:
         const std::string& lhs, const std::string& rhs) const = 0;
     virtual std::string emit(const ASTOrOperator* node,
         const std::string& lhs, const std::string& rhs) const = 0;
+};
 
-    virtual ~SQLEmitter() = default;
-    virtual std::string tableQuote() const = 0;
+class ColumnMapper {
+public:
+    virtual ~ColumnMapper() = default;
+    virtual bool hasEntry(const std::string& tag) const = 0;
+    virtual std::string tableQuoted() const = 0;
+    virtual std::string mapQuoted(const std::string& tag) const = 0;
+    virtual std::string mapQuotedLower(const std::string& tag) const = 0;
 };
 
 class DefaultSQLEmitter : public SQLEmitter {
 public:
-    DefaultSQLEmitter(std::string tabQuote, std::string tableAlias, std::string metaAlias)
-        : tabQuote(std::move(tabQuote))
-        , tableAlias(std::move(tableAlias))
-        , metaAlias(std::move(metaAlias))
+    DefaultSQLEmitter(std::shared_ptr<ColumnMapper> colMapper, std::shared_ptr<ColumnMapper> metaMapper, std::shared_ptr<ColumnMapper> resMapper)
+        : colMapper(std::move(colMapper))
+        , metaMapper(std::move(metaMapper))
+        , resMapper(std::move(resMapper))
     {
     }
 
     std::string emitSQL(const ASTNode* node) const override;
-    std::string emit(const ASTAsterisk* node) const override { return "*"; }
+    std::string emit(const ASTAsterisk* node) const override { return {}; }
     std::string emit(const ASTParenthesis* node, const std::string& bracketedNode) const override;
-    std::string emit(const ASTDQuote* node) const override { return ""; }
+    std::string emit(const ASTDQuote* node) const override { return {}; }
     std::string emit(const ASTCompareOperator* node,
         const std::string& property, const std::string& value) const override;
     std::string emit(const ASTStringOperator* node,
@@ -396,12 +408,10 @@ public:
     std::string emit(const ASTAndOperator* node, const std::string& lhs, const std::string& rhs) const override;
     std::string emit(const ASTOrOperator* node, const std::string& lhs, const std::string& rhs) const override;
 
-    std::string tableQuote() const override { return tabQuote; }
-
 private:
-    std::string tabQuote;
-    std::string tableAlias;
-    std::string metaAlias;
+    std::shared_ptr<ColumnMapper> colMapper;
+    std::shared_ptr<ColumnMapper> metaMapper;
+    std::shared_ptr<ColumnMapper> resMapper;
 
     std::pair<std::string, std::string> getPropertyStatement(const std::string& property) const;
 };
@@ -421,7 +431,6 @@ protected:
     std::shared_ptr<ASTNode> parseRelationshipExpression();
     std::shared_ptr<ASTNode> parseParenthesis();
     std::shared_ptr<ASTQuotedString> parseQuotedString();
-    void checkIsExpected(TokenType tokenType, const std::string& tokenTypeDescription);
 
 private:
     std::shared_ptr<SearchToken> currentToken;
@@ -429,43 +438,74 @@ private:
     const SQLEmitter& sqlEmitter;
 };
 
-class ColumnMapper {
-public:
-    virtual std::string mapQuoted(const std::string& tag) const = 0;
-    virtual ~ColumnMapper() = default;
-};
-
 template <class En>
 class EnumColumnMapper : public ColumnMapper {
 public:
-    explicit EnumColumnMapper(const char tabQuoteBegin, const char tabQuoteEnd, const std::vector<std::pair<std::string, En>>& keyMap, const std::map<En, std::pair<std::string, std::string>>& colMap)
+    explicit EnumColumnMapper(const char tabQuoteBegin, const char tabQuoteEnd, std::string tableAlias, std::string tableName,
+        const std::vector<std::pair<std::string, En>>& keyMap, const std::map<En, std::pair<std::string, std::string>>& colMap)
         : table_quote_begin(tabQuoteBegin)
         , table_quote_end(tabQuoteEnd)
+        , tableAlias(std::move(tableAlias))
+        , tableName(std::move(tableName))
         , keyMap(keyMap)
         , colMap(colMap)
     {
     }
+    bool hasEntry(const std::string& tag) const override
+    {
+        return std::find_if(keyMap.begin(), keyMap.end(), [=](auto&& map) { return map.first == tag; }) != keyMap.end();
+    }
+    std::string mapQuoted(En tag) const
+    {
+        auto it = std::find_if(colMap.begin(), colMap.end(), [=](auto&& map) { return map.first == tag; });
+        if (it != colMap.end()) {
+            if (colMap.at(tag).first.empty()) // no column
+                return colMap.at(tag).second;
+            return fmt::format("{0}{1}{3}.{0}{2}{3}", table_quote_begin, colMap.at(tag).first, colMap.at(tag).second, table_quote_end);
+        }
+        return {};
+    }
+
+    std::string tableQuoted() const override
+    {
+        return fmt::format("{0}{1}{3} {0}{2}{3}", table_quote_begin, tableName, tableAlias, table_quote_end);
+    }
+
     std::string mapQuoted(const std::string& tag) const override
     {
         auto it = std::find_if(keyMap.begin(), keyMap.end(), [=](auto&& map) { return map.first == tag; });
         if (it != keyMap.end()) {
+            if (colMap.at(it->second).first.empty()) // no column
+                return colMap.at(it->second).second;
             return fmt::format("{0}{1}{3}.{0}{2}{3}", table_quote_begin, colMap.at(it->second).first, colMap.at(it->second).second, table_quote_end);
         }
-        return "";
+        return {};
+    }
+    std::string mapQuotedLower(const std::string& tag) const override
+    {
+        auto it = std::find_if(keyMap.begin(), keyMap.end(), [=](auto&& map) { return map.first == tag; });
+        if (it != keyMap.end()) {
+            if (colMap.at(it->second).first.empty()) // no column
+                return fmt::format("LOWER({})", colMap.at(it->second).second);
+            return fmt::format("LOWER({0}{1}{3}.{0}{2}{3})", table_quote_begin, colMap.at(it->second).first, colMap.at(it->second).second, table_quote_end);
+        }
+        return {};
     }
 
 private:
     const char table_quote_begin;
     const char table_quote_end;
+    std::string tableAlias;
+    std::string tableName;
     const std::vector<std::pair<std::string, En>>& keyMap;
     const std::map<En, std::pair<std::string, std::string>>& colMap;
 };
 
 class SortParser {
 public:
-    SortParser(std::shared_ptr<ColumnMapper> colMapper, const std::string& sortCriteria)
+    SortParser(std::shared_ptr<ColumnMapper> colMapper, std::string sortCriteria)
         : colMapper(std::move(colMapper))
-        , sortCrit(sortCriteria)
+        , sortCrit(std::move(sortCriteria))
     {
     }
     std::string parse();
