@@ -37,117 +37,27 @@
 
 #define DB_BACKUP_FORMAT "{}.backup"
 
-// updates 1->2
-#define SQLITE3_UPDATE_1_2_1 "DROP INDEX mt_autoscan_obj_id"
-#define SQLITE3_UPDATE_1_2_2 "CREATE UNIQUE INDEX mt_autoscan_obj_id ON mt_autoscan(obj_id)"
-#define SQLITE3_UPDATE_1_2_3 "ALTER TABLE \"mt_autoscan\" ADD \"path_ids\" text"
-
-// updates 2->3
-#define SQLITE3_UPDATE_2_3_1 "ALTER TABLE \"mt_cds_object\" ADD \"service_id\" varchar(255) default NULL"
-#define SQLITE3_UPDATE_2_3_2 "CREATE INDEX mt_cds_object_service_id ON mt_cds_object(service_id)"
-
-// updates 3->4: Move to Metadata table
-#define SQLITE3_UPDATE_3_4_1 "CREATE TABLE \"mt_metadata\" ( \
-  \"id\" integer primary key, \
-  \"item_id\" integer NOT NULL, \
-  \"property_name\" varchar(255) NOT NULL, \
-  \"property_value\" text NOT NULL, \
-  CONSTRAINT \"mt_metadata_idfk1\" FOREIGN KEY (\"item_id\") REFERENCES \"mt_cds_object\" (\"id\") \
-  ON DELETE CASCADE ON UPDATE CASCADE )"
-#define SQLITE3_UPDATE_3_4_2 "CREATE INDEX mt_metadata_item_id ON mt_metadata(item_id)"
-
-// updates 4->5: Fix incorrect SQLite foreign key
-#define SQLITE3_UPDATE_4_5_1 "PRAGMA foreign_keys = OFF;  \
-CREATE TABLE mt_cds_object_new \
-( \
-    id integer primary key, \
-    ref_id integer default NULL \
-    constraint cds_object_ibfk_1 \
-        references mt_cds_object (id) \
-            ON update cascade on delete cascade, \
-            parent_id integer default '0' not null \
-    constraint cds_object_ibfk_2 \
-        references mt_cds_object (id) \
-            ON update cascade on delete cascade, \
-            object_type tinyint unsigned not null, \
-    upnp_class varchar(80) default NULL, \
-    dc_title varchar(255) default NULL, \
-    location text default NULL, \
-    location_hash integer unsigned default NULL, \
-    metadata text default NULL, \
-    auxdata text default NULL, \
-    resources text default NULL, \
-    update_id integer default '0' not null, \
-    mime_type varchar(40) default NULL, \
-    flags integer unsigned default '1' not null, \
-    track_number integer default NULL, \
-    service_id varchar(255) default NULL \
-); \
-INSERT INTO mt_cds_object_new(id, ref_id, parent_id, object_type, upnp_class, dc_title, location, location_hash, metadata, auxdata, resources, update_id, mime_type, flags, track_number, service_id) SELECT id, ref_id, parent_id, object_type, upnp_class, dc_title, location, location_hash, metadata, auxdata, resources, update_id, mime_type, flags, track_number, service_id FROM mt_cds_object; \
-DROP TABLE mt_cds_object; \
-ALTER TABLE mt_cds_object_new RENAME TO mt_cds_object; \
-CREATE INDEX mt_cds_object_parent_id ON mt_cds_object (parent_id, object_type, dc_title); \
-CREATE INDEX mt_cds_object_ref_id ON mt_cds_object (ref_id); \
-CREATE INDEX mt_cds_object_service_id ON mt_cds_object (service_id); \
-CREATE INDEX mt_location_parent ON mt_cds_object (location_hash, parent_id); \
-CREATE INDEX mt_object_type ON mt_cds_object (object_type); \
-CREATE INDEX mt_track_number on mt_cds_object (track_number); \
-PRAGMA foreign_keys = ON;"
-
-// updates 5->6: add config value table
-#define SQLITE3_UPDATE_5_6_1 "CREATE TABLE \"grb_config_value\" ( \
-  \"item\" varchar(255) primary key, \
-  \"key\" varchar(255) NOT NULL, \
-  \"item_value\" varchar(255) NOT NULL, \
-  \"status\" varchar(20) NOT NULL)"
-#define SQLITE3_UPDATE_5_6_2 "CREATE INDEX grb_config_value_item ON grb_config_value(item)"
-
-// updates 6->7
-#define SQLITE3_UPDATE_6_7_1 "DROP TABLE mt_cds_active_item;"
-
-// updates 7->8: part_number
-#define SQLITE3_UPDATE_7_8_1 "ALTER TABLE \"mt_cds_object\" ADD \"part_number\" integer default NULL"
-#define SQLITE3_UPDATE_7_8_2 "DROP INDEX mt_track_number"
-#define SQLITE3_UPDATE_7_8_3 "CREATE INDEX \"grb_track_number\" ON mt_cds_object (part_number,track_number)"
-
-// updates 8->9: bookmark_pos
-#define SQLITE3_UPDATE_8_9_1 "ALTER TABLE \"mt_cds_object\" ADD \"bookmark_pos\" integer unsigned NOT NULL default 0"
-
-// updates 9->10: last_modified
-#define SQLITE3_UPDATE_9_10_1 "ALTER TABLE \"mt_cds_object\" ADD \"last_modified\" integer unsigned default NULL"
-
+#define SQLITE3_SET_VERSION "INSERT INTO \"mt_internal_setting\" VALUES('db_version', '{}')"
 #define SQLITE3_UPDATE_VERSION "UPDATE \"mt_internal_setting\" SET \"value\"='{}' WHERE \"key\"='db_version' AND \"value\"='{}'"
+#define SQLITE3_ADD_RESOURCE_ATTR "ALTER TABLE \"grb_cds_resource\" ADD COLUMN \"{}\" varchar(255) default NULL"
 
-static const auto dbUpdates = std::array<std::vector<const char*>, 9> { {
-    { SQLITE3_UPDATE_1_2_1, SQLITE3_UPDATE_1_2_2, SQLITE3_UPDATE_1_2_3 },
-    { SQLITE3_UPDATE_2_3_1, SQLITE3_UPDATE_2_3_2 },
-    { SQLITE3_UPDATE_3_4_1, SQLITE3_UPDATE_3_4_2 },
-    { SQLITE3_UPDATE_4_5_1 },
-    { SQLITE3_UPDATE_5_6_1, SQLITE3_UPDATE_5_6_2 },
-    { SQLITE3_UPDATE_6_7_1 },
-    { SQLITE3_UPDATE_7_8_1, SQLITE3_UPDATE_7_8_2, SQLITE3_UPDATE_7_8_3 },
-    { SQLITE3_UPDATE_8_9_1 },
-    { SQLITE3_UPDATE_9_10_1 },
-} };
-
-Sqlite3Database::Sqlite3Database(std::shared_ptr<Config> config, std::shared_ptr<Timer> timer)
-    : SQLDatabase(std::move(config))
+Sqlite3Database::Sqlite3Database(std::shared_ptr<Config> config, std::shared_ptr<Mime> mime, std::shared_ptr<Timer> timer)
+    : SQLDatabase(std::move(config), std::move(mime))
     , timer(std::move(timer))
-    , shutdownFlag(false)
-    , dirty(false)
-    , dbInitDone(false)
-    , hasBackupTimer(false)
 {
     table_quote_begin = '"';
     table_quote_end = '"';
+
+    // if sqlite3.sql or sqlite3-upgrade.xml is changed hashies have to be updated, index 0 is used for create script
+    hashies = { 3147846384, 778996897, 3362507034, 853149842, 4035419264, 3497064885, 974692115, 119767663, 3167732653, 2427825904, 3305506356, 43189396, 2767540493 };
 }
 
 void Sqlite3Database::prepare()
 {
     _exec("PRAGMA locking_mode = EXCLUSIVE");
     _exec("PRAGMA foreign_keys = ON");
-    _exec("PRAGMA journal_mode = WAL;");
-    SQLDatabase::exec(fmt::format("PRAGMA synchronous = {}", config->getIntOption(CFG_SERVER_STORAGE_SQLITE_SYNCHRONOUS)));
+    _exec("PRAGMA journal_mode = WAL");
+    exec(fmt::format("PRAGMA synchronous = {}", config->getIntOption(CFG_SERVER_STORAGE_SQLITE_SYNCHRONOUS)));
 }
 
 void Sqlite3Database::init()
@@ -213,7 +123,7 @@ void Sqlite3Database::init()
 
     if (dbVersion.empty() && access(dbFilePathbackup.c_str(), R_OK) != 0) {
         log_info("No sqlite3 backup is available or backup is corrupt. Automatically creating new database file...");
-        auto itask = std::make_shared<SLInitTask>(config);
+        auto itask = std::make_shared<SLInitTask>(config, hashies[0]);
         addTask(itask);
         try {
             itask->waitForTask();
@@ -232,27 +142,8 @@ void Sqlite3Database::init()
     }
 
     try {
-        log_debug("db_version: {}", dbVersion.c_str());
-
-        /* --- database upgrades --- */
-        int version = 1;
-        for (auto&& upgrade : dbUpdates) {
-            if (dbVersion == fmt::to_string(version)) {
-                log_info("Running an automatic database upgrade from database version {} to version {}...", version, version + 1);
-                for (auto&& upgradeCmd : upgrade) {
-                    _exec(upgradeCmd);
-                }
-                _exec(fmt::format(SQLITE3_UPDATE_VERSION, version + 1, version).c_str());
-                dbVersion = fmt::to_string(version + 1);
-                log_info("Database upgrade to version {} successful.", dbVersion.c_str());
-            }
-            version++;
-        }
-
-        if (dbVersion != fmt::to_string(version))
-            throw_std_runtime_error("The database seems to be from a newer version");
-
-        if (config->getBoolOption(CFG_SERVER_STORAGE_SQLITE_BACKUP_ENABLED)) {
+        upgradeDatabase(std::move(dbVersion), hashies, CFG_SERVER_STORAGE_SQLITE_UPGRADE_FILE, SQLITE3_UPDATE_VERSION, SQLITE3_ADD_RESOURCE_ATTR);
+        if (config->getBoolOption(CFG_SERVER_STORAGE_SQLITE_BACKUP_ENABLED) && timer) {
             // do a backup now
             auto btask = std::make_shared<SLBackupTask>(config, false);
             this->addTask(btask);
@@ -276,15 +167,18 @@ std::shared_ptr<Database> Sqlite3Database::getSelf()
     return shared_from_this();
 }
 
-void Sqlite3Database::_exec(const char* query)
+void Sqlite3Database::_exec(const std::string& query)
 {
-    exec(query, strlen(query), false);
+    exec(query, false);
 }
 
-std::string Sqlite3Database::quote(std::string value) const
+std::string Sqlite3Database::quote(const std::string& value) const
 {
-    char* q = sqlite3_mprintf("'%q'", value.c_str());
-    std::string ret = q;
+    // https://www.sqlite.org/printf.html#percentq:
+    // The string is printed with all single quote (') characters doubled so that the string can safely appear inside an SQL string literal.
+    // The %Q substitution type also puts single-quotes on both ends of the substituted string.
+    char* q = sqlite3_mprintf("%Q", value.c_str());
+    auto ret = std::string(q);
     sqlite3_free(q);
     return ret;
 }
@@ -295,7 +189,7 @@ std::string Sqlite3Database::getError(const std::string& query, const std::strin
     return fmt::format("SQLITE3: ({}, : {}) {}\nQuery: {}\nerror: {}", sqlite3_errcode(db), sqlite3_extended_errcode(db), sqlite3_errmsg(db), query.empty() ? "unknown" : query, error.empty() ? "unknown" : error);
 }
 
-void Sqlite3Database::beginTransaction(const std::string_view& tName)
+void Sqlite3DatabaseWithTransactions::beginTransaction(const std::string_view& tName)
 {
     if (use_transaction) {
         log_debug("BEGIN TRANSACTION {} {}", tName, inTransaction);
@@ -307,7 +201,7 @@ void Sqlite3Database::beginTransaction(const std::string_view& tName)
     }
 }
 
-void Sqlite3Database::rollback(const std::string_view& tName)
+void Sqlite3DatabaseWithTransactions::rollback(const std::string_view& tName)
 {
     if (use_transaction && inTransaction) {
         log_debug("ROLLBACK {} {}", tName, inTransaction);
@@ -316,7 +210,7 @@ void Sqlite3Database::rollback(const std::string_view& tName)
     }
 }
 
-void Sqlite3Database::commit(const std::string_view& tName)
+void Sqlite3DatabaseWithTransactions::commit(const std::string_view& tName)
 {
     if (use_transaction && inTransaction) {
         log_debug("COMMIT {} {}", tName, inTransaction);
@@ -325,7 +219,7 @@ void Sqlite3Database::commit(const std::string_view& tName)
     }
 }
 
-std::shared_ptr<SQLResult> Sqlite3Database::select(const char* query, int length)
+std::shared_ptr<SQLResult> Sqlite3Database::select(const std::string& query)
 {
     try {
         log_debug("Adding select to Queue: {}", query);
@@ -343,7 +237,7 @@ std::shared_ptr<SQLResult> Sqlite3Database::select(const char* query, int length
     }
 }
 
-int Sqlite3Database::exec(const char* query, int length, bool getLastInsertId)
+int Sqlite3Database::exec(const std::string& query, bool getLastInsertId)
 {
     try {
         log_debug("Adding query to Queue: {}", query);
@@ -456,7 +350,7 @@ void Sqlite3Database::shutdownDriver()
     auto lock = threadRunner->uniqueLockS("shutdown");
     if (!shutdownFlag) {
         shutdownFlag = true;
-        if (hasBackupTimer) {
+        if (hasBackupTimer && timer) {
             timer->removeTimerSubscriber(this, nullptr);
         }
         log_debug("signalling...");
@@ -470,11 +364,9 @@ void Sqlite3Database::shutdownDriver()
 
 void Sqlite3Database::storeInternalSetting(const std::string& key, const std::string& value)
 {
-    std::ostringstream q;
-    q << "INSERT OR REPLACE INTO " << QTB << INTERNAL_SETTINGS_TABLE << QTE << " (" << QTB << "key" << QTE << ", " << QTB << "value" << QTE << ") "
-                                                                                                                                               "VALUES ("
-      << quote(key) << ", " << quote(value) << ") ";
-    SQLDatabase::exec(q.str());
+    auto command = fmt::format("INSERT OR REPLACE INTO {} ({}, {}) VALUES ({}, {})",
+        identifier(INTERNAL_SETTINGS_TABLE), identifier("key"), identifier("value"), quote(key), quote(value));
+    exec(command);
 }
 
 bool SLTask::is_running() const
@@ -513,11 +405,6 @@ void SLTask::waitForTask()
 }
 
 /* SLInitTask */
-SLInitTask::SLInitTask(std::shared_ptr<Config> config)
-    : config(std::move(config))
-{
-}
-
 void SLInitTask::run(sqlite3** db, Sqlite3Database* sl)
 {
     log_debug("Running: init");
@@ -532,32 +419,33 @@ void SLInitTask::run(sqlite3** db, Sqlite3Database* sl)
     auto sqlFilePath = config->getOption(CFG_SERVER_STORAGE_SQLITE_INIT_SQL_FILE);
     log_debug("Loading initialisation SQL from: {}", sqlFilePath.c_str());
     auto sql = readTextFile(sqlFilePath);
+    auto&& myHash = stringHash(sql);
 
-    char* err = nullptr;
-    int ret = sqlite3_exec(
-        *db,
-        sql.c_str(),
-        nullptr,
-        nullptr,
-        &err);
-    std::string error;
-    if (err != nullptr) {
-        error = err;
-        sqlite3_free(err);
+    if (myHash == hashie) {
+        sql += fmt::format("\n" SQLITE3_SET_VERSION ";", DBVERSION);
+
+        char* err = nullptr;
+        int ret = sqlite3_exec(
+            *db,
+            sql.c_str(),
+            nullptr,
+            nullptr,
+            &err);
+        std::string error;
+        if (err) {
+            error = err;
+            sqlite3_free(err);
+        }
+        if (ret != SQLITE_OK) {
+            throw DatabaseException("", sl->getError(sql, error, *db, ret));
+        }
+        contamination = true;
+    } else {
+        log_warning("Wrong hash for create script {}: {} != {}", DBVERSION, myHash, hashie);
     }
-    if (ret != SQLITE_OK) {
-        throw DatabaseException("", sl->getError(sql, error, *db, ret));
-    }
-    contamination = true;
 }
 
 /* SLSelectTask */
-
-SLSelectTask::SLSelectTask(const char* query)
-    : query(query)
-{
-}
-
 void SLSelectTask::run(sqlite3** db, Sqlite3Database* sl)
 {
     log_debug("Running: {}", query);
@@ -572,7 +460,7 @@ void SLSelectTask::run(sqlite3** db, Sqlite3Database* sl)
         &pres->ncolumn,
         &err);
     std::string error;
-    if (err != nullptr) {
+    if (err) {
         log_debug(err);
         error = err;
         sqlite3_free(err);
@@ -587,8 +475,8 @@ void SLSelectTask::run(sqlite3** db, Sqlite3Database* sl)
 
 /* SLExecTask */
 
-SLExecTask::SLExecTask(const char* query, bool getLastInsertId)
-    : query(query)
+SLExecTask::SLExecTask(const std::string& query, bool getLastInsertId)
+    : query(query.c_str())
     , getLastInsertIdFlag(getLastInsertId)
 {
 }
@@ -604,7 +492,7 @@ void SLExecTask::run(sqlite3** db, Sqlite3Database* sl)
         nullptr,
         &err);
     std::string error;
-    if (err != nullptr) {
+    if (err) {
         error = err;
         sqlite3_free(err);
     }
@@ -680,13 +568,6 @@ std::unique_ptr<SQLRow> Sqlite3Result::nextRow()
     return nullptr;
 }
 
-/* Sqlite3Row */
-
-Sqlite3Row::Sqlite3Row(char** row)
-    : row(row)
-{
-}
-
 /* Sqlite3BackupTimerSubscriber */
 
 void Sqlite3Database::timerNotify(std::shared_ptr<Timer::Parameter> param)
