@@ -48,7 +48,7 @@ class ContentManager;
 
 class ProcListItem {
 public:
-    explicit ProcListItem(std::shared_ptr<Executor> exec, bool abortOnDeath = false);
+    explicit ProcListItem(std::shared_ptr<Executor>&& exec, bool abortOnDeath = false);
     std::shared_ptr<Executor> getExecutor();
     bool abortOnDeath() const;
 
@@ -65,8 +65,8 @@ public:
     /// \param procList associated processes that will be terminated once
     /// they are no longer needed
     ProcessIOHandler(std::shared_ptr<ContentManager> content,
-        fs::path filename, const std::shared_ptr<Executor>& mainProc,
-        std::vector<std::shared_ptr<ProcListItem>> procList = std::vector<std::shared_ptr<ProcListItem>>(),
+        fs::path filename, std::shared_ptr<Executor> mainProc,
+        std::vector<std::shared_ptr<ProcListItem>> procList = {},
         bool ignoreSeek = false);
     ~ProcessIOHandler() override;
 
