@@ -40,18 +40,13 @@
 #include "util/string_converter.h"
 #include "util/tools.h"
 
-Exiv2Handler::Exiv2Handler(const std::shared_ptr<Context>& context)
-    : MetadataHandler(context)
-{
-}
-
-void Exiv2Handler::fillMetadata(std::shared_ptr<CdsObject> item)
+void Exiv2Handler::fillMetadata(const std::shared_ptr<CdsObject>& item)
 {
     try {
         std::string value;
         const auto sc = StringConverter::m2i(CFG_IMPORT_LIBOPTS_EXIV2_CHARSET, item->getLocation(), config);
 
-        const auto image = Exiv2::ImageFactory::open(item->getLocation().string());
+        const auto image = Exiv2::ImageFactory::open(item->getLocation());
         image->readMetadata();
         Exiv2::ExifData& exifData = image->exifData();
         Exiv2::XmpData& xmpData = image->xmpData();
@@ -171,13 +166,12 @@ void Exiv2Handler::fillMetadata(std::shared_ptr<CdsObject> item)
         } else {
             log_debug("No aux data requested");
         }
-
     } catch (Exiv2::AnyError& ex) {
         log_warning("Caught Exiv2 exception processing {}: '{}'", item->getLocation().c_str(), ex.what());
     }
 }
 
-std::unique_ptr<IOHandler> Exiv2Handler::serveContent(std::shared_ptr<CdsObject> item, int resNum)
+std::unique_ptr<IOHandler> Exiv2Handler::serveContent(const std::shared_ptr<CdsObject>& item, int resNum)
 {
     return nullptr;
 }
