@@ -41,8 +41,8 @@ public:
         : MetadataHandler(context)
     {
     }
-    void fillMetadata(std::shared_ptr<CdsObject> item) override;
-    std::unique_ptr<IOHandler> serveContent(std::shared_ptr<CdsObject> item, int resNum) override;
+    void fillMetadata(const std::shared_ptr<CdsObject>& item) override;
+    std::unique_ptr<IOHandler> serveContent(const std::shared_ptr<CdsObject>& item, int resNum) override;
 };
 
 #endif // __METADATA_EXIV2_H__
