@@ -62,7 +62,7 @@ public:
         : file(fopen(path, "rb"))
 #endif
     {
-        if (file == nullptr) {
+        if (!file) {
             throw_std_runtime_error("Could not fopen {}", path);
         }
     }
@@ -77,7 +77,7 @@ public:
 
     uint32 read(void* buffer, size_t size) override
     {
-        assert(file != nullptr);
+        assert(file);
         if (size == 0)
             return 0;
         return fread(buffer, 1, size, file);
@@ -85,7 +85,7 @@ public:
 
     void setFilePointer(int64_t offset, seek_mode mode = seek_beginning) override
     {
-        assert(file != nullptr);
+        assert(file);
         assert(mode == SEEK_CUR || mode == SEEK_END || mode == SEEK_SET);
         if (fseeko(file, offset, mode) != 0) {
             throw_std_runtime_error("fseek failed");
@@ -100,63 +100,56 @@ public:
 
     uint64 getFilePointer() override
     {
-        assert(file != nullptr);
+        assert(file);
         return ftello(file);
     }
 
     void close() override
     {
-        if (file == nullptr)
+        if (!file)
             return;
         if (fclose(file) != 0) {
-            throw_std_runtime_error("fclose failed");
+            log_error("fclose failed");
         }
         file = nullptr;
     }
 };
 
-MatroskaHandler::MatroskaHandler(const std::shared_ptr<Context>& context)
-    : MetadataHandler(context)
-{
-}
-
-void MatroskaHandler::fillMetadata(std::shared_ptr<CdsObject> obj)
+void MatroskaHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
 {
     auto item = std::dynamic_pointer_cast<CdsItem>(obj);
-    if (item == nullptr)
+    if (!item)
         return;
 
     parseMKV(item, nullptr);
 }
 
-std::unique_ptr<IOHandler> MatroskaHandler::serveContent(std::shared_ptr<CdsObject> obj, int resNum)
+std::unique_ptr<IOHandler> MatroskaHandler::serveContent(const std::shared_ptr<CdsObject>& obj, int resNum)
 {
     auto item = std::dynamic_pointer_cast<CdsItem>(obj);
-    if (item == nullptr)
+    if (!item)
         return nullptr;
 
-    MemIOHandler* io_handler = nullptr;
+    std::unique_ptr<MemIOHandler> io_handler;
     parseMKV(item, &io_handler);
 
-    return std::unique_ptr<IOHandler>(io_handler);
+    return std::move(io_handler);
 }
 
-void MatroskaHandler::parseMKV(const std::shared_ptr<CdsItem>& item, MemIOHandler** p_io_handler) const
+void MatroskaHandler::parseMKV(const std::shared_ptr<CdsItem>& item, std::unique_ptr<MemIOHandler>* p_io_handler) const
 {
-    file_io_callback ebml_file(item->getLocation().c_str());
-    EbmlStream ebml_stream(ebml_file);
+    auto ebml_file = file_io_callback(item->getLocation().c_str());
+    auto ebml_stream = EbmlStream(ebml_file);
 
     auto el_l0 = ebml_stream.FindNextID(LIBMATROSKA_NAMESPACE::KaxSegment::ClassInfos, ~0);
-    while (el_l0 != nullptr) {
+    while (el_l0) {
         int i_upper_level = 0;
-        auto el_l1 = ebml_stream.FindNextElement(el_l0->Generic().Context, i_upper_level, ~0, true);
-        while (el_l1 != nullptr) {
+        EbmlElement* el_l1;
+        while ((el_l1 = ebml_stream.FindNextElement(el_l0->Generic().Context, i_upper_level, ~0, true))) {
             parseLevel1Element(item, ebml_stream, el_l1, p_io_handler);
 
             el_l1->SkipData(ebml_stream, el_l1->Generic().Context);
             delete el_l1;
-
-            el_l1 = ebml_stream.FindNextElement(el_l0->Generic().Context, i_upper_level, ~0, true);
         } // while elementLevel1
 
         el_l0->SkipData(ebml_stream, LIBMATROSKA_NAMESPACE::KaxSegment_Context);
@@ -168,13 +161,13 @@ void MatroskaHandler::parseMKV(const std::shared_ptr<CdsItem>& item, MemIOHandle
     ebml_file.close();
 }
 
-void MatroskaHandler::parseLevel1Element(const std::shared_ptr<CdsItem>& item, EbmlStream& ebml_stream, EbmlElement* el_l1, MemIOHandler** p_io_handler) const
+void MatroskaHandler::parseLevel1Element(const std::shared_ptr<CdsItem>& item, EbmlStream& ebml_stream, EbmlElement* el_l1, std::unique_ptr<MemIOHandler>* p_io_handler) const
 {
     // Looking at just at EbmlId is not reliable since it can be a dummy element.
     if (!el_l1->IsMaster())
         return;
     auto master = dynamic_cast<EbmlMaster*>(el_l1);
-    if (master == nullptr) {
+    if (!master) {
         log_debug("dynamic_cast unexpectedly returned nullptr, seems to be broken");
         return;
     }
@@ -198,7 +191,7 @@ void MatroskaHandler::parseInfo(const std::shared_ptr<CdsItem>& item, EbmlStream
     for (auto&& el : *info) {
         if (EbmlId(*el) == LIBMATROSKA_NAMESPACE::KaxTitle::ClassInfos.GlobalId) {
             auto title_el = dynamic_cast<LIBMATROSKA_NAMESPACE::KaxTitle*>(el);
-            if (title_el == nullptr) {
+            if (!title_el) {
                 log_error("Malformed MKV file; KaxTitle cast failed!");
                 continue;
             }
@@ -207,7 +200,7 @@ void MatroskaHandler::parseInfo(const std::shared_ptr<CdsItem>& item, EbmlStream
             item->setMetadata(M_TITLE, sc->convert(title));
         } else if (EbmlId(*el) == LIBMATROSKA_NAMESPACE::KaxDateUTC::ClassInfos.GlobalId) {
             auto date_el = dynamic_cast<LIBMATROSKA_NAMESPACE::KaxDateUTC*>(el);
-            if (date_el == nullptr) {
+            if (!date_el) {
                 log_error("Malformed MKV file; KaxDateUTC cast failed!");
                 continue;
             }
@@ -220,7 +213,7 @@ void MatroskaHandler::parseInfo(const std::shared_ptr<CdsItem>& item, EbmlStream
     }
 }
 
-void MatroskaHandler::parseAttachments(const std::shared_ptr<CdsItem>& item, EbmlStream& ebml_stream, EbmlMaster* attachments, MemIOHandler** p_io_handler) const
+void MatroskaHandler::parseAttachments(const std::shared_ptr<CdsItem>& item, EbmlStream& ebml_stream, EbmlMaster* attachments, std::unique_ptr<MemIOHandler>* p_io_handler) const
 {
     EbmlElement* dummy_el;
     int i_upper_level = 0;
@@ -233,12 +226,12 @@ void MatroskaHandler::parseAttachments(const std::shared_ptr<CdsItem>& item, Ebm
         log_debug("KaxFileName = {}", fileName);
 
         if (startswith(fileName, "cover")) {
-            auto&& fileData = GetChild<LIBMATROSKA_NAMESPACE::KaxFileData>(*attachedFile);
+            const auto& fileData = GetChild<LIBMATROSKA_NAMESPACE::KaxFileData>(*attachedFile);
             log_debug("KaxFileData (size={})", fileData.GetSize());
 
-            if (p_io_handler != nullptr) {
+            if (p_io_handler) {
                 // serveContent
-                *p_io_handler = new MemIOHandler(fileData.GetBuffer(), fileData.GetSize());
+                *p_io_handler = std::make_unique<MemIOHandler>(fileData.GetBuffer(), fileData.GetSize());
             } else {
                 // fillMetadata
                 std::string art_mimetype = getContentTypeFromByteVector(&fileData);
@@ -253,14 +246,12 @@ void MatroskaHandler::parseAttachments(const std::shared_ptr<CdsItem>& item, Ebm
 
 std::string MatroskaHandler::getContentTypeFromByteVector(const LIBMATROSKA_NAMESPACE::KaxFileData* data) const
 {
-    std::string art_mimetype = MIMETYPE_DEFAULT;
 #ifdef HAVE_MAGIC
-    art_mimetype = mime->bufferToMimeType(data->GetBuffer(), data->GetSize());
-    if (art_mimetype.empty()) {
-        return MIMETYPE_DEFAULT;
-    }
+    auto art_mimetype = mime->bufferToMimeType(data->GetBuffer(), data->GetSize());
+    return art_mimetype.empty() ? MIMETYPE_DEFAULT : art_mimetype;
+#else
+    return MIMETYPE_DEFAULT;
 #endif
-    return art_mimetype;
 }
 
 void MatroskaHandler::addArtworkResource(const std::shared_ptr<CdsItem>& item, const std::string& art_mimetype)
@@ -273,7 +264,7 @@ void MatroskaHandler::addArtworkResource(const std::shared_ptr<CdsItem>& item, c
         auto resource = std::make_shared<CdsResource>(CH_MATROSKA);
         resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo(art_mimetype));
         resource->addParameter(RESOURCE_CONTENT_TYPE, ID3_ALBUM_ART);
-        item->addResource(resource);
+        item->addResource(move(resource));
     }
 }
 
