@@ -67,7 +67,7 @@ std::vector<fs::path> ContentPathSetup::getContentPath(const std::shared_ptr<Cds
                     continue;
 
                 log_debug("{}: found", found.c_str());
-                result.push_back(found);
+                result.push_back(std::move(found));
             }
         } else {
             std::map<std::string, fs::path> fileNames;
@@ -126,7 +126,7 @@ std::vector<fs::path> ContentPathSetup::getContentPath(const std::shared_ptr<Cds
         }
     }
     if (result.empty())
-        result.push_back("");
+        result.emplace_back();
     return result;
 }
 
@@ -169,7 +169,7 @@ FanArtHandler::FanArtHandler(const std::shared_ptr<Context>& context)
     }
 }
 
-void FanArtHandler::fillMetadata(std::shared_ptr<CdsObject> obj)
+void FanArtHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
 {
     log_debug("Running fanart handler on {}", obj->getLocation().c_str());
     auto pathList = setup->getContentPath(obj, SETTING_FANART);
@@ -191,7 +191,7 @@ void FanArtHandler::fillMetadata(std::shared_ptr<CdsObject> obj)
     }
 }
 
-std::unique_ptr<IOHandler> FanArtHandler::serveContent(std::shared_ptr<CdsObject> obj, int resNum)
+std::unique_ptr<IOHandler> FanArtHandler::serveContent(const std::shared_ptr<CdsObject>& obj, int resNum)
 {
     fs::path path = obj->getResource(resNum)->getAttribute(R_RESOURCE_FILE);
     if (path.empty()) {
@@ -217,7 +217,7 @@ ContainerArtHandler::ContainerArtHandler(const std::shared_ptr<Context>& context
     }
 }
 
-void ContainerArtHandler::fillMetadata(std::shared_ptr<CdsObject> obj)
+void ContainerArtHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
 {
     auto pathList = setup->getContentPath(obj, SETTING_CONTAINERART, config->getOption(CFG_IMPORT_RESOURCES_CONTAINERART_LOCATION));
     if (pathList.empty() || pathList[0].empty()) {
@@ -242,7 +242,7 @@ void ContainerArtHandler::fillMetadata(std::shared_ptr<CdsObject> obj)
     }
 }
 
-std::unique_ptr<IOHandler> ContainerArtHandler::serveContent(std::shared_ptr<CdsObject> obj, int resNum)
+std::unique_ptr<IOHandler> ContainerArtHandler::serveContent(const std::shared_ptr<CdsObject>& obj, int resNum)
 {
     fs::path path = obj->getResource(resNum)->getAttribute(R_RESOURCE_FILE);
     if (path.empty()) {
@@ -271,7 +271,7 @@ SubtitleHandler::SubtitleHandler(const std::shared_ptr<Context>& context)
     }
 }
 
-void SubtitleHandler::fillMetadata(std::shared_ptr<CdsObject> obj)
+void SubtitleHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
 {
     auto pathList = setup->getContentPath(obj, SETTING_SUBTITLE);
 
@@ -300,7 +300,7 @@ void SubtitleHandler::fillMetadata(std::shared_ptr<CdsObject> obj)
     }
 }
 
-std::unique_ptr<IOHandler> SubtitleHandler::serveContent(std::shared_ptr<CdsObject> obj, int resNum)
+std::unique_ptr<IOHandler> SubtitleHandler::serveContent(const std::shared_ptr<CdsObject>& obj, int resNum)
 {
     fs::path path = obj->getResource(resNum)->getAttribute(R_RESOURCE_FILE);
     if (path.empty()) {
@@ -326,7 +326,7 @@ ResourceHandler::ResourceHandler(const std::shared_ptr<Context>& context)
     }
 }
 
-void ResourceHandler::fillMetadata(std::shared_ptr<CdsObject> obj)
+void ResourceHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
 {
     auto pathList = setup->getContentPath(obj, SETTING_RESOURCE);
 
@@ -345,7 +345,7 @@ void ResourceHandler::fillMetadata(std::shared_ptr<CdsObject> obj)
     }
 }
 
-std::unique_ptr<IOHandler> ResourceHandler::serveContent(std::shared_ptr<CdsObject> obj, int resNum)
+std::unique_ptr<IOHandler> ResourceHandler::serveContent(const std::shared_ptr<CdsObject>& obj, int resNum)
 {
     fs::path path = obj->getResource(resNum)->getAttribute(R_RESOURCE_FILE);
     if (path.empty()) {
