@@ -28,67 +28,77 @@
 #define __METADATA_CONTENT_H__
 
 #include <filesystem>
+#include <map>
 namespace fs = std::filesystem;
 
+#include "config/config.h"
 #include "metadata_handler.h"
 
+class ContentPathSetup {
+public:
+    explicit ContentPathSetup(std::shared_ptr<Config> config, config_option_t fileListOption, config_option_t dirListOption);
+    std::vector<fs::path> getContentPath(const std::shared_ptr<CdsObject>& obj, const std::string& setting, fs::path folder = "");
+
+private:
+    std::shared_ptr<Config> config;
+    std::vector<std::string> names;
+    std::map<std::string, std::string> patterns;
+    std::shared_ptr<DirectoryConfigList> allTweaks;
+    static std::string expandName(std::string_view name, const std::shared_ptr<CdsObject>& obj);
+    bool caseSensitive;
+};
+
 /// \brief This class is responsible for populating filesystem based metadata
 class MetacontentHandler : public MetadataHandler {
 public:
-    explicit MetacontentHandler(const std::shared_ptr<Context>& context);
-    static bool caseSensitive;
-
-protected:
-    static fs::path getContentPath(const std::vector<std::string>& names, const std::shared_ptr<CdsObject>& obj, bool isCaseSensitive, fs::path folder = "");
-    static std::string expandName(const std::string& name, const std::shared_ptr<CdsObject>& obj);
+    explicit MetacontentHandler(const std::shared_ptr<Context>& context)
+        : MetadataHandler(context)
+    {
+    }
 };
 
 /// \brief This class is responsible for populating filesystem based album and fan art
 class FanArtHandler : public MetacontentHandler {
 public:
     explicit FanArtHandler(const std::shared_ptr<Context>& context);
-    void fillMetadata(std::shared_ptr<CdsObject> obj) override;
-    std::unique_ptr<IOHandler> serveContent(std::shared_ptr<CdsObject> obj, int resNum) override;
+    void fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
+    std::unique_ptr<IOHandler> serveContent(const std::shared_ptr<CdsObject>& obj, int resNum) override;
 
 private:
-    static std::vector<std::string> names;
-    static bool initDone;
+    static std::unique_ptr<ContentPathSetup> setup;
 };
 
 /// \brief This class is responsible for populating filesystem based album and fan art
 class ContainerArtHandler : public MetacontentHandler {
 public:
     explicit ContainerArtHandler(const std::shared_ptr<Context>& context);
-    void fillMetadata(std::shared_ptr<CdsObject> obj) override;
-    std::unique_ptr<IOHandler> serveContent(std::shared_ptr<CdsObject> obj, int resNum) override;
+    void fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
+    std::unique_ptr<IOHandler> serveContent(const std::shared_ptr<CdsObject>& obj, int resNum) override;
 
 private:
-    static std::vector<std::string> names;
-    static bool initDone;
+    static std::unique_ptr<ContentPathSetup> setup;
 };
 
 /// \brief This class is responsible for populating filesystem based subtitles
 class SubtitleHandler : public MetacontentHandler {
 public:
     explicit SubtitleHandler(const std::shared_ptr<Context>& context);
-    void fillMetadata(std::shared_ptr<CdsObject> obj) override;
-    std::unique_ptr<IOHandler> serveContent(std::shared_ptr<CdsObject> obj, int resNum) override;
+    void fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
+    std::unique_ptr<IOHandler> serveContent(const std::shared_ptr<CdsObject>& obj, int resNum) override;
 
 private:
-    static std::vector<std::string> names;
-    static bool initDone;
+    static std::unique_ptr<ContentPathSetup> setup;
 };
 
 /// \brief This class is responsible for reverse mapping filesystem based resources
 class ResourceHandler : public MetacontentHandler {
 public:
     explicit ResourceHandler(const std::shared_ptr<Context>& context);
-    void fillMetadata(std::shared_ptr<CdsObject> obj) override;
-    std::unique_ptr<IOHandler> serveContent(std::shared_ptr<CdsObject> obj, int resNum) override;
+    void fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
+    std::unique_ptr<IOHandler> serveContent(const std::shared_ptr<CdsObject>& obj, int resNum) override;
 
 private:
-    static std::vector<std::string> names;
-    static bool initDone;
+    static std::unique_ptr<ContentPathSetup> setup;
 };
 
 #endif // __METADATA_CONTENT_H__
