@@ -61,7 +61,6 @@
 
 Server::Server(std::shared_ptr<Config> config)
     : config(std::move(config))
-    , server_shutdown_flag(false)
 {
 }
 
@@ -83,7 +82,7 @@ void Server::init()
     clients = std::make_shared<Clients>(config);
     mime = std::make_shared<Mime>(config);
     timer->run();
-    database = Database::createInstance(config, timer);
+    database = Database::createInstance(config, mime, timer);
     config->updateConfigFromDatabase(database);
     session_manager = std::make_shared<web::SessionManager>(config, timer);
     context = std::make_shared<Context>(config, clients, mime, database, self, session_manager);
@@ -150,7 +149,7 @@ void Server::run()
     std::string presentationURL = getPresentationUrl();
 
     log_debug("Creating UpnpXMLBuilder");
-    xmlbuilder = std::make_unique<UpnpXMLBuilder>(context, virtualUrl, presentationURL);
+    xmlbuilder = std::make_shared<UpnpXMLBuilder>(context, virtualUrl, presentationURL);
 
     // register root device with the library
     auto desc = xmlbuilder->renderDeviceDescription();
@@ -216,7 +215,7 @@ int Server::startupInterface(const std::string& iface, in_port_t inPort)
     const char* ifName = iface.empty() ? nullptr : iface.c_str();
 
     int ret = UPNP_E_INIT_FAILED;
-    for (int attempt = 0; ret != UPNP_E_SUCCESS; attempt++) {
+    for (size_t attempt = 0; ret != UPNP_E_SUCCESS; attempt++) {
         ret = UpnpInit2(ifName, inPort);
         if (ret != UPNP_E_SUCCESS) {
             if (attempt > 3) {
@@ -244,7 +243,7 @@ int Server::startupInterface(const std::string& iface, in_port_t inPort)
     return ret;
 }
 
-std::string Server::getPresentationUrl()
+std::string Server::getPresentationUrl() const
 {
     std::string presentationURL = config->getOption(CFG_SERVER_PRESENTATION_URL);
     if (presentationURL.empty()) {
@@ -280,7 +279,7 @@ void Server::emptyBookmark()
     writeTextFile(path, data);
 }
 
-std::string Server::getVirtualUrl()
+std::string Server::getVirtualUrl() const
 {
     auto cfgVirt = config->getOption(CFG_VIRTUAL_URL);
     return cfgVirt.empty() ? virtualUrl : fmt::format("{}/{}", cfgVirt, virtual_directory);
@@ -352,14 +351,13 @@ int Server::handleUpnpRootDeviceEvent(Upnp_EventType eventType, const void* even
     log_debug("start");
 
     // check parameters
-    if (event == nullptr) {
+    if (!event) {
         log_debug("handleUpnpRootDeviceEvent: NULL event structure");
         return UPNP_E_BAD_REQUEST;
     }
 
     // dispatch event based on event type
     switch (eventType) {
-
     case UPNP_CONTROL_ACTION_REQUEST:
         log_debug("UPNP_CONTROL_ACTION_REQUEST");
         try {
@@ -404,7 +402,7 @@ int Server::handleUpnpClientEventCallback(Upnp_EventType eventType, const void*
 int Server::handleUpnpClientEvent(Upnp_EventType eventType, const void* event)
 {
     // check parameters
-    if (event == nullptr) {
+    if (!event) {
         log_debug("handleUpnpClientEvent: NULL event structure");
         return UPNP_E_BAD_REQUEST;
     }
@@ -413,17 +411,9 @@ int Server::handleUpnpClientEvent(Upnp_EventType eventType, const void* event)
     case UPNP_DISCOVERY_ADVERTISEMENT_ALIVE:
     case UPNP_DISCOVERY_SEARCH_RESULT: {
         auto d_event = reinterpret_cast<const UpnpDiscovery*>(event);
-#if defined(USING_NPUPNP)
         const char* userAgent = UpnpDiscovery_get_Os_cstr(d_event);
-#else
-        const char* userAgent = UpnpString_get_String(UpnpDiscovery_get_Os(d_event));
-#endif
         const struct sockaddr_storage* destAddr = UpnpDiscovery_get_DestAddr(d_event);
-#if defined(USING_NPUPNP)
         const char* location = UpnpDiscovery_get_Location_cstr(d_event);
-#else
-        const char* location = UpnpString_get_String(UpnpDiscovery_get_Location(d_event));
-#endif
 
         clients->addClientByDiscovery(destAddr, userAgent, location);
         break;
@@ -502,11 +492,11 @@ std::unique_ptr<RequestHandler> Server::createRequestHandler(const char* filenam
     std::string link = urlUnescape(filename);
     log_debug("Filename: {}", filename);
 
-    std::unique_ptr<RequestHandler> ret = nullptr;
-
     if (startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, CONTENT_MEDIA_HANDLER))) {
-        ret = std::make_unique<FileRequestHandler>(content, xmlbuilder.get());
-    } else if (startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, CONTENT_UI_HANDLER))) {
+        return std::make_unique<FileRequestHandler>(content, xmlbuilder);
+    }
+
+    if (startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, CONTENT_UI_HANDLER))) {
         std::string parameters;
         std::string path;
         RequestHandler::splitUrl(filename, URL_UI_PARAM_SEPARATOR, path, parameters);
@@ -517,26 +507,28 @@ std::unique_ptr<RequestHandler> Server::createRequestHandler(const char* filenam
         auto it = params.find(URL_REQUEST_TYPE);
         std::string r_type = it != params.end() && !it->second.empty() ? it->second : "index";
 
-        ret = web::createWebRequestHandler(content, r_type);
-    } else if (startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, DEVICE_DESCRIPTION_PATH))) {
-        ret = std::make_unique<DeviceDescriptionHandler>(content, xmlbuilder.get());
-    } else if (startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, CONTENT_SERVE_HANDLER))) {
-        if (config->getOption(CFG_SERVER_SERVEDIR).empty())
-            throw_std_runtime_error("Serving directories is not enabled in configuration");
+        return web::createWebRequestHandler(context, content, xmlbuilder, r_type);
+    }
 
-        ret = std::make_unique<ServeRequestHandler>(content);
+    if (startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, DEVICE_DESCRIPTION_PATH))) {
+        return std::make_unique<DeviceDescriptionHandler>(content, xmlbuilder.get());
+    }
+
+    if (startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, CONTENT_SERVE_HANDLER))) {
+        if (config->getOption(CFG_SERVER_SERVEDIR).empty()) {
+            throw_std_runtime_error("Serving directories is not enabled in configuration");
+        }
+
+        return std::make_unique<ServeRequestHandler>(content);
     }
 
 #if defined(HAVE_CURL)
-    else if (startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, CONTENT_ONLINE_HANDLER))) {
-        ret = std::make_unique<URLRequestHandler>(content);
+    if (startswith(link, fmt::format("/{}/{}", SERVER_VIRTUAL_DIR, CONTENT_ONLINE_HANDLER))) {
+        return std::make_unique<URLRequestHandler>(content);
     }
 #endif
-    else {
-        throw_std_runtime_error("No valid handler type in {}", filename);
-    }
 
-    return ret;
+    throw_std_runtime_error("No valid handler type in {}", filename);
 }
 
 int Server::registerVirtualDirCallbacks()
@@ -558,7 +550,7 @@ int Server::registerVirtualDirCallbacks()
             return -1;
         }
     });
-    if (ret != 0)
+    if (ret != UPNP_E_SUCCESS)
         return ret;
 
     log_debug("Setting UpnpVirtualDir OpenCallback");
@@ -622,7 +614,7 @@ int Server::registerVirtualDirCallbacks()
     ret = UpnpVirtualDir_set_CloseCallback([](UpnpWebFileHandle f, const void* cookie, const void* requestCookie) -> int {
         //log_debug("{} close()", f);
         int ret_close = 0;
-        auto handler = static_cast<IOHandler*>(f);
+        auto handler = std::unique_ptr<IOHandler>(static_cast<IOHandler*>(f));
         try {
             handler->close();
         } catch (const std::runtime_error& e) {
@@ -630,9 +622,6 @@ int Server::registerVirtualDirCallbacks()
             ret_close = -1;
         }
 
-        delete handler;
-        handler = nullptr;
-
         return ret_close;
     });
 
