@@ -49,6 +49,10 @@ class ContentManager;
 class Server : public std::enable_shared_from_this<Server> {
 public:
     explicit Server(std::shared_ptr<Config> config);
+    virtual ~Server();
+
+    Server(const Server&) = delete;
+    Server& operator=(const Server&) = delete;
 
     /// \brief Initializes the server.
     ///
@@ -56,8 +60,6 @@ public:
     /// various variables (like server UDN and so forth).
     virtual void init();
 
-    virtual ~Server();
-
     /// \brief Cleanup routine to shutdown the server.
     ///
     /// Unregisters the device with the SDK, shuts down the
@@ -78,7 +80,7 @@ public:
     /// the port is also specified in the config, we can never be sure
     /// that we actually get that port after startup. This function
     /// contains the port on which the server is actually running.
-    std::string getVirtualUrl();
+    std::string getVirtualUrl() const;
 
     /// \brief Tells if the server is about to be terminated.
     ///
@@ -102,14 +104,14 @@ protected:
     std::shared_ptr<ContentManager> content;
 
     std::string ip;
-    in_port_t port;
+    in_port_t port {};
 
     /// \brief This flag is set to true by the upnp_cleanup() function.
-    bool server_shutdown_flag;
+    bool server_shutdown_flag {};
 
     /// \brief Handle for our upnp callbacks.
-    UpnpDevice_Handle rootDeviceHandle;
-    UpnpDevice_Handle clientHandle;
+    UpnpDevice_Handle rootDeviceHandle {};
+    UpnpDevice_Handle clientHandle {};
 
     /// \brief Unique Device Number of the server.
     ///
@@ -143,9 +145,9 @@ protected:
     /// \brief Time interval to send ssdp:alive advertisements.
     ///
     /// The value is read from the configuration.
-    int aliveAdvertisementInterval;
+    int aliveAdvertisementInterval {};
 
-    std::unique_ptr<UpnpXMLBuilder> xmlbuilder;
+    std::shared_ptr<UpnpXMLBuilder> xmlbuilder;
 
     /// \brief ContentDirectoryService instance.
     ///
@@ -231,7 +233,7 @@ protected:
     void writeBookmark(const std::string& addr);
     void emptyBookmark();
 
-    std::string getPresentationUrl();
+    std::string getPresentationUrl() const;
     int startupInterface(const std::string& iface, in_port_t port);
 };
 
