@@ -31,7 +31,7 @@
 
 #include "upnp_cds.h" // API
 
-#include <memory>
+#include <sstream>
 #include <string>
 #include <vector>
 
@@ -42,8 +42,7 @@
 
 ContentDirectoryService::ContentDirectoryService(const std::shared_ptr<Context>& context,
     UpnpXMLBuilder* xmlBuilder, UpnpDevice_Handle deviceHandle, int stringLimit)
-    : systemUpdateID(0)
-    , stringLimit(stringLimit)
+    : stringLimit(stringLimit)
     , config(context->getConfig())
     , database(context->getDatabase())
     , deviceHandle(deviceHandle)
@@ -72,11 +71,10 @@ void ContentDirectoryService::doBrowse(const std::unique_ptr<ActionRequest>& req
     log_debug("Browse received parameters: ObjectID [{}] BrowseFlag [{}] StartingIndex [{}] RequestedCount [{}] SortCriteria [{}]",
         objID.c_str(), browseFlag.c_str(), startingIndex.c_str(), requestedCount.c_str(), sortCriteria.c_str());
 
-    int objectID;
     if (objID.empty())
         throw UpnpException(UPNP_E_NO_SUCH_ID, "empty object id");
 
-    objectID = stoiString(objID);
+    int objectID = stoiString(objID);
 
     unsigned int flag = BROWSE_ITEMS | BROWSE_CONTAINERS | BROWSE_EXACT_CHILDCOUNT;
 
@@ -93,7 +91,7 @@ void ContentDirectoryService::doBrowse(const std::unique_ptr<ActionRequest>& req
     if (config->getBoolOption(CFG_SERVER_HIDE_PC_DIRECTORY))
         flag |= BROWSE_HIDE_FS_ROOT;
 
-    auto param = std::make_unique<BrowseParam>(objectID, flag);
+    auto param = std::make_unique<BrowseParam>(parent, flag);
 
     param->setStartingIndex(stoiString(startingIndex));
     param->setRequestedCount(stoiString(requestedCount));
@@ -131,9 +129,7 @@ void ContentDirectoryService::doBrowse(const std::unique_ptr<ActionRequest>& req
         xmlBuilder->renderObject(obj, stringLimit, &didl_lite_root, request->getQuirks());
     }
 
-    std::ostringstream buf;
-    didl_lite.print(buf, "", 0);
-    std::string didl_lite_xml = buf.str();
+    std::string didl_lite_xml = UpnpXMLBuilder::printXml(didl_lite, "", 0);
     log_debug("didl {}", didl_lite_xml);
 
     auto response = UpnpXMLBuilder::createResponse(request->getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
@@ -204,9 +200,7 @@ void ContentDirectoryService::doSearch(const std::unique_ptr<ActionRequest>& req
         xmlBuilder->renderObject(cdsObject, stringLimit, &didl_lite_root);
     }
 
-    std::ostringstream buf;
-    didl_lite.print(buf, "", 0);
-    std::string didl_lite_xml = buf.str();
+    std::string didl_lite_xml = UpnpXMLBuilder::printXml(didl_lite, "", 0);
     log_debug("didl {}", didl_lite_xml);
 
     auto response = UpnpXMLBuilder::createResponse(request->getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
@@ -226,7 +220,7 @@ void ContentDirectoryService::doGetSearchCapabilities(const std::unique_ptr<Acti
 
     auto response = UpnpXMLBuilder::createResponse(request->getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
     auto root = response->document_element();
-    root.append_child("SearchCaps").append_child(pugi::node_pcdata).set_value("dc:title,upnp:class,upnp:artist,upnp:album");
+    root.append_child("SearchCaps").append_child(pugi::node_pcdata).set_value(SQLDatabase::getSearchCapabilities().c_str());
     request->setResponse(std::move(response));
 
     log_debug("end");
@@ -274,6 +268,24 @@ void ContentDirectoryService::doSamsungFeatureList(const std::unique_ptr<ActionR
     log_debug("end");
 }
 
+void ContentDirectoryService::doSamsungGetObjectIDfromIndex(const std::unique_ptr<ActionRequest>& request)
+{
+    log_debug("start");
+
+    request->getQuirks()->getSamsungObjectIDfromIndex(request);
+
+    log_debug("end");
+}
+
+void ContentDirectoryService::doSamsungGetIndexfromRID(const std::unique_ptr<ActionRequest>& request)
+{
+    log_debug("start");
+
+    request->getQuirks()->getSamsungIndexfromRID(request);
+
+    log_debug("end");
+}
+
 void ContentDirectoryService::processActionRequest(const std::unique_ptr<ActionRequest>& request)
 {
     log_debug("start");
@@ -292,6 +304,10 @@ void ContentDirectoryService::processActionRequest(const std::unique_ptr<ActionR
         doSamsungBookmark(request);
     } else if (request->getActionName() == "X_GetFeatureList") {
         doSamsungFeatureList(request);
+    } else if (request->getActionName() == "X_GetObjectIDfromIndex") {
+        doSamsungGetObjectIDfromIndex(request);
+    } else if (request->getActionName() == "X_GetIndexfromRID") {
+        doSamsungGetIndexfromRID(request);
     } else {
         // invalid or unsupported action
         log_warning("Unrecognized action {}", request->getActionName().c_str());
