@@ -53,7 +53,7 @@ protected:
     /// devices.
     /// Also, this variable is returned by the upnp_action_GetSystemUpdateID()
     /// action.
-    int systemUpdateID;
+    int systemUpdateID {};
 
     /// \brief All strings in the XML will be cut at this length.
     int stringLimit;
@@ -102,6 +102,14 @@ protected:
     ///
     static void doSamsungFeatureList(const std::unique_ptr<ActionRequest>& request);
 
+    /// \brief Samsung Extension X_GetObjectIDfromIndex
+    /// \param request Incoming ActionRequest.
+    static void doSamsungGetObjectIDfromIndex(const std::unique_ptr<ActionRequest>& request);
+
+    /// \brief Samsung Extension X_GetIndexfromRID
+    /// \param request Incoming ActionRequest.
+    static void doSamsungGetIndexfromRID(const std::unique_ptr<ActionRequest>& request);
+
     std::shared_ptr<Config> config;
     std::shared_ptr<Database> database;
 
@@ -113,7 +121,6 @@ public:
     /// in internal variables.
     explicit ContentDirectoryService(const std::shared_ptr<Context>& context,
         UpnpXMLBuilder* builder, UpnpDevice_Handle deviceHandle, int stringLimit);
-    virtual ~ContentDirectoryService() = default;
 
     /// \brief Dispatches the ActionRequest between the available actions.
     /// \param request ActionRequest to be processed by the function.
