@@ -31,6 +31,8 @@
 
 #include "upnp_xml.h" // API
 
+#include <sstream>
+
 #include "config/config_manager.h"
 #include "content/scripting/script_names.h"
 #include "database/database.h"
@@ -38,8 +40,6 @@
 #include "request_handler.h"
 #include "transcoding/transcoding.h"
 
-std::vector<int> UpnpXMLBuilder::orderedHandler = {};
-
 UpnpXMLBuilder::UpnpXMLBuilder(const std::shared_ptr<Context>& context,
     std::string virtualUrl, std::string presentationURL)
     : config(context->getConfig())
@@ -47,13 +47,12 @@ UpnpXMLBuilder::UpnpXMLBuilder(const std::shared_ptr<Context>& context,
     , virtualURL(std::move(virtualUrl))
     , presentationURL(std::move(presentationURL))
 {
-    if (orderedHandler.empty())
-        for (auto&& entry : this->config->getArrayOption(CFG_IMPORT_RESOURCES_ORDER)) {
-            auto ch = MetadataHandler::remapContentHandler(entry);
-            if (ch > -1) {
-                orderedHandler.push_back(ch);
-            }
+    for (auto&& entry : this->config->getArrayOption(CFG_IMPORT_RESOURCES_ORDER)) {
+        auto ch = MetadataHandler::remapContentHandler(entry);
+        if (ch > -1) {
+            orderedHandler.push_back(ch);
         }
+    }
 }
 
 std::unique_ptr<pugi::xml_document> UpnpXMLBuilder::createResponse(const std::string& actionName, const std::string& serviceType)
@@ -78,11 +77,11 @@ metadata_fields_t UpnpXMLBuilder::remapMetaDataField(const std::string& fieldNam
 void UpnpXMLBuilder::addPropertyList(pugi::xml_node& result, const std::map<std::string, std::string>& meta, const std::map<std::string, std::string>& auxData,
     config_option_t itemProps, config_option_t nsProp)
 {
-    auto&& namespaceMap = config->getDictionaryOption(nsProp);
+    auto namespaceMap = config->getDictionaryOption(nsProp);
     for (auto&& [xmlns, uri] : namespaceMap) {
         result.append_attribute(fmt::format("xmlns:{}", xmlns).c_str()) = uri.c_str();
     }
-    auto&& propertyMap = config->getDictionaryOption(itemProps);
+    auto propertyMap = config->getDictionaryOption(itemProps);
     for (auto&& [tag, field] : propertyMap) {
         auto metaField = remapMetaDataField(field);
         auto value = (metaField != M_MAX) ? getValueOrDefault(meta, MetadataHandler::getMetaFieldName(metaField)) : getValueOrDefault(auxData, field);
@@ -119,7 +118,7 @@ void UpnpXMLBuilder::addField(pugi::xml_node& entry, const std::string& key, con
     }
 }
 
-void UpnpXMLBuilder::renderObject(const std::shared_ptr<CdsObject>& obj, size_t stringLimit, pugi::xml_node* parent, const std::shared_ptr<Quirks>& quirks)
+void UpnpXMLBuilder::renderObject(const std::shared_ptr<CdsObject>& obj, size_t stringLimit, pugi::xml_node* parent, const std::unique_ptr<Quirks>& quirks)
 {
     auto result = parent->append_child("");
 
@@ -345,16 +344,16 @@ std::unique_ptr<UpnpXMLBuilder::PathBase> UpnpXMLBuilder::getPathBase(const std:
     /// for each resource once the io handlers are ready    int objectType = ;
     if (item->isExternalItem()) {
         if (!item->getFlag(OBJECT_FLAG_PROXY_URL) && (!forceLocal)) {
-            return std::make_unique<PathBase>(PathBase { item->getLocation(), false });
+            return std::make_unique<PathBase>(item->getLocation(), false);
         }
 
         if ((item->getFlag(OBJECT_FLAG_ONLINE_SERVICE) && item->getFlag(OBJECT_FLAG_PROXY_URL)) || forceLocal) {
             auto path = RequestHandler::joinUrl({ CONTENT_ONLINE_HANDLER, dictEncodeSimple(dict), URL_RESOURCE_ID }, true);
-            return std::make_unique<PathBase>(PathBase { path, true });
+            return std::make_unique<PathBase>(path, true);
         }
     }
     auto path = RequestHandler::joinUrl({ CONTENT_MEDIA_HANDLER, dictEncodeSimple(dict), URL_RESOURCE_ID }, true);
-    return std::make_unique<PathBase>(PathBase { path, true });
+    return std::make_unique<PathBase>(path, true);
 }
 
 /// \brief build path for first resource from item
@@ -388,10 +387,11 @@ std::string UpnpXMLBuilder::getArtworkUrl(const std::shared_ptr<CdsItem>& item)
 
 std::pair<std::string, bool> UpnpXMLBuilder::renderContainerImage(const std::string& virtualURL, const std::shared_ptr<CdsContainer>& cont)
 {
-    for (auto&& res : cont->getResources()) {
+    auto orderedResources = getOrderedResources(cont);
+    for (auto&& res : orderedResources) {
         if (res->isMetaResource(ID3_ALBUM_ART)) {
-            auto&& resFile = res->getAttribute(R_RESOURCE_FILE);
-            auto&& resObj = res->getAttribute(R_FANART_OBJ_ID);
+            auto resFile = res->getAttribute(R_RESOURCE_FILE);
+            auto resObj = res->getAttribute(R_FANART_OBJ_ID);
             if (!resFile.empty()) {
                 // found, FanArtHandler deals already with file
                 std::map<std::string, std::string> dict;
@@ -400,7 +400,7 @@ std::pair<std::string, bool> UpnpXMLBuilder::renderContainerImage(const std::str
                 auto res_params = res->getParameters();
                 res_params[RESOURCE_HANDLER] = fmt::to_string(res->getHandlerType());
                 auto url = virtualURL + RequestHandler::joinUrl({ CONTENT_MEDIA_HANDLER, dictEncodeSimple(dict), URL_RESOURCE_ID, fmt::to_string(res->getResId()), dictEncodeSimple(res_params) });
-                return std::pair(url, true);
+                return { url, true };
             }
 
             if (!resObj.empty()) {
@@ -409,7 +409,7 @@ std::pair<std::string, bool> UpnpXMLBuilder::renderContainerImage(const std::str
 
                 auto res_params = res->getParameters();
                 auto url = virtualURL + RequestHandler::joinUrl({ CONTENT_MEDIA_HANDLER, dictEncodeSimple(dict), URL_RESOURCE_ID, res->getAttribute(R_FANART_RES_ID), dictEncodeSimple(res_params) });
-                return std::pair(url, true);
+                return { url, true };
             }
         }
     }
@@ -418,7 +418,7 @@ std::pair<std::string, bool> UpnpXMLBuilder::renderContainerImage(const std::str
 
 std::string UpnpXMLBuilder::renderOneResource(const std::string& virtualURL, const std::shared_ptr<CdsItem>& item, const std::shared_ptr<CdsResource>& res)
 {
-    auto&& res_params = res->getParameters();
+    auto res_params = res->getParameters();
     auto urlBase = getPathBase(item);
     std::string url;
     if (urlBase->addResID) {
@@ -440,7 +440,7 @@ std::pair<std::string, bool> UpnpXMLBuilder::renderItemImage(const std::string&
                              || (res->getHandlerType() == CH_LIBEXIF && res->getParameter(RESOURCE_CONTENT_TYPE) == EXIF_THUMBNAIL) //
                              || (res->getHandlerType() == CH_FFTH && res->getOption(RESOURCE_CONTENT_TYPE) == THUMBNAIL); });
     if (resFound != orderedResources.end()) {
-        return std::pair(renderOneResource(virtualURL, item, *resFound), true);
+        return { renderOneResource(virtualURL, item, *resFound), true };
     }
 
     return {};
@@ -453,14 +453,14 @@ std::pair<std::string, bool> UpnpXMLBuilder::renderSubtitle(const std::string& v
         [](auto&& res) { return res->isMetaResource(VIDEO_SUB, CH_SUBTITLE); });
     if (resFound != resources.end()) {
         auto url = renderOneResource(virtualURL, item, *resFound) + renderExtension("", (*resFound)->getAttribute(R_RESOURCE_FILE));
-        return std::pair(url, true);
+        return { url, true };
     }
     return {};
 }
 
 std::string UpnpXMLBuilder::renderExtension(const std::string& contentType, const fs::path& location)
 {
-    auto&& ext = RequestHandler::joinUrl({ URL_FILE_EXTENSION, "file" });
+    auto ext = RequestHandler::joinUrl({ URL_FILE_EXTENSION, "file" });
 
     if (!contentType.empty() && (contentType != CONTENT_TYPE_PLAYLIST)) {
         return fmt::format("{}.{}", ext, contentType);
@@ -468,21 +468,21 @@ std::string UpnpXMLBuilder::renderExtension(const std::string& contentType, cons
 
     if (!location.empty() && location.has_extension()) {
         // make sure that the filename does not contain the separator character
-        auto&& filename = urlEscape(location.filename().stem().string());
-        auto&& extension = location.filename().extension().string();
-        return fmt::format("{}.{}{}", ext, (filename), extension);
+        std::string filename = urlEscape(location.filename().stem().string());
+        std::string extension = location.filename().extension();
+        return fmt::format("{}.{}{}", ext, filename, extension);
     }
 
-    return "";
+    return {};
 }
 
-std::vector<std::shared_ptr<CdsResource>> UpnpXMLBuilder::getOrderedResources(const std::shared_ptr<CdsItem>& item)
+std::deque<std::shared_ptr<CdsResource>> UpnpXMLBuilder::getOrderedResources(const std::shared_ptr<CdsObject>& object)
 {
     // Order resources according to index defined by orderedHandler
-    std::vector<std::shared_ptr<CdsResource>> orderedResources;
-    auto&& resources = item->getResources();
+    std::deque<std::shared_ptr<CdsResource>> orderedResources;
+    auto&& resources = object->getResources();
     for (auto&& oh : orderedHandler) {
-        std::for_each(resources.begin(), resources.end(), [&](auto res) { if (oh == res->getHandlerType()) orderedResources.push_back(res); });
+        std::copy_if(resources.begin(), resources.end(), std::back_inserter(orderedResources), [&](auto res) { return oh == res->getHandlerType(); });
     }
 
     // Append resources not listed in orderedHandler
@@ -495,7 +495,7 @@ std::vector<std::shared_ptr<CdsResource>> UpnpXMLBuilder::getOrderedResources(co
     return orderedResources;
 }
 
-void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xml_node* parent, const std::shared_ptr<Quirks>& quirks)
+void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xml_node* parent, const std::unique_ptr<Quirks>& quirks)
 {
     auto urlBase = getPathBase(item);
     bool skipURL = (item->isExternalItem() && !item->getFlag(OBJECT_FLAG_PROXY_URL));
@@ -614,7 +614,7 @@ void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xm
                 hide_original_resource = true;
 
             if (tp->firstResource()) {
-                orderedResources.insert(orderedResources.begin(), std::move(t_res));
+                orderedResources.push_front(std::move(t_res));
                 original_resource = 0;
             } else
                 orderedResources.push_back(std::move(t_res));
