@@ -32,11 +32,14 @@
 #ifndef __UPNP_XML_H__
 #define __UPNP_XML_H__
 
+#include <deque>
 #include <memory>
 #include <pugixml.hpp>
+#include <vector>
 
 #include "cds_objects.h"
 #include "common.h"
+#include "config/config.h"
 #include "context.h"
 #include "util/upnp_quirks.h"
 
@@ -61,7 +64,7 @@ public:
     ///
     /// This function looks at the object, and renders the DIDL-Lite representation of it -
     /// either a container or an item
-    void renderObject(const std::shared_ptr<CdsObject>& obj, size_t stringLimit, pugi::xml_node* parent, const std::shared_ptr<Quirks>& quirks = nullptr);
+    void renderObject(const std::shared_ptr<CdsObject>& obj, size_t stringLimit, pugi::xml_node* parent, const std::unique_ptr<Quirks>& quirks = nullptr);
 
     /// \brief Renders XML for the event property set.
     /// \return pugi::xml_document representing the newly created XML.
@@ -79,34 +82,46 @@ public:
     /// \param attributes Dictionary containing the <res> tag attributes (like resolution, etc.)
     static void renderResource(const std::string& URL, const std::map<std::string, std::string>& attributes, pugi::xml_node* parent);
 
-    static bool renderContainerImage(const std::string& virtualURL, const std::shared_ptr<CdsContainer>& cont, std::string& url);
-    static bool renderItemImage(const std::string& virtualURL, const std::shared_ptr<CdsItem>& item, std::string& url);
-    static bool renderSubtitle(const std::string& virtualURL, const std::shared_ptr<CdsItem>& item, std::string& url);
+    std::pair<std::string, bool> renderContainerImage(const std::string& virtualURL, const std::shared_ptr<CdsContainer>& cont);
+    std::pair<std::string, bool> renderItemImage(const std::string& virtualURL, const std::shared_ptr<CdsItem>& item);
+    static std::pair<std::string, bool> renderSubtitle(const std::string& virtualURL, const std::shared_ptr<CdsItem>& item);
+    static std::string renderOneResource(const std::string& virtualURL, const std::shared_ptr<CdsItem>& item, const std::shared_ptr<CdsResource>& res);
 
-    void addResources(const std::shared_ptr<CdsItem>& item, pugi::xml_node* parent);
+    void addResources(const std::shared_ptr<CdsItem>& item, pugi::xml_node* parent, const std::unique_ptr<Quirks>& quirks);
 
-    // FIXME: This needs to go, once we sort a nicer way for the webui code to access this
+    /// \brief build path for first resource from item
+    /// depending on the item type it returns the url to the media
     static std::string getFirstResourcePath(const std::shared_ptr<CdsItem>& item);
 
+    /// \brief convert xml tree to string
+    static std::string printXml(const pugi::xml_node& entry, const char* indent = PUGIXML_TEXT("\t"), int flags = pugi::format_default);
+
 protected:
     std::shared_ptr<Config> config;
     std::shared_ptr<Database> database;
 
+    std::vector<int> orderedHandler;
+
     const std::string virtualURL;
     const std::string presentationURL;
 
-    // Holds a part of path and bool which says if we need to append the resource
-    // TODO: Remove this and use centralised routing instead of building URLs all over the place
-    class PathBase {
-    public:
+    /// \brief Holds a part of path and bool which says if we need to append the resource
+    struct PathBase {
+        PathBase(std::string pathBase, bool addResID)
+            : pathBase(std::move(pathBase))
+            , addResID(addResID)
+        {
+        }
         std::string pathBase;
         bool addResID;
     };
+    std::deque<std::shared_ptr<CdsResource>> getOrderedResources(const std::shared_ptr<CdsObject>& object);
 
     static std::unique_ptr<PathBase> getPathBase(const std::shared_ptr<CdsItem>& item, bool forceLocal = false);
-    static std::string renderExtension(const std::string& contentType, const std::string& location);
+    static std::string renderExtension(const std::string& contentType, const fs::path& location);
     std::string getArtworkUrl(const std::shared_ptr<CdsItem>& item) const;
     static void addField(pugi::xml_node& entry, const std::string& key, const std::string& val);
+    void addPropertyList(pugi::xml_node& result, const std::map<std::string, std::string>& meta, const std::map<std::string, std::string>& auxData, config_option_t itemProps, config_option_t nsProp);
     static metadata_fields_t remapMetaDataField(const std::string& fieldName);
 };
 #endif // __UPNP_XML_H__
