@@ -54,9 +54,9 @@ public:
         };
 
         Parameter(timer_param_t param, int id)
+            : param(param)
+            , id(id)
         {
-            this->param = param;
-            this->id = id;
         }
 
         timer_param_t whoami() const { return param; }
@@ -119,9 +119,10 @@ protected:
         }
         void updateNextNotify()
         {
-            getTimespecAfterMillis(notifyInterval, nextNotify);
+            auto start = std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::system_clock::now().time_since_epoch());
+            nextNotify = start + notifyInterval;
         }
-        std::chrono::milliseconds getNextNotify() { return nextNotify; }
+        std::chrono::milliseconds getNextNotify() const { return nextNotify; }
 
         std::shared_ptr<Parameter> getParameter() const { return parameter; }
 
@@ -135,13 +136,13 @@ protected:
         Subscriber* subscriber;
         std::chrono::milliseconds notifyInterval;
         std::shared_ptr<Parameter> parameter;
-        std::chrono::milliseconds nextNotify;
+        std::chrono::milliseconds nextNotify {};
         bool once;
     };
 
     std::mutex waitMutex;
     std::list<TimerSubscriberElement> subscribers;
-    std::atomic_bool shutdownFlag;
+    std::atomic_bool shutdownFlag {};
 
     void notify();
     std::chrono::milliseconds getNextNotifyTime();
