@@ -38,10 +38,11 @@
 #include <cstdlib>
 #include <filesystem>
 #include <fstream>
-#include <iterator>
 #include <netdb.h>
 #include <netinet/in.h>
+#include <numeric>
 #include <queue>
+#include <random>
 #include <sstream>
 #include <sys/ioctl.h>
 #include <sys/socket.h>
@@ -74,23 +75,23 @@
 
 #define WHITE_SPACE " \t\r\n"
 
-static constexpr const char* HEX_CHARS = "0123456789abcdef";
+static constexpr auto HEX_CHARS = "0123456789abcdef";
 
-std::vector<std::string> splitString(const std::string& str, char sep, bool empty)
+std::vector<std::string> splitString(std::string_view str, char sep, bool empty)
 {
     std::vector<std::string> ret;
-    const char* data = str.c_str();
+    const char* data = str.data();
     const char* end = data + str.length();
     while (data < end) {
         auto pos = std::strchr(data, sep);
-        if (pos == nullptr) {
+        if (!pos) {
             std::string part = data;
             ret.push_back(part);
             data = end;
         } else if (pos == data) {
             data++;
             if ((data < end) && empty)
-                ret.emplace_back("");
+                ret.emplace_back();
         } else {
             std::string part(data, pos - data);
             ret.push_back(part);
@@ -126,58 +127,56 @@ std::string trimString(std::string str)
     return str;
 }
 
-bool startswith(const std::string& str, const std::string& check)
+bool startswith(std::string_view str, std::string_view check)
 {
     return str.rfind(check, 0) == 0;
 }
 
-std::string toLower(std::string str)
+std::string toLower(std::string_view str)
 {
-    std::transform(str.begin(), str.end(), str.begin(), ::tolower);
-    return str;
+    std::string lower(str);
+    std::transform(str.begin(), str.end(), lower.begin(), ::tolower);
+    return lower;
 }
 
 int stoiString(const std::string& str, int def, int base)
 {
-    if (str.empty() || !std::isdigit(*str.c_str()))
+    if (str.empty() || (str[0] == '-' && !std::isdigit(*str.substr(1).c_str())) || (str[0] != '-' && !std::isdigit(*str.c_str())))
         return def;
 
     return std::stoi(str, nullptr, base);
 }
+
 unsigned long stoulString(const std::string& str, int def, int base)
 {
-    if (str.empty() || !std::isdigit(*str.c_str()))
+    if (str.empty() || (str[0] == '-' && !std::isdigit(*str.substr(1).c_str())) || (str[0] != '-' && !std::isdigit(*str.c_str())))
         return def;
 
     return std::stoul(str, nullptr, base);
 }
 
-std::string reduceString(std::string str, char ch)
+void reduceString(std::string& str, char ch)
 {
-    std::string::iterator new_end = std::unique(
-        str.begin(), str.end(),
-        [&](char lhs, char rhs) { return (lhs == rhs) && (lhs == ch); });
+    auto new_end = std::unique(str.begin(), str.end(),
+        [=](char lhs, char rhs) { return (lhs == rhs) && (lhs == ch); });
 
     str.erase(new_end, str.end());
-    return str;
 }
 
-std::string& replaceString(std::string& str, std::string_view from, const std::string& to)
+void replaceString(std::string& str, std::string_view from, std::string_view to)
 {
     size_t start_pos = str.find(from);
     if (start_pos != std::string::npos)
         str.replace(start_pos, from.length(), to);
-    return str;
 }
 
-std::string& replaceAllString(std::string& str, std::string_view from, const std::string& to)
+void replaceAllString(std::string& str, std::string_view from, std::string_view to)
 {
     size_t start_pos = str.find(from);
     while (start_pos != std::string::npos) {
         str.replace(start_pos, from.length(), to);
         start_pos = str.find(from, start_pos + to.length());
     }
-    return str;
 }
 
 bool isRegularFile(const fs::path& path, std::error_code& ec) noexcept
@@ -235,7 +234,7 @@ off_t getFileSize(const fs::directory_entry& dirEnt)
 bool isExecutable(const fs::path& path, int* err)
 {
     int ret = access(path.c_str(), R_OK | X_OK);
-    if (err != nullptr)
+    if (err)
         *err = errno;
 
     return ret == 0;
@@ -245,7 +244,7 @@ fs::path findInPath(const fs::path& exec)
 {
     std::string PATH = getenv("PATH");
     if (PATH.empty())
-        return "";
+        return {};
 
     std::error_code ec;
     auto pathAr = splitString(PATH, ':');
@@ -255,22 +254,15 @@ fs::path findInPath(const fs::path& exec)
             return check;
     }
 
-    return "";
+    return {};
 }
 
-std::string renderWebUri(const std::string& ip, int port)
+std::string renderWebUri(std::string_view ip, int port)
 {
-    std::ostringstream webUIAddr;
-    if (ip.find(':') != std::string::npos) {
-        webUIAddr << '[' << ip << ']';
-    } else {
-        webUIAddr << ip;
-    }
-    webUIAddr << ':' << port;
-    return webUIAddr.str();
+    return fmt::format((ip.find(':') != std::string::npos) ? "[{}]:{}" : "{}:{}", ip, port);
 }
 
-std::string httpRedirectTo(const std::string& addr, const std::string& page)
+std::string httpRedirectTo(std::string_view addr, std::string_view page)
 {
     return fmt::format(R"(<html><head><meta http-equiv="Refresh" content="0;URL={}/{}"></head><body bgcolor="#dddddd"></body></html>)", addr, page);
 }
@@ -293,9 +285,9 @@ std::string hexEncode(const void* data, int len)
     return buf.str();
 }
 
-std::string hexDecodeString(const std::string& encoded)
+std::string hexDecodeString(std::string_view encoded)
 {
-    auto ptr = const_cast<char*>(encoded.c_str());
+    auto ptr = const_cast<char*>(encoded.data());
     int len = encoded.length();
 
     std::ostringstream buf;
@@ -322,9 +314,9 @@ std::string hexMd5(const void* data, int length)
 
     return hexEncode(md5buf, 16);
 }
-std::string hexStringMd5(const std::string& str)
+std::string hexStringMd5(std::string_view str)
 {
-    return hexMd5(str.c_str(), str.length());
+    return hexMd5(str.data(), str.length());
 }
 std::string generateRandomId()
 {
@@ -345,7 +337,7 @@ std::string generateRandomId()
 #endif
 
     log_debug("Generated: {}", uuid_str);
-    std::string uuid_String = std::string(uuid_str);
+    auto uuid_String = std::string(uuid_str);
 #ifdef BSD_NATIVE_UUID
     free(uuid_str);
 #endif
@@ -353,9 +345,9 @@ std::string generateRandomId()
     return uuid_String;
 }
 
-static constexpr const char* HEX_CHARS2 = "0123456789ABCDEF";
+static constexpr auto HEX_CHARS2 = "0123456789ABCDEF";
 
-std::string urlEscape(const std::string& str)
+std::string urlEscape(std::string_view str)
 {
     std::ostringstream buf;
     for (size_t i = 0; i < str.length();) {
@@ -385,15 +377,15 @@ std::string urlEscape(const std::string& str)
     return buf.str();
 }
 
-std::string urlUnescape(const std::string& str)
+std::string urlUnescape(std::string_view str)
 {
-    auto data = const_cast<char*>(str.c_str());
+    auto data = str.data();
     int len = str.length();
     std::ostringstream buf;
 
     int i = 0;
     while (i < len) {
-        char c = data[i++];
+        const char c = data[i++];
         if (c == '%') {
             if (i + 2 > len)
                 break; // avoid buffer overrun
@@ -442,9 +434,9 @@ std::string dictEncodeSimple(const std::map<std::string, std::string>& dict)
     return dictEncode(dict, '/', '/');
 }
 
-void dictDecode(const std::string& url, std::map<std::string, std::string>* dict, bool unEscape)
+void dictDecode(std::string_view url, std::map<std::string, std::string>* dict, bool unEscape)
 {
-    auto data = url.c_str();
+    auto data = url.data();
     auto dataEnd = data + url.length();
     while (data < dataEnd) {
         auto ampPos = reinterpret_cast<const char*>(std::strchr(data, '&'));
@@ -460,7 +452,7 @@ void dictDecode(const std::string& url, std::map<std::string, std::string>* dict
                 value = urlUnescape(value);
             }
 
-            dict->insert(std::pair(key, value));
+            dict->emplace(key, value);
         }
         data = ampPos + 1;
     }
@@ -468,7 +460,7 @@ void dictDecode(const std::string& url, std::map<std::string, std::string>* dict
 
 // this is somewhat tricky as we need an exact amount of pairs
 // object_id=720&res_id=0
-void dictDecodeSimple(const std::string& url, std::map<std::string, std::string>* dict)
+void dictDecodeSimple(std::string_view url, std::map<std::string, std::string>* dict)
 {
     size_t pos;
     size_t last_pos = 0;
@@ -488,19 +480,13 @@ void dictDecodeSimple(const std::string& url, std::map<std::string, std::string>
         std::string value = urlUnescape(url.substr(last_pos, pos - last_pos));
         last_pos = pos + 1;
 
-        dict->insert(std::pair(key, value));
+        dict->emplace(key, value);
     } while (last_pos < url.length());
 }
 
 std::string mimeTypesToCsv(const std::vector<std::string>& mimeTypes)
 {
-    std::ostringstream buf;
-    for (auto&& mimeType : mimeTypes) {
-        buf << "http-get:*:" << mimeType << ":*"
-            << ",";
-    }
-
-    return buf.str();
+    return mimeTypes.empty() ? "" : fmt::format("http-get:*:{}:*", fmt::join(mimeTypes, ":*,http-get:*:"));
 }
 
 std::string readTextFile(const fs::path& path)
@@ -523,7 +509,7 @@ std::string readTextFile(const fs::path& path)
     return buf.str();
 }
 
-void writeTextFile(const fs::path& path, const std::string& contents)
+void writeTextFile(const fs::path& path, std::string_view contents)
 {
 #ifdef __linux__
     auto f = ::fopen(path.c_str(), "wte");
@@ -534,7 +520,7 @@ void writeTextFile(const fs::path& path, const std::string& contents)
         throw_std_runtime_error("Could not open {}: {}", path.c_str(), std::strerror(errno));
     }
 
-    size_t bytesWritten = std::fwrite(contents.c_str(), 1, contents.length(), f);
+    size_t bytesWritten = std::fwrite(contents.data(), 1, contents.length(), f);
     if (bytesWritten < contents.length()) {
         fclose(f);
 
@@ -563,14 +549,14 @@ std::optional<std::vector<std::byte>> readBinaryFile(const fs::path& path)
 
     fb.pubseekoff(0, std::ios::beg);
 
-    std::vector<std::byte> result(size);
-    size = fb.sgetn(reinterpret_cast<char*>(result.data()), size);
+    auto result = std::optional<std::vector<std::byte>>(size);
+    size = fb.sgetn(reinterpret_cast<char*>(result->data()), size);
     if (size < 0 || !file)
         throw_std_runtime_error("Failed to read from file {}", path.c_str());
 
-    result.resize(size);
+    result->resize(size);
 
-    return std::move(result);
+    return result;
 }
 
 void writeBinaryFile(const fs::path& path, const std::byte* data, std::size_t size)
@@ -587,7 +573,7 @@ void writeBinaryFile(const fs::path& path, const std::byte* data, std::size_t si
         throw_std_runtime_error("Failed to write to file {}", path.c_str());
 }
 
-std::string renderProtocolInfo(const std::string& mimetype, const std::string& protocol, const std::string& extend)
+std::string renderProtocolInfo(std::string_view mimetype, std::string_view protocol, std::string_view extend)
 {
     if (!mimetype.empty() && !protocol.empty()) {
         if (!extend.empty())
@@ -598,13 +584,13 @@ std::string renderProtocolInfo(const std::string& mimetype, const std::string& p
     return "http-get:*:*:*";
 }
 
-std::string getMTFromProtocolInfo(const std::string& protocol)
+std::string getMTFromProtocolInfo(std::string_view protocol)
 {
     std::vector<std::string> parts = splitString(protocol, ':');
     if (parts.size() > 2)
         return parts[2];
 
-    return "";
+    return {};
 }
 
 std::string getProtocol(const std::string& protocolInfo)
@@ -627,7 +613,7 @@ std::string millisecondsToHMSF(int milliseconds)
     return fmt::format("{:01}:{:02}:{:02}.{:03}", h, m, s, ms);
 }
 
-int HMSFToMilliseconds(const std::string& time)
+int HMSFToMilliseconds(std::string_view time)
 {
     if (time.empty()) {
         log_warning("Could not convert time representation to seconds!");
@@ -638,17 +624,17 @@ int HMSFToMilliseconds(const std::string& time)
     int minutes = 0;
     int seconds = 0;
     int ms = 0;
-    sscanf(time.c_str(), "%d:%d:%d.%d", &hours, &minutes, &seconds, &ms);
+    sscanf(time.data(), "%d:%d:%d.%d", &hours, &minutes, &seconds, &ms);
 
     return ((hours * 3600) + (minutes * 60) + seconds) * 1000 + ms;
 }
 
-bool checkResolution(const std::string& resolution, int* x, int* y)
+bool checkResolution(std::string_view resolution, int* x, int* y)
 {
-    if (x != nullptr)
+    if (x)
         *x = 0;
 
-    if (y != nullptr)
+    if (y)
         *y = 0;
 
     std::vector<std::string> parts = splitString(resolution, 'x');
@@ -660,10 +646,10 @@ bool checkResolution(const std::string& resolution, int* x, int* y)
         int _y = std::stoi(parts[1]);
 
         if ((_x > 0) && (_y > 0)) {
-            if (x != nullptr)
+            if (x)
                 *x = _x;
 
-            if (y != nullptr)
+            if (y)
                 *y = _y;
 
             return true;
@@ -745,14 +731,9 @@ std::string fallbackString(const std::string& first, const std::string& fallback
     return first.empty() ? fallback : first;
 }
 
-unsigned int stringHash(const std::string& str)
+unsigned int stringHash(std::string_view str)
 {
-    unsigned int hash = 5381;
-    auto data = str.c_str();
-    int c;
-    while ((c = *data++))
-        hash = ((hash << 5) + hash) ^ c; /* (hash * 33) ^ c */
-    return hash;
+    return std::accumulate(str.begin(), str.end(), 5381U, [](auto h, auto ch) { return ((h << 5) + h) ^ ch; });
 }
 
 std::string getValueOrDefault(const std::map<std::string, std::string>& m, const std::string& key, const std::string& defval)
@@ -760,11 +741,6 @@ std::string getValueOrDefault(const std::map<std::string, std::string>& m, const
     return getValueOrDefault<std::string, std::string>(m, key, defval);
 }
 
-std::string toCSV(const std::shared_ptr<std::unordered_set<int>>& array)
-{
-    return array->empty() ? "" : join(*array, ",");
-}
-
 std::chrono::seconds currentTime()
 {
     return std::chrono::duration_cast<std::chrono::seconds>(std::chrono::system_clock::now().time_since_epoch());
@@ -786,16 +762,10 @@ std::chrono::milliseconds getDeltaMillis(std::chrono::milliseconds first, std::c
     return second - first;
 }
 
-void getTimespecAfterMillis(std::chrono::milliseconds delta, std::chrono::milliseconds& ret)
-{
-    auto start = std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::system_clock::now().time_since_epoch());
-    ret = start + delta;
-}
-
-std::string ipToInterface(const std::string& ip)
+std::string ipToInterface(std::string_view ip)
 {
     if (ip.empty()) {
-        return "";
+        return {};
     }
 
     log_warning("Please provide an interface name instead! LibUPnP does not support specifying an IP in current versions.");
@@ -809,8 +779,8 @@ std::string ipToInterface(const std::string& ip)
         log_error("Could not getifaddrs: {}", std::strerror(errno));
     }
 
-    for (ifa = ifaddr, n = 0; ifa != nullptr; ifa = ifa->ifa_next, n++) {
-        if (ifa->ifa_addr == nullptr)
+    for (ifa = ifaddr, n = 0; ifa; ifa = ifa->ifa_next, n++) {
+        if (!ifa->ifa_addr)
             continue;
 
         family = ifa->ifa_addr->sa_family;
@@ -822,7 +792,7 @@ std::string ipToInterface(const std::string& ip)
                 host, NI_MAXHOST, nullptr, 0, NI_NUMERICHOST);
             if (s != 0) {
                 log_error("getnameinfo() failed: {}", gai_strerror(s));
-                return "";
+                return {};
             }
 
             std::string ipaddr = host;
@@ -834,13 +804,13 @@ std::string ipToInterface(const std::string& ip)
     }
 
     freeifaddrs(ifaddr);
-    log_warning("Failed to find interface for IP: {}", ip.c_str());
-    return "";
+    log_warning("Failed to find interface for IP: {}", ip);
+    return {};
 }
 
-bool validateYesNo(const std::string& value)
+bool validateYesNo(std::string_view value)
 {
-    return !((value != "yes") && (value != "no"));
+    return value == "yes" || value == "no";
 }
 
 std::vector<std::string> populateCommandLine(const std::string& line,
@@ -921,7 +891,7 @@ fs::path tempName(const fs::path& leadPath, char* tmpl)
     XXXXXX = strstr(tmpl, "XXXXXX");
 
     if (!XXXXXX || strncmp(XXXXXX, "XXXXXX", 6) != 0) {
-        return "";
+        return {};
     }
 
     /* Get some more or less random data.  */
@@ -950,12 +920,12 @@ fs::path tempName(const fs::path& leadPath, char* tmpl)
             if ((errno == ENOENT) || (errno == ENOTDIR))
                 return check;
 
-            return "";
+            return {};
         }
     }
 
     /* We got out of the loop because we ran out of combinations to try.  */
-    return "";
+    return {};
 }
 
 bool isTheora(const fs::path& ogg_filename)
@@ -1002,18 +972,16 @@ bool isTheora(const fs::path& ogg_filename)
 
 fs::path getLastPath(const fs::path& path)
 {
-    fs::path ret;
-
     auto it = std::prev(path.end()); // filename
     if (it != path.end())
         it = std::prev(it); // last path
     if (it != path.end())
-        ret = *it;
+        return *it;
 
-    return ret;
+    return {};
 }
 
-ssize_t getValidUTF8CutPosition(std::string str, ssize_t cutpos)
+ssize_t getValidUTF8CutPosition(std::string_view str, ssize_t cutpos)
 {
     ssize_t pos = -1;
     size_t len = str.length();
@@ -1045,62 +1013,50 @@ ssize_t getValidUTF8CutPosition(std::string str, ssize_t cutpos)
     return pos;
 }
 
-std::string getDLNAprofileString(const std::string& contentType)
+std::string getDLNAprofileString(const std::shared_ptr<Config>& config, const std::string& contentType)
 {
-    std::string profile;
-    if (contentType == CONTENT_TYPE_MP4)
-        profile = UPNP_DLNA_PROFILE_AVC_MP4_EU;
-    else if (contentType == CONTENT_TYPE_MKV)
-        profile = UPNP_DLNA_PROFILE_MKV;
-    else if (contentType == CONTENT_TYPE_AVI)
-        profile = UPNP_DLNA_PROFILE_AVI;
-    else if (contentType == CONTENT_TYPE_MPEG)
-        profile = UPNP_DLNA_PROFILE_MPEG_PS_PAL;
-    else if (contentType == CONTENT_TYPE_MP3)
-        profile = UPNP_DLNA_PROFILE_MP3;
-    else if (contentType == CONTENT_TYPE_PCM)
-        profile = UPNP_DLNA_PROFILE_LPCM;
+    // get profiles from <contenttype-dlnaprofile> mappings
+    auto mappings = config->getDictionaryOption(CFG_IMPORT_MAPPINGS_CONTENTTYPE_TO_DLNAPROFILE_LIST);
+    auto profile = getValueOrDefault(mappings, contentType, "");
 
-    if (!profile.empty())
-        profile = fmt::format("{}={}", UPNP_DLNA_PROFILE, profile);
-    return profile;
+    return profile.empty() ? "" : fmt::format("{}={};", UPNP_DLNA_PROFILE, profile);
 }
 
 std::string getDLNAContentHeader(const std::shared_ptr<Config>& config, const std::string& contentType)
 {
-    std::string content_parameter;
-    content_parameter = getDLNAprofileString(contentType);
-    if (!content_parameter.empty())
-        content_parameter += std::string(";");
-    content_parameter += std::string(UPNP_DLNA_OP) + "=" + UPNP_DLNA_OP_SEEK_RANGE + ";";
-    content_parameter += std::string(UPNP_DLNA_CONVERSION_INDICATOR) + "=" + UPNP_DLNA_NO_CONVERSION + ";";
-    content_parameter += std::string(UPNP_DLNA_FLAGS "=" UPNP_DLNA_ORG_FLAGS_AV);
-    return content_parameter;
+    std::string content_parameter = getDLNAprofileString(config, contentType);
+    return fmt::format("{}{}={};{}={};{}={}", content_parameter, //
+        UPNP_DLNA_OP, UPNP_DLNA_OP_SEEK_RANGE, //
+        UPNP_DLNA_CONVERSION_INDICATOR, UPNP_DLNA_NO_CONVERSION, //
+        UPNP_DLNA_FLAGS, UPNP_DLNA_ORG_FLAGS_AV);
 }
 
-std::string getDLNATransferHeader(const std::shared_ptr<Config>& config, const std::string& mimeType)
+std::string getDLNATransferHeader(const std::shared_ptr<Config>& config, std::string_view mimeType)
 {
-    std::string transfer_parameter;
-    if (startswith(mimeType, "image"))
-        transfer_parameter = UPNP_DLNA_TRANSFER_MODE_INTERACTIVE;
-    else if (startswith(mimeType, "audio") || startswith(mimeType, "video"))
-        transfer_parameter = UPNP_DLNA_TRANSFER_MODE_STREAMING;
-    return transfer_parameter;
+    if (startswith(mimeType, "image")) {
+        return UPNP_DLNA_TRANSFER_MODE_INTERACTIVE;
+    }
+
+    if (startswith(mimeType, "audio") || startswith(mimeType, "video")) {
+        return UPNP_DLNA_TRANSFER_MODE_STREAMING;
+    }
+
+    return {};
 }
 
 #ifndef HAVE_FFMPEG
-std::string getAVIFourCC(const fs::path& avi_filename)
+std::string getAVIFourCC(std::string_view avi_filename)
 {
 #define FCC_OFFSET 0xbc
     char* buffer;
 
 #ifdef __linux__
-    auto f = ::fopen(avi_filename.c_str(), "rbe");
+    auto f = ::fopen(avi_filename.data(), "rbe");
 #else
-    auto f = ::fopen(avi_filename.c_str(), "rb");
+    auto f = ::fopen(avi_filename.data(), "rb");
 #endif
     if (!f)
-        throw_std_runtime_error("Could not open file {}: {}", avi_filename.c_str(), std::strerror(errno));
+        throw_std_runtime_error("Could not open file {}: {}", avi_filename, std::strerror(errno));
 
     buffer = new char[FCC_OFFSET + 6];
 
@@ -1108,22 +1064,22 @@ std::string getAVIFourCC(const fs::path& avi_filename)
     fclose(f);
     if (rb != FCC_OFFSET + 4) {
         delete[] buffer;
-        throw_std_runtime_error("Could not read header of {}: {}", avi_filename.c_str(), std::strerror(errno));
+        throw_std_runtime_error("Could not read header of {}: {}", avi_filename, std::strerror(errno));
     }
 
     buffer[FCC_OFFSET + 5] = '\0';
 
     if (strncmp(buffer, "RIFF", 4) != 0) {
         delete[] buffer;
-        return "";
+        return {};
     }
 
     if (strncmp(buffer + 8, "AVI ", 4) != 0) {
         delete[] buffer;
-        return "";
+        return {};
     }
 
-    std::string fourcc = std::string(buffer + FCC_OFFSET, 4);
+    auto fourcc = std::string(buffer + FCC_OFFSET, 4);
     delete[] buffer;
 
     return fourcc;
@@ -1169,7 +1125,7 @@ std::string sockAddrGetNameInfo(const struct sockaddr* sa)
         throw_std_runtime_error("could not determine getnameinfo: {}", std::strerror(errno));
     }
 
-    return std::string(hoststr) + ":" + std::string(portstr);
+    return fmt::format("{}:{}", hoststr, portstr);
 }
 
 #ifdef SOPCAST
@@ -1187,8 +1143,11 @@ int find_local_port(in_port_t range_min, in_port_t range_max)
         return -1;
     }
 
+    std::mt19937 rng;
+    std::uniform_int_distribution<in_port_t> gen(range_min, range_max);
+
     do {
-        port = rand() % (range_max - range_min) + range_min;
+        port = gen(rng);
 
         fd = socket(AF_INET, SOCK_STREAM, 0);
         if (fd < 0) {
@@ -1197,7 +1156,7 @@ int find_local_port(in_port_t range_min, in_port_t range_max)
         }
 
         server = gethostbyname("127.0.0.1");
-        if (server == nullptr) {
+        if (!server) {
             log_error("could not resolve localhost");
             close(fd);
             return -1;
@@ -1215,9 +1174,10 @@ int find_local_port(in_port_t range_min, in_port_t range_max)
             return port;
         }
 
-        retry_count++;
+        close(fd);
 
-    } while (retry_count < std::numeric_limits<unsigned short>::max());
+        retry_count++;
+    } while (retry_count < std::numeric_limits<uint16_t>::max());
 
     log_error("Could not find free port on localhost");
 
