@@ -33,10 +33,15 @@
 
 #include <upnp.h>
 
-// table of supported clients (reverse search, sequence of entries matters!)
-static const auto bultinClientInfo = std::array<ClientInfo, 8> {
-    {
+Clients::Clients(const std::shared_ptr<Config>& config)
+{
+    refresh(config);
+}
 
+void Clients::refresh(const std::shared_ptr<Config>& config)
+{
+    // table of supported clients (reverse search, sequence of entries matters!)
+    clientInfo = {
         // Used for not explicitly listed clients, must be first entry
         {
             "Unknown",
@@ -116,20 +121,13 @@ static const auto bultinClientInfo = std::array<ClientInfo, 8> {
             ClientMatchType::UserAgent,
             "[BD]J5500",
         },
-    }
-};
+    };
 
-Clients::Clients(const std::shared_ptr<Config>& config)
-{
-    std::copy(bultinClientInfo.begin(), bultinClientInfo.end(), std::back_inserter(clientInfo));
     auto clientConfigList = config->getClientConfigListOption(CFG_CLIENTS_LIST);
     for (size_t i = 0; i < clientConfigList->size(); i++) {
         auto clientConfig = clientConfigList->get(i);
-        auto client = clientConfig->getClientInfo();
-        clientInfo.push_back(*client);
+        clientInfo.push_back(*clientConfig->getClientInfo());
     }
-
-    cache = std::make_shared<std::vector<ClientCacheEntry>>();
 }
 
 void Clients::addClientByDiscovery(const struct sockaddr_storage* addr, const std::string& userAgent, const std::string& descLocation)
@@ -137,8 +135,8 @@ void Clients::addClientByDiscovery(const struct sockaddr_storage* addr, const st
 #if 0 // only needed if UserAgent is not good enough
     const ClientInfo* info = nullptr;
 
-    std::unique_ptr<pugi::xml_document> descXml;
-    if (downloadDescription(descLocation, descXml)) {
+    auto descXml = downloadDescription(descLocation);
+    if (descXml) {
         // TODO: search for FriendlyName + ModelName
         //(void)getInfoByType(userAgent, ClientMatchType::FriendlyName, &info);
     }
@@ -240,10 +238,10 @@ bool Clients::getInfoByCache(const struct sockaddr_storage* addr, const ClientIn
 {
     AutoLock lock(mutex);
 
-    auto it = std::find_if(cache->begin(), cache->end(), [&](auto&& entry) //
+    auto it = std::find_if(cache.begin(), cache.end(), [&](auto&& entry) //
         { return sockAddrCmpAddr(reinterpret_cast<const struct sockaddr*>(&entry.addr), reinterpret_cast<const struct sockaddr*>(addr)) == 0; });
 
-    if (it != cache->end()) {
+    if (it != cache.end()) {
         *ppInfo = it->pInfo;
         auto hostName = getHostName(reinterpret_cast<const struct sockaddr*>(&it->addr));
         log_debug("found client by cache (hostname='{}')", hostName.c_str());
@@ -254,59 +252,54 @@ bool Clients::getInfoByCache(const struct sockaddr_storage* addr, const ClientIn
     return false;
 }
 
-void Clients::updateCache(const struct sockaddr_storage* addr, const std::string& userAgent, const ClientInfo* pInfo)
+void Clients::updateCache(const struct sockaddr_storage* addr, std::string userAgent, const ClientInfo* pInfo)
 {
     AutoLock lock(mutex);
 
     // house cleaning, remove old entries
     auto now = currentTime();
-    cache->erase(std::remove_if(cache->begin(), cache->end(),
-                     [now](auto&& entry) { return entry.last + std::chrono::hours(6) < now; }),
-        cache->end());
+    cache.erase(std::remove_if(cache.begin(), cache.end(),
+                    [now](auto&& entry) { return entry.last + std::chrono::hours(6) < now; }),
+        cache.end());
 
-    auto it = std::find_if(cache->begin(), cache->end(), [=](auto&& entry) //
+    auto it = std::find_if(cache.begin(), cache.end(), [=](auto&& entry) //
         { return sockAddrCmpAddr(reinterpret_cast<const struct sockaddr*>(&entry.addr), reinterpret_cast<const struct sockaddr*>(addr)) == 0; });
 
-    if (it != cache->end()) {
+    if (it != cache.end()) {
         it->last = now;
         if (it->pInfo != pInfo) {
             // client info changed, update all
             it->age = now;
-            it->userAgent = userAgent;
+            it->userAgent = std::move(userAgent);
             it->pInfo = pInfo;
         }
     } else {
         // add new client
-        auto add = ClientCacheEntry();
-        add.addr = *addr;
-        add.age = add.last = now;
-        add.userAgent = userAgent;
-        add.pInfo = pInfo;
-        cache->push_back(add);
+        cache.emplace_back(*addr, std::move(userAgent), now, now, pInfo);
     }
 }
 
-bool Clients::downloadDescription(const std::string& location, std::unique_ptr<pugi::xml_document>& xml)
+std::unique_ptr<pugi::xml_document> Clients::downloadDescription(const std::string& location)
 {
 #if defined(USING_NPUPNP)
     std::string description, ct;
     int errCode = UpnpDownloadUrlItem(location, description, ct);
     if (errCode != UPNP_E_SUCCESS) {
         log_debug("Error obtaining client description from {} -- error = {}", location, errCode);
-        return false;
+        return {};
     }
-    xml = std::make_unique<pugi::xml_document>();
+    auto xml = std::make_unique<pugi::xml_document>();
     auto ret = xml->load_string(description.c_str());
 #else
     IXML_Document* descDoc = nullptr;
     int errCode = UpnpDownloadXmlDoc(location.c_str(), &descDoc);
     if (errCode != UPNP_E_SUCCESS) {
         log_debug("Error obtaining client description from {} -- error = {}", location, errCode);
-        return false;
+        return {};
     }
 
     DOMString cxml = ixmlPrintDocument(descDoc);
-    xml = std::make_unique<pugi::xml_document>();
+    auto xml = std::make_unique<pugi::xml_document>();
     auto ret = xml->load_string(cxml);
 
     ixmlFreeDOMString(cxml);
@@ -315,8 +308,8 @@ bool Clients::downloadDescription(const std::string& location, std::unique_ptr<p
 
     if (ret.status != pugi::xml_parse_status::status_ok) {
         log_debug("Unable to parse xml client description from {}", location);
-        return false;
+        return {};
     }
 
-    return true;
+    return xml;
 }
