@@ -72,6 +72,15 @@ struct ClientInfo {
 };
 
 struct ClientCacheEntry {
+    ClientCacheEntry(struct sockaddr_storage addr, std::string userAgent, std::chrono::seconds last, std::chrono::seconds age, const struct ClientInfo* pInfo)
+        : addr(addr)
+        , userAgent(std::move(userAgent))
+        , last(last)
+        , age(age)
+        , pInfo(pInfo)
+    {
+    }
+
     struct sockaddr_storage addr;
     std::string userAgent;
     std::chrono::seconds last;
@@ -82,25 +91,26 @@ struct ClientCacheEntry {
 class Clients {
 public:
     explicit Clients(const std::shared_ptr<Config>& config);
+    void refresh(const std::shared_ptr<Config>& config);
 
     // always return something, 'Unknown' if we do not know better
     void getInfo(const struct sockaddr_storage* addr, const std::string& userAgent, const ClientInfo** ppInfo);
 
     void addClientByDiscovery(const struct sockaddr_storage* addr, const std::string& userAgent, const std::string& descLocation);
-    std::shared_ptr<std::vector<ClientCacheEntry>> getClientList() const { return cache; }
+    const std::vector<ClientCacheEntry>& getClientList() const { return cache; }
 
 private:
     bool getInfoByAddr(const struct sockaddr_storage* addr, const ClientInfo** ppInfo);
     bool getInfoByType(const std::string& match, ClientMatchType type, const ClientInfo** ppInfo);
 
     bool getInfoByCache(const struct sockaddr_storage* addr, const ClientInfo** ppInfo);
-    void updateCache(const struct sockaddr_storage* addr, const std::string& userAgent, const ClientInfo* pInfo);
+    void updateCache(const struct sockaddr_storage* addr, std::string userAgent, const ClientInfo* pInfo);
 
-    static bool downloadDescription(const std::string& location, std::unique_ptr<pugi::xml_document> xml);
+    static std::unique_ptr<pugi::xml_document> downloadDescription(const std::string& location);
 
     std::mutex mutex;
     using AutoLock = std::lock_guard<std::mutex>;
-    std::shared_ptr<std::vector<ClientCacheEntry>> cache;
+    std::vector<ClientCacheEntry> cache;
 
     std::vector<ClientInfo> clientInfo;
 };
