@@ -43,7 +43,12 @@ Quirks::Quirks(std::shared_ptr<Context> context, const struct sockaddr_storage*
     this->context->getClients()->getInfo(addr, userAgent, &pClientInfo);
 }
 
-void Quirks::addCaptionInfo(const std::shared_ptr<CdsItem>& item, std::unique_ptr<Headers>& headers) const
+int Quirks::checkFlags(int flags)
+{
+    return pClientInfo ? pClientInfo->flags & flags : 0;
+}
+
+void Quirks::addCaptionInfo(const std::shared_ptr<CdsItem>& item, const std::unique_ptr<Headers>& headers) const
 {
     if ((pClientInfo->flags & QUIRK_FLAG_SAMSUNG) == 0)
         return;
@@ -51,8 +56,8 @@ void Quirks::addCaptionInfo(const std::shared_ptr<CdsItem>& item, std::unique_pt
     if (!startswith(item->getMimeType(), "video"))
         return;
 
-    std::string url;
-    if (UpnpXMLBuilder::renderSubtitle(context->getServer()->getVirtualUrl(), item, url)) {
+    auto [url, subAdded] = UpnpXMLBuilder::renderSubtitle(context->getServer()->getVirtualUrl(), item);
+    if (subAdded) {
         headers->addHeader("CaptionInfo.sec", url);
     }
 }
@@ -65,24 +70,70 @@ void Quirks::getSamsungFeatureList(const std::unique_ptr<ActionRequest>& request
     log_debug("Call for Samsung extension: X_GetFeatureList");
 
     auto response = UpnpXMLBuilder::createResponse(request->getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
-    auto features = response->append_child("FeatureList").append_child("Features").append_child("Feature");
+    pugi::xml_document resp_root;
+    auto features = resp_root.append_child("Features");
     features.append_attribute("xmlns") = "urn:schemas-upnp-org:av:avs";
     features.append_attribute("xmlns:xsi") = "http://www.w3.org/2001/XMLSchema-instance";
     features.append_attribute("xsi:schemaLocation") = "urn:schemas-upnp-org:av:avs http://www.upnp.org/schemas/av/avs.xsd";
     auto feature = features.append_child("Feature");
     feature.append_attribute("name") = "samsung.com_BASICVIEW";
     feature.append_attribute("version") = "1";
-    feature.append_attribute("version") = "1";
-    constexpr auto containers = std::array<std::pair<std::string_view, std::string_view>, 3> { {
-        { "object.item.audioItem", "0" },
-        { "object.item.videoItem", "0" },
-        { "object.item.imageItem", "0" },
-    } };
+    constexpr auto containers = std::array {
+        std::pair("object.item.audioItem", "0"), // A
+        std::pair("object.item.videoItem", "0"), // V
+        std::pair("object.item.imageItem", "0"), // I
+        std::pair("object.item.playlistItem", "0"), // P
+        //std::pair("object.item.textItem", "0"), // T
+    };
+
     for (auto&& [type, id] : containers) {
         auto container = feature.append_child("container");
-        container.append_attribute("id") = id.data();
-        container.append_attribute("type") = type.data();
+        container.append_attribute("id") = id;
+        container.append_attribute("type") = type;
     }
+
+    response->document_element().append_child("FeatureList").append_child(pugi::node_pcdata).set_value(UpnpXMLBuilder::printXml(resp_root, "", 0).c_str());
+    request->setResponse(std::move(response));
+}
+
+void Quirks::getSamsungObjectIDfromIndex(const std::unique_ptr<ActionRequest>& request) const
+{
+    if ((pClientInfo->flags & QUIRK_FLAG_SAMSUNG) == 0)
+        return;
+
+    log_debug("Call for Samsung extension: X_GetObjectIDfromIndex");
+
+    auto req_root = request->getRequest()->document_element();
+
+    log_debug("request {}", UpnpXMLBuilder::printXml(req_root, " "));
+
+    [[maybe_unused]] auto categoryType = req_root.child("CategoryType").text().as_string();
+    [[maybe_unused]] auto index = req_root.child("Index").text().as_string();
+
+    log_debug("X_GetObjectIDfromIndex CategoryType [{}] Index[{}]", categoryType, index);
+
+    auto response = UpnpXMLBuilder::createResponse(request->getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
+    response->document_element().append_child("ObjectID").append_child(pugi::node_pcdata).set_value("0");
+    request->setResponse(std::move(response));
+}
+
+void Quirks::getSamsungIndexfromRID(const std::unique_ptr<ActionRequest>& request) const
+{
+    if ((pClientInfo->flags & QUIRK_FLAG_SAMSUNG) == 0)
+        return;
+
+    log_debug("Call for Samsung extension: X_GetIndexfromRID");
+    auto req_root = request->getRequest()->document_element();
+
+    log_debug("request {}", UpnpXMLBuilder::printXml(req_root, " "));
+
+    [[maybe_unused]] auto categoryType = req_root.child("CategoryType").text().as_string();
+    [[maybe_unused]] auto rID = req_root.child("RID").text().as_string();
+
+    log_debug("X_GetIndexfromRID CategoryType [{}] RID[{}]", categoryType, rID);
+
+    auto response = UpnpXMLBuilder::createResponse(request->getActionName(), UPNP_DESC_CDS_SERVICE_TYPE);
+    response->document_element().append_child("Index").append_child(pugi::node_pcdata).set_value("0");
     request->setResponse(std::move(response));
 }
 
@@ -111,12 +162,12 @@ void Quirks::saveSamsungBookMarkedPosition(const std::unique_ptr<ActionRequest>&
         auto req_root = request->getRequest()->document_element();
         auto objectID = req_root.child("ObjectID").text().as_string();
         auto bookMarkPos = std::to_string(stoiString(req_root.child("PosSecond").text().as_string()) / divider);
-        auto categoryType = req_root.child("CategoryType").text().as_string();
-        auto rID = req_root.child("RID").text().as_string();
+        [[maybe_unused]] auto categoryType = req_root.child("CategoryType").text().as_string();
+        [[maybe_unused]] auto rID = req_root.child("RID").text().as_string();
 
         log_debug("saveSamsungBookMarkedPosition: ObjectID [{}] PosSecond [{}] CategoryType [{}] RID [{}]", objectID, bookMarkPos, categoryType, rID);
 
-        std::map<std::string, std::string> m = {
+        std::map<std::string, std::string> m {
             { "bookmarkpos", bookMarkPos },
         };
         content->updateObject(stoiString(objectID), m);
