@@ -40,8 +40,9 @@
 #include "upnp_xml.h"
 #include "util/upnp_clients.h"
 
-web::configSave::configSave(std::shared_ptr<ContentManager> content)
+web::configSave::configSave(std::shared_ptr<Context> context, std::shared_ptr<ContentManager> content)
     : WebRequestHandler(std::move(content))
+    , context(std::move(context))
 {
 }
 
@@ -73,7 +74,7 @@ void web::configSave::process()
             auto item = fmt::format("data[{}][{}]", i, "item");
             auto status = fmt::format("data[{}][{}]", i, "status");
             bool success = false;
-            std::shared_ptr<ConfigSetup> cs = nullptr;
+            std::shared_ptr<ConfigSetup> cs;
             log_debug("save item {}='{}' {}", param(item), param(key), param(status));
             if (!param(key).empty() && param(key) != "-1") {
                 config_option_t option = CFG_MAX;
@@ -86,7 +87,7 @@ void web::configSave::process()
                 continue;
             }
 
-            if (cs != nullptr) {
+            if (cs) {
                 auto value = fmt::format("data[{}][{}]", i, "value");
                 auto orig = fmt::format("data[{}][{}]", i, "origValue");
                 log_debug("found option to update {}", cs->getUniquePath());
@@ -97,7 +98,7 @@ void web::configSave::process()
                 std::string parValue = param(value);
                 std::string parStatus = param(status);
                 bool update = param(status) == STATUS_CHANGED;
-                std::map<std::string, std::string> arguments = { { "status", parStatus } };
+                std::map<std::string, std::string> arguments { { "status", parStatus } };
                 if (parStatus == STATUS_RESET || parStatus == STATUS_KILLED) {
                     // remove value and restore original
                     database->removeConfigValue(param(item));
@@ -157,13 +158,13 @@ void web::configSave::process()
     if (action == "rescan" && !target.empty()) {
         if (target != "--all") {
             fs::path targetPath(target);
-            std::shared_ptr<AutoscanDirectory> autoscan = nullptr;
-            while (targetPath != "/" && autoscan == nullptr) {
+            std::shared_ptr<AutoscanDirectory> autoscan;
+            while (targetPath != "/" && !autoscan) {
                 autoscan = content->getAutoscanDirectory(targetPath);
                 targetPath = targetPath.parent_path();
             }
             int objectID = database->findObjectIDByPath(target);
-            if (objectID > 0 && autoscan != nullptr) {
+            if (objectID > 0 && autoscan) {
                 content->rescanDirectory(autoscan, objectID, target);
                 auto taskEl = root.append_child("task");
                 taskEl.append_attribute("text") = fmt::format("Rescanning directory {}", target).c_str();
@@ -179,4 +180,6 @@ void web::configSave::process()
             }
         }
     }
+
+    context->getClients()->refresh(context->getConfig());
 }
