@@ -37,8 +37,9 @@
 #include "server.h"
 #include "upnp_xml.h"
 
-web::containers::containers(std::shared_ptr<ContentManager> content)
+web::containers::containers(std::shared_ptr<ContentManager> content, std::shared_ptr<UpnpXMLBuilder> xmlBuilder)
     : WebRequestHandler(std::move(content))
+    , xmlBuilder(std::move(xmlBuilder))
 {
 }
 
@@ -61,8 +62,8 @@ void web::containers::process()
     if (!param("select_it").empty())
         containers.append_attribute("select_it") = param("select_it").c_str();
 
-    auto param = std::make_unique<BrowseParam>(parentID, BROWSE_DIRECT_CHILDREN | BROWSE_CONTAINERS);
-    auto arr = database->browse(param);
+    auto parent = database->loadObject(parentID);
+    auto arr = database->browse(std::make_unique<BrowseParam>(parent, BROWSE_DIRECT_CHILDREN | BROWSE_CONTAINERS));
     for (auto&& obj : arr) {
         //if (obj->isContainer())
         //{
@@ -74,8 +75,8 @@ void web::containers::process()
         int autoscanType = cont->getAutoscanType();
         ce.append_attribute("autoscan_type") = mapAutoscanType(autoscanType).data();
 
-        std::string url;
-        if (UpnpXMLBuilder::renderContainerImage(server->getVirtualUrl(), cont, url)) {
+        auto [url, artAdded] = xmlBuilder->renderContainerImage(server->getVirtualUrl(), cont);
+        if (artAdded) {
             ce.append_attribute("image") = url.c_str();
         }
 
@@ -84,8 +85,8 @@ void web::containers::process()
             autoscanMode = "timed";
 #ifdef HAVE_INOTIFY
             if (config->getBoolOption(CFG_IMPORT_AUTOSCAN_USE_INOTIFY)) {
-                std::shared_ptr<AutoscanDirectory> adir = database->getAutoscanDirectory(cont->getID());
-                if ((adir != nullptr) && (adir->getScanMode() == ScanMode::INotify))
+                auto adir = database->getAutoscanDirectory(cont->getID());
+                if (adir && (adir->getScanMode() == ScanMode::INotify))
                     autoscanMode = "inotify";
             }
 #endif
