@@ -41,8 +41,9 @@
 #include "upnp_xml.h"
 #include "util/tools.h"
 
-web::edit_load::edit_load(std::shared_ptr<ContentManager> content)
+web::edit_load::edit_load(std::shared_ptr<ContentManager> content, std::shared_ptr<UpnpXMLBuilder> xmlBuilder)
     : WebRequestHandler(std::move(content))
+    , xmlBuilder(std::move(xmlBuilder))
 {
 }
 
@@ -137,7 +138,7 @@ void web::edit_load::process()
 
         resEntry = resources.append_child("resources");
         resEntry.append_attribute("resname") = "handlerType";
-        resEntry.append_attribute("resvalue") = fmt::to_string(MetadataHandler::mapContentHandler2String(resItem->getHandlerType())).c_str();
+        resEntry.append_attribute("resvalue") = MetadataHandler::mapContentHandler2String(resItem->getHandlerType()).c_str();
         resEntry.append_attribute("editable") = false;
 
         // write resource content
@@ -195,7 +196,7 @@ void web::edit_load::process()
         mimeType.append_attribute("value") = objItem->getMimeType().c_str();
         mimeType.append_attribute("editable") = true;
 
-        auto [url, artAdded] = UpnpXMLBuilder::renderItemImage(server->getVirtualUrl(), objItem);
+        auto [url, artAdded] = xmlBuilder->renderItemImage(server->getVirtualUrl(), objItem);
         if (artAdded) {
             auto image = item.append_child("image");
             image.append_attribute("value") = url.c_str();
@@ -212,7 +213,7 @@ void web::edit_load::process()
     // write container meta info
     if (obj->isContainer()) {
         auto cont = std::static_pointer_cast<CdsContainer>(obj);
-        auto [url, artAdded] = UpnpXMLBuilder::renderContainerImage(server->getVirtualUrl(), cont);
+        auto [url, artAdded] = xmlBuilder->renderContainerImage(server->getVirtualUrl(), cont);
         if (artAdded) {
             auto image = item.append_child("image");
             image.append_attribute("value") = url.c_str();
