@@ -37,11 +37,13 @@
 #include "server.h"
 #include "upnp_xml.h"
 
-web::items::items(std::shared_ptr<ContentManager> content)
+web::items::items(std::shared_ptr<ContentManager> content, std::shared_ptr<UpnpXMLBuilder> xmlBuilder)
     : WebRequestHandler(std::move(content))
+    , xmlBuilder(std::move(xmlBuilder))
 {
 }
 
+/// \brief orocess request for item list in ui
 void web::items::process()
 {
     check_request();
@@ -54,23 +56,24 @@ void web::items::process()
     if (count < 0)
         throw_std_runtime_error("illegal count parameter");
 
+    // set result options
     auto root = xmlDoc->document_element();
-
     auto items = root.append_child("items");
     xml2JsonHints->setArrayName(items, "item");
     xml2JsonHints->setFieldType("title", "string");
     items.append_attribute("parent_id") = parentID;
 
     auto container = database->loadObject(parentID);
-    auto param = std::make_unique<BrowseParam>(parentID, BROWSE_DIRECT_CHILDREN | BROWSE_ITEMS);
+    auto param = std::make_unique<BrowseParam>(container, BROWSE_DIRECT_CHILDREN | BROWSE_ITEMS);
     param->setRange(start, count);
 
-    if ((container->getClass() == UPNP_CLASS_MUSIC_ALBUM) || (container->getClass() == UPNP_CLASS_PLAYLIST_CONTAINER))
+    auto c = container->getClass();
+    if (c == UPNP_CLASS_MUSIC_ALBUM || c == UPNP_CLASS_PLAYLIST_CONTAINER)
         param->setFlag(BROWSE_TRACK_SORT);
 
+    // get contents of request
     auto arr = database->browse(param);
     items.append_attribute("virtual") = container->isVirtual();
-
     items.append_attribute("start") = start;
     //items.append_attribute("returned") = arr->size();
     items.append_attribute("total_matches") = param->getTotalMatches();
@@ -81,23 +84,22 @@ void web::items::process()
 
     auto parentDir = database->getAutoscanDirectory(parentID);
     int autoscanType = 0;
-    if (parentDir != nullptr) {
+    if (parentDir) {
         autoscanType = parentDir->persistent() ? 2 : 1;
         autoscanMode = "timed";
     }
 
 #ifdef HAVE_INOTIFY
     if (config->getBoolOption(CFG_IMPORT_AUTOSCAN_USE_INOTIFY)) {
+        // check for inotify mode
         int startpoint_id = INVALID_OBJECT_ID;
         if (autoscanType == 0) {
             auto pathIDs = database->getPathIDs(parentID);
-            if (pathIDs != nullptr) {
-                for (int pathId : *pathIDs) {
-                    auto pathDir = database->getAutoscanDirectory(pathId);
-                    if (pathDir != nullptr && pathDir->getRecursive()) {
-                        startpoint_id = pathId;
-                        break;
-                    }
+            for (int pathId : pathIDs) {
+                auto pathDir = database->getAutoscanDirectory(pathId);
+                if (pathDir && pathDir->getRecursive()) {
+                    startpoint_id = pathId;
+                    break;
                 }
             }
         } else {
@@ -105,8 +107,8 @@ void web::items::process()
         }
 
         if (startpoint_id != INVALID_OBJECT_ID) {
-            std::shared_ptr<AutoscanDirectory> startPtDir = database->getAutoscanDirectory(startpoint_id);
-            if (startPtDir != nullptr && startPtDir->getScanMode() == ScanMode::INotify) {
+            auto startPtDir = database->getAutoscanDirectory(startpoint_id);
+            if (startPtDir && startPtDir->getScanMode() == ScanMode::INotify) {
                 protectItems = true;
                 if (autoscanType == 0 || startPtDir->persistent())
                     protectContainer = true;
@@ -121,24 +123,19 @@ void web::items::process()
     items.append_attribute("protect_container") = protectContainer;
     items.append_attribute("protect_items") = protectItems;
 
+    // ouput objects of container
     for (auto&& arrayObj : arr) {
-        //if (arrayObj->isItem())
-        //{
         auto item = items.append_child("item");
         item.append_attribute("id") = arrayObj->getID();
         item.append_child("title").append_child(pugi::node_pcdata).set_value(arrayObj->getTitle().c_str());
-        /// \todo clean this up, should have more generic options for online
-        /// services
-        // FIXME
+
         auto objItem = std::static_pointer_cast<CdsItem>(arrayObj);
         std::string res = UpnpXMLBuilder::getFirstResourcePath(objItem);
         item.append_child("res").append_child(pugi::node_pcdata).set_value(res.c_str());
 
-        std::string url;
-        if (UpnpXMLBuilder::renderItemImage(server->getVirtualUrl(), objItem, url)) {
+        auto [url, artAdded] = xmlBuilder->renderItemImage(server->getVirtualUrl(), objItem);
+        if (artAdded) {
             item.append_child("image").append_child(pugi::node_pcdata).set_value(url.c_str());
         }
-        //item.append_attribute("virtual") = arrayObj->isVirtual();
-        //}
     }
 }
