@@ -34,7 +34,9 @@
 namespace web {
 
 std::unique_ptr<WebRequestHandler> createWebRequestHandler(
+    std::shared_ptr<Context> context,
     std::shared_ptr<ContentManager> content,
+    std::shared_ptr<UpnpXMLBuilder> xmlBuilder,
     std::string_view page)
 {
     if (page == "add")
@@ -46,15 +48,15 @@ std::unique_ptr<WebRequestHandler> createWebRequestHandler(
     if (page == "auth")
         return std::make_unique<web::auth>(std::move(content));
     if (page == "containers")
-        return std::make_unique<web::containers>(std::move(content));
+        return std::make_unique<web::containers>(std::move(content), std::move(xmlBuilder));
     if (page == "directories")
         return std::make_unique<web::directories>(std::move(content));
     if (page == "files")
         return std::make_unique<web::files>(std::move(content));
     if (page == "items")
-        return std::make_unique<web::items>(std::move(content));
+        return std::make_unique<web::items>(std::move(content), std::move(xmlBuilder));
     if (page == "edit_load")
-        return std::make_unique<web::edit_load>(std::move(content));
+        return std::make_unique<web::edit_load>(std::move(content), std::move(xmlBuilder));
     if (page == "edit_save")
         return std::make_unique<web::edit_save>(std::move(content));
     if (page == "autoscan")
@@ -70,7 +72,7 @@ std::unique_ptr<WebRequestHandler> createWebRequestHandler(
     if (page == "config_load")
         return std::make_unique<web::configLoad>(std::move(content));
     if (page == "config_save")
-        return std::make_unique<web::configSave>(std::move(content));
+        return std::make_unique<web::configSave>(std::move(context), std::move(content));
 
     throw_std_runtime_error("Unknown page: {}", page);
 }
