@@ -44,10 +44,7 @@
 namespace web {
 
 Session::Session(std::chrono::seconds timeout)
-    : updateAll(false)
-    , uiUpdateIDs(std::make_shared<std::unordered_set<int>>())
-    , timeout(timeout)
-    , loggedIn(false)
+    : timeout(timeout)
 {
     access();
 }
@@ -71,11 +68,11 @@ void Session::containerChangedUI(int objectID)
     if (!updateAll) {
         AutoLockR lock(rmutex);
         if (!updateAll) {
-            if (uiUpdateIDs->size() >= MAX_UI_UPDATE_IDS) {
+            if (uiUpdateIDs.size() >= MAX_UI_UPDATE_IDS) {
                 updateAll = true;
-                uiUpdateIDs->clear();
+                uiUpdateIDs.clear();
             } else
-                uiUpdateIDs->insert(objectID);
+                uiUpdateIDs.insert(objectID);
         }
     }
 }
@@ -91,28 +88,29 @@ void Session::containerChangedUI(const std::vector<int>& objectIDs)
     if (updateAll)
         return;
 
-    if (uiUpdateIDs->size() + arSize >= MAX_UI_UPDATE_IDS) {
+    if (uiUpdateIDs.size() + arSize >= MAX_UI_UPDATE_IDS) {
         updateAll = true;
-        uiUpdateIDs->clear();
+        uiUpdateIDs.clear();
         return;
     }
-    for (int objectId : objectIDs) {
-        uiUpdateIDs->insert(objectId);
-    }
+
+    uiUpdateIDs.insert(objectIDs.begin(), objectIDs.end());
 }
 
 std::string Session::getUIUpdateIDs()
 {
     if (!hasUIUpdateIDs())
-        return "";
+        return {};
     AutoLockR lock(rmutex);
     if (updateAll) {
         updateAll = false;
         return "all";
     }
-    std::string ret = toCSV(uiUpdateIDs);
-    if (!ret.empty())
-        uiUpdateIDs->clear();
+    std::string ret;
+    if (!uiUpdateIDs.empty()) {
+        ret = fmt::format("{}", fmt::join(uiUpdateIDs, ","));
+        uiUpdateIDs.clear();
+    }
     return ret;
 }
 
@@ -121,22 +119,21 @@ bool Session::hasUIUpdateIDs() const
     if (updateAll)
         return true;
     // AutoLock lock(mutex); only accessing an int - shouldn't be necessary
-    return (!uiUpdateIDs->empty());
+    return !uiUpdateIDs.empty();
 }
 
 void Session::clearUpdateIDs()
 {
     log_debug("clearing UI updateIDs");
     AutoLockR lock(rmutex);
-    uiUpdateIDs->clear();
+    uiUpdateIDs.clear();
     updateAll = false;
 }
 
 SessionManager::SessionManager(const std::shared_ptr<Config>& config, std::shared_ptr<Timer> timer)
     : timer(std::move(timer))
-    , timerAdded(false)
+    , accounts(config->getDictionaryOption(CFG_SERVER_UI_ACCOUNT_LIST))
 {
-    accounts = config->getDictionaryOption(CFG_SERVER_UI_ACCOUNT_LIST);
 }
 
 std::shared_ptr<Session> SessionManager::createSession(std::chrono::seconds timeout)
@@ -150,7 +147,7 @@ std::shared_ptr<Session> SessionManager::createSession(std::chrono::seconds time
         sessionID = generateRandomId();
         if (count++ > 100)
             throw_std_runtime_error("There seems to be something wrong with the random numbers. I tried to get a unique id 100 times and failed. last sessionID: {}", sessionID);
-    } while (getSession(sessionID, false) != nullptr); // for the rare case, where we get a random id, that is already taken
+    } while (getSession(sessionID, false)); // for the rare case, where we get a random id, that is already taken
 
     newSession->setID(sessionID);
     sessions.push_back(newSession);
@@ -188,7 +185,7 @@ void SessionManager::removeSession(const std::string& sessionID)
     }
 }
 
-std::string SessionManager::getUserPassword(const std::string& user)
+std::string SessionManager::getUserPassword(const std::string& user) const
 {
     return getValueOrDefault(accounts, user);
 }
