@@ -65,12 +65,12 @@ void web::autoscan::process()
         if (fromFs) {
             autoscan.append_child("from_fs").append_child(pugi::node_pcdata).set_value("1");
             autoscan.append_child("object_id").append_child(pugi::node_pcdata).set_value(objID.c_str());
-            std::shared_ptr<AutoscanDirectory> adir = content->getAutoscanDirectory(path);
+            auto adir = content->getAutoscanDirectory(path);
             autoscan2XML(adir, &autoscan);
         } else {
             autoscan.append_child("from_fs").append_child(pugi::node_pcdata).set_value("0");
             autoscan.append_child("object_id").append_child(pugi::node_pcdata).set_value(objID.c_str());
-            std::shared_ptr<AutoscanDirectory> adir = database->getAutoscanDirectory(intParam("object_id"));
+            auto adir = database->getAutoscanDirectory(intParam("object_id"));
             autoscan2XML(adir, &autoscan);
         }
     } else if (action == "as_edit_save") {
@@ -78,11 +78,7 @@ void web::autoscan::process()
         if (scan_mode_str == "none") {
             // remove...
             try {
-                std::shared_ptr<AutoscanDirectory> adir;
-                if (fromFs)
-                    adir = content->getAutoscanDirectory(path);
-                else
-                    adir = content->getAutoscanDirectory(intParam("object_id"));
+                auto adir = fromFs ? content->getAutoscanDirectory(path) : content->getAutoscanDirectory(intParam("object_id"));
                 content->removeAutoscanDirectory(adir);
             } catch (const std::runtime_error& e) {
                 // didn't work, well we don't care in this case
@@ -142,7 +138,7 @@ void web::autoscan::process()
 
 void web::autoscan::autoscan2XML(const std::shared_ptr<AutoscanDirectory>& adir, pugi::xml_node* element)
 {
-    if (adir == nullptr) {
+    if (!adir) {
         element->append_child("scan_mode").append_child(pugi::node_pcdata).set_value("none");
         element->append_child("recursive").append_child(pugi::node_pcdata).set_value("0");
         element->append_child("hidden").append_child(pugi::node_pcdata).set_value("0");
