@@ -46,7 +46,6 @@ namespace web {
 WebRequestHandler::WebRequestHandler(std::shared_ptr<ContentManager> content)
     : RequestHandler(std::move(content))
     , sessionManager(this->content->getContext()->getSessionManager())
-    , checkRequestCalled(false)
 {
 }
 
@@ -75,7 +74,7 @@ void WebRequestHandler::check_request(bool checkLogin)
     if (sid.empty())
         throw SessionException("no session id given");
 
-    if ((session = sessionManager->getSession(sid)) == nullptr)
+    if (!(session = sessionManager->getSession(sid)))
         throw SessionException("invalid session id");
 
     if (checkLogin && !session->isLoggedIn())
@@ -85,7 +84,7 @@ void WebRequestHandler::check_request(bool checkLogin)
 
 std::string WebRequestHandler::renderXMLHeader()
 {
-    return std::string(R"(<?xml version="1.0" encoding=")") + DEFAULT_INTERNAL_CHARSET + "\"?>\n";
+    return fmt::format((R"(<?xml version="1.0" encoding="{}"?>{})"), DEFAULT_INTERNAL_CHARSET, "\n");
 }
 
 void WebRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
@@ -107,25 +106,25 @@ void WebRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
     std::string mimetype = (returnType == "xml") ? MIMETYPE_XML : MIMETYPE_JSON;
     std::string contentType = mimetype + "; charset=" + DEFAULT_INTERNAL_CHARSET;
 
-#if defined(USING_NPUPNP)
-    UpnpFileInfo_set_ContentType(info, contentType);
+#ifdef USING_NPUPNP
+    info->content_type = std::move(contentType);
 #else
-    UpnpFileInfo_set_ContentType(info, ixmlCloneDOMString(contentType.c_str()));
+    UpnpFileInfo_set_ContentType(info, contentType.c_str());
 #endif
     Headers headers;
-    headers.addHeader(std::string { "Cache-Control" }, std::string { "no-cache, must-revalidate" });
+    headers.addHeader("Cache-Control", "no-cache, must-revalidate");
     headers.writeHeaders(info);
 }
 
 std::unique_ptr<IOHandler> WebRequestHandler::open(enum UpnpOpenFileMode mode)
 {
-    xmlDoc = std::make_shared<pugi::xml_document>();
+    xmlDoc = std::make_unique<pugi::xml_document>();
     auto decl = xmlDoc->prepend_child(pugi::node_declaration);
     decl.append_attribute("version") = "1.0";
     decl.append_attribute("encoding") = "UTF-8";
     auto root = xmlDoc->append_child("root");
 
-    xml2JsonHints = std::make_shared<Xml2Json::Hints>();
+    xml2JsonHints = std::make_unique<Xml2Json::Hints>();
 
     std::string error;
     int error_code = 0;
@@ -160,7 +159,7 @@ std::unique_ptr<IOHandler> WebRequestHandler::open(enum UpnpOpenFileMode mode)
         error = e.getUserMessage();
         error_code = 500;
     } catch (const std::runtime_error& e) {
-        error = std::string { "Error: " } + e.what();
+        error = fmt::format("Error: {}", e.what());
         error_code = 800;
     }
 
@@ -258,7 +257,7 @@ void WebRequestHandler::addUpdateIDs(const std::shared_ptr<Session>& session, pu
 
 void WebRequestHandler::appendTask(const std::shared_ptr<GenericTask>& task, pugi::xml_node* parent)
 {
-    if (task == nullptr || parent == nullptr)
+    if (!task || !parent)
         return;
     auto taskEl = parent->append_child("task");
     taskEl.append_attribute("id") = task->getID();
