@@ -26,7 +26,7 @@ Gerbera - https://gerbera.io/
 
 class MySQLConfigFake : public Config {
 public:
-    fs::path getConfigFilename() const override { return ""; }
+    fs::path getConfigFilename() const override { return {}; }
     std::string getOption(config_option_t option) const override {
         if (option == CFG_SERVER_STORAGE_MYSQL_HOST) {
             return "hydra.home";
@@ -46,18 +46,18 @@ public:
 //        if (option == CFG_SERVER_STORAGE_MYSQL_DATABASE) {
 //            return "gerbera";
 //        }
-        return "";
-    };
+        return {};
+    }
     void addOption(config_option_t option, std::shared_ptr<ConfigOption> optionValue) override { }
     int getIntOption(config_option_t option) const override { return 0; }
     bool getBoolOption(config_option_t option) const override { return false; }
-    std::map<std::string, std::string> getDictionaryOption(config_option_t option) const override { return std::map<std::string, std::string>(); }
-    std::vector<std::string> getArrayOption(config_option_t option) const override { return std::vector<std::string>(); }
+    std::map<std::string, std::string> getDictionaryOption(config_option_t option) const override { return {}; }
+    std::vector<std::string> getArrayOption(config_option_t option) const override { return {}; }
     std::shared_ptr<AutoscanList> getAutoscanListOption(config_option_t option) const override { return nullptr; }
     std::shared_ptr<ClientConfigList> getClientConfigListOption(config_option_t option) const override { return nullptr; }
     std::shared_ptr<DirectoryConfigList> getDirectoryTweakOption(config_option_t option) const override { return nullptr; }
-    void updateConfigFromDatabase(std::shared_ptr<Database> database) override {};
-    std::string getOrigValue(const std::string& item) const override { return ""; }
+    void updateConfigFromDatabase(std::shared_ptr<Database> database) override {}
+    std::string getOrigValue(const std::string& item) const override { return {}; }
     void setOrigValue(const std::string& item, const std::string& value) override { }
     void setOrigValue(const std::string& item, bool value) override { }
     void setOrigValue(const std::string& item, int value) override { }
