@@ -10,8 +10,8 @@ using namespace ::testing;
 
 class ConfigMock : public Config {
 public:
-    fs::path getConfigFilename() const override { return ""; }
-    fs::path getDataDir() const override { return ""; }
+    fs::path getConfigFilename() const override { return {}; }
+    fs::path getDataDir() const override { return {}; }
     MOCK_METHOD(std::string, getOption, (config_option_t option), (const override));
     void addOption(config_option_t option, std::shared_ptr<ConfigOption> optionValue) override { }
     int getIntOption(config_option_t option) const override { return 0; }
@@ -34,15 +34,15 @@ public:
                     { "upnp:genre", "M_GENRE" },
                 };
             default:
-                return std::map<std::string, std::string>();
+                return {};
         }
     }
-    std::vector<std::string> getArrayOption(config_option_t option) const override { return std::vector<std::string>(); }
+    std::vector<std::string> getArrayOption(config_option_t option) const override { return {}; }
     std::shared_ptr<AutoscanList> getAutoscanListOption(config_option_t option) const override { return nullptr; }
     std::shared_ptr<ClientConfigList> getClientConfigListOption(config_option_t option) const override { return nullptr; }
     std::shared_ptr<DirectoryConfigList> getDirectoryTweakOption(config_option_t option) const override { return nullptr; }
-    void updateConfigFromDatabase(std::shared_ptr<Database> database) override {};
-    std::string getOrigValue(const std::string& item) const override { return ""; }
+    void updateConfigFromDatabase(std::shared_ptr<Database> database) override {}
+    std::string getOrigValue(const std::string& item) const override { return {}; }
     void setOrigValue(const std::string& item, const std::string& value) override { }
     void setOrigValue(const std::string& item, bool value) override { }
     void setOrigValue(const std::string& item, int value) override { }
