@@ -2,9 +2,9 @@
 #ifndef GERBERA_SCRIPTTESTFIXTURE_H
 #define GERBERA_SCRIPTTESTFIXTURE_H
 
+#include <duktape.h>
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
-#include <duktape.h>
 #include <memory>
 
 #include "util/string_converter.h"
@@ -12,37 +12,31 @@
 #include "common_script_mock.h"
 
 using namespace ::testing;
-using namespace std;
 
-struct _addCdsObjectParams {
-    map<string, string> objectValues;
-    string containerChain;
-    string objectType;
+struct addCdsObjectParams {
+    std::map<std::string, std::string> objectValues;
+    std::string containerChain;
+    std::string objectType;
 };
-typedef struct _addCdsObjectParams addCdsObjectParams;
 
-struct _abcBoxParams {
-    string inputValue;
+struct abcBoxParams {
+    std::string inputValue;
     int boxType;
-    string divChar;
+    std::string divChar;
 };
-typedef struct _abcBoxParams abcBoxParams;
 
-struct _getRootPathParams {
-    string objScriptPath;
-    string origObjLocation;
+struct getRootPathParams {
+    std::string objScriptPath;
+    std::string origObjLocation;
 };
-typedef struct _getRootPathParams getRootPathParams;
 
-struct _copyObjectParams {
+struct copyObjectParams {
     bool isObject;
 };
-typedef struct _copyObjectParams copyObjectParams;
 
-struct _getCdsObjectParams {
-    string location;
+struct getCdsObjectParams {
+    std::string location;
 };
-typedef struct _getCdsObjectParams getCdsObjectParams;
 
 // The class provides a way to test the Duktape scripts
 // providing various c++ translations of script functions
@@ -54,18 +48,18 @@ class ScriptTestFixture : public ::testing::Test {
 public:
     // Builds up the Duktape context
     // Reads in the script under test
-    virtual void SetUp();
+    void SetUp() override;
 
     // Destroys the Duktape context
-    virtual void TearDown();
+    void TearDown() override;
 
     // Creates a mock item(orig) global object in Duktape context
-    duk_ret_t dukMockItem(duk_context* ctx, string mimetype, string id, int theora, string title,
-        map<string, string> meta, map<string, string> aux, map<string, string> res,
-        string location, int online_service);
+    static duk_ret_t dukMockItem(duk_context* ctx, const std::string& mimetype, const std::string& id, int theora, const std::string& title,
+        const std::map<std::string, std::string>& meta, const std::map<std::string, std::string>& aux, const std::map<std::string, std::string>& res,
+        const std::string& location, int online_service);
 
     // Creates a mock playlist global object in Duktape context
-    duk_ret_t dukMockPlaylist(duk_context* ctx, string title, string location, string mimetype);
+    static duk_ret_t dukMockPlaylist(duk_context* ctx, const std::string& title, const std::string& location, const std::string& mimetype);
 
     // Add global Duktape methods to proxy into c++ layer
     void addGlobalFunctions(duk_context* ctx, const duk_function_list_entry* funcs, const std::map<std::string_view, std::string_view>& config = {});
@@ -74,44 +68,44 @@ public:
     static void addConfig(duk_context* ctx, const std::map<std::string_view, std::string_view>& config);
 
     // Access the global object(script) by name, and execute
-    void executeScript(duk_context* ctx);
+    static void executeScript(duk_context* ctx);
 
     // Proxy the common.js script with `createContainerChain`
     // Mimics the creation of a directory chain
     // Returns the chain as a vector of strings (for easy expectations)
-    static vector<string> createContainerChain(duk_context* ctx);
+    static std::vector<std::string> createContainerChain(duk_context* ctx);
 
     // Proxy the common.js script with `getLastPath`
     // Mimics finding the last path of the item
     // Pushes the last path value to the Duktape stack
     // Returns the inputPath parameter sent by the script
-    static string getLastPath(duk_context* ctx);
+    static std::string getLastPath(duk_context* ctx);
 
     // Proxy the common.js script with `getPlaylistType`
     // Mimics determination of the playlist type
     // Pushes the playlist type `m3u`, `pls` to the duktape stack
     // Returns the input parameter matching the mimetype
     // sent by the script
-    static string getPlaylistType(duk_context* ctx);
+    static std::string getPlaylistType(duk_context* ctx);
 
     // Proxy the common.js script with `print`
     // Mimics the print of text
     // Returns the string sent by the script to print
-    static string print(duk_context* ctx);
+    static std::string print(duk_context* ctx);
 
     // Proxy the common.js script with `getYear`
     // Mimics the parsing of YYYY
     // Pushes the year in YYYY format to the duktape context
     // Returns the full date sent by the script
-    static string getYear(duk_context* ctx);
+    static std::string getYear(duk_context* ctx);
 
     // Proxy the Duktape script with `addCdsObject` global function.
     // Translates the Duktape value stack to c++
-    static addCdsObjectParams addCdsObject(duk_context* ctx, vector<string> objectKeys);
+    static addCdsObjectParams addCdsObject(duk_context* ctx, const std::vector<std::string>& objectKeys);
 
     // Proxy the Duktape script with `addContainerTree` C function.
     // Translates the Duktape value stack to c++
-    static vector<string> addContainerTree(duk_context* ctx, map<string, string> resMap);
+    static std::vector<std::string> addContainerTree(duk_context* ctx, std::map<std::string, std::string> resMap);
 
     // Proxy the Duktape script with `abcbox` common.js function
     static abcBoxParams abcBox(duk_context* ctx);
@@ -120,16 +114,16 @@ public:
     static getRootPathParams getRootPath(duk_context* ctx);
 
     // Proxy the Duktape script with `copyObject` global function
-    static copyObjectParams copyObject(duk_context* ctx, map<string, string> obj, map<string, string> meta);
+    static copyObjectParams copyObject(duk_context* ctx, const std::map<std::string, std::string>& obj, const std::map<std::string, std::string>& meta);
 
     // Proxy the Duktape script with `copyObject` global function
-    static getCdsObjectParams getCdsObject(duk_context* ctx, map<string, string> obj, map<string, string> meta);
+    static getCdsObjectParams getCdsObject(duk_context* ctx, const std::map<std::string, std::string>& obj, const std::map<std::string, std::string>& meta);
 
     // Script file name under test
     // System defaults to known project path `/scripts/js/<scriptName>`
-    string scriptName;
+    std::string scriptName;
     // Select audio layout to test
-    string audioLayout;
+    std::string audioLayout;
 
     // The Duktape Context
     duk_context* ctx;
