@@ -1,8 +1,8 @@
 #ifdef HAVE_JS
 
+#include <duktape.h>
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
-#include <duktape.h>
 #include <memory>
 
 #include "cds_objects.h"
@@ -23,34 +23,34 @@ public:
     {
         commonScriptMock = std::make_unique<::testing::NiceMock<CommonScriptMock>>();
         scriptName = "import.js";
-    };
+    }
 
     ~ImportScriptTest() override
     {
         commonScriptMock.reset();
-    };
+    }
 
     // As Duktape requires static methods, so must the mock expectations be
-    static unique_ptr<CommonScriptMock> commonScriptMock;
+    static std::unique_ptr<CommonScriptMock> commonScriptMock;
 };
 
-unique_ptr<CommonScriptMock> ImportScriptTest::commonScriptMock;
+std::unique_ptr<CommonScriptMock> ImportScriptTest::commonScriptMock;
 
 static duk_ret_t print(duk_context* ctx)
 {
-    string msg = ScriptTestFixture::print(ctx);
+    std::string msg = ScriptTestFixture::print(ctx);
     return ImportScriptTest::commonScriptMock->print(msg);
 }
 
 static duk_ret_t getPlaylistType(duk_context* ctx)
 {
-    string playlistMimeType = ScriptTestFixture::getPlaylistType(ctx);
+    std::string playlistMimeType = ScriptTestFixture::getPlaylistType(ctx);
     return ImportScriptTest::commonScriptMock->getPlaylistType(playlistMimeType);
 }
 
 static duk_ret_t addContainerTree(duk_context* ctx)
 {
-    map<string,string> map = {
+    std::map<std::string, std::string> map {
         { "", "0" },
         { "/Audio/All Audio", "42" },
         { "/Audio/Artists/Artist/All Songs", "43" },
@@ -72,25 +72,25 @@ static duk_ret_t addContainerTree(duk_context* ctx)
         { "/Online Services/Apple Trailers/Release Date/2018-01", "82" },
         { "/Online Services/Apple Trailers/Post Date/2018-01", "83" },
     };
-    vector<string> tree = ScriptTestFixture::addContainerTree(ctx, map);
+    std::vector<std::string> tree = ScriptTestFixture::addContainerTree(ctx, map);
     return ImportScriptTest::commonScriptMock->addContainerTree(tree);
 }
 
 static duk_ret_t createContainerChain(duk_context* ctx)
 {
-    vector<string> array = ScriptTestFixture::createContainerChain(ctx);
+    std::vector<std::string> array = ScriptTestFixture::createContainerChain(ctx);
     return ImportScriptTest::commonScriptMock->createContainerChain(array);
 }
 
 static duk_ret_t getLastPath(duk_context* ctx)
 {
-    string inputPath = ScriptTestFixture::getLastPath(ctx);
+    std::string inputPath = ScriptTestFixture::getLastPath(ctx);
     return ImportScriptTest::commonScriptMock->getLastPath(inputPath);
 }
 
 static duk_ret_t addCdsObject(duk_context* ctx)
 {
-    vector<string> keys = {
+    std::vector<std::string> keys {
         "title",
         "meta['dc:title']",
         "meta['upnp:artist']",
@@ -109,7 +109,7 @@ static duk_ret_t addCdsObject(duk_context* ctx)
 
 static duk_ret_t getYear(duk_context* ctx)
 {
-    string date = ScriptTestFixture::getYear(ctx);
+    std::string date = ScriptTestFixture::getYear(ctx);
     return ImportScriptTest::commonScriptMock->getYear(date);
 }
 
@@ -153,57 +153,57 @@ TEST_F(ImportScriptTest, CreatesDukContextWithImportScript)
 
 TEST_F(ImportScriptTest, AddsAudioItemToVariousCdsContainerChains)
 {
-    string title = "Audio Title";
-    string mimetype = "audio/mpeg";
-    string artist = "Artist";
-    string album = "Album";
-    string composer = "Composer";
-    string conductor = "Conductor";
-    string orchestra = "Orchestra";
-    string date = "2018-01-01";
-    string year = "2018";
-    string genre = "Genre";
-    string desc = "Description";
-    string id = "2";
-    string location = "/home/gerbera/audio.mp3";
-    string channels = "2";
+    std::string title = "Audio Title";
+    std::string mimetype = "audio/mpeg";
+    std::string artist = "Artist";
+    std::string album = "Album";
+    std::string composer = "Composer";
+    std::string conductor = "Conductor";
+    std::string orchestra = "Orchestra";
+    std::string date = "2018-01-01";
+    std::string year = "2018";
+    std::string genre = "Genre";
+    std::string desc = "Description";
+    std::string id = "2";
+    std::string location = "/home/gerbera/audio.mp3";
+    std::string channels = "2";
     int online_service = 0;
     int theora = 0;
-    map<string, string> aux;
+    std::map<std::string, std::string> aux;
 
-    map<string, string> meta = {
-        make_pair("dc:title", title),
-        make_pair("upnp:artist", artist),
-        make_pair("upnp:album", album),
-        make_pair("dc:date", date),
-        make_pair("upnp:date", year),
-        make_pair("upnp:genre", genre),
-        make_pair("dc:description", desc),
-        make_pair("upnp:composer", composer),
-        make_pair("upnp:conductor", conductor),
-        make_pair("upnp:orchestra", orchestra)
+    std::map<std::string, std::string> meta {
+        { "dc:title", title },
+        { "upnp:artist", artist },
+        { "upnp:album", album },
+        { "dc:date", date },
+        { "upnp:date", year },
+        { "upnp:genre", genre },
+        { "dc:description", desc },
+        { "upnp:composer", composer },
+        { "upnp:conductor", conductor },
+        { "upnp:orchestra", orchestra },
     };
 
-    map<string, string> res = {
-        make_pair("res['nrAudioChannels']", channels)
+    std::map<std::string, std::string> res {
+        { "res['nrAudioChannels']", channels },
     };
 
     // Represents the values passed to `addCdsObject`, extracted from keys defined there.
-    map<string, string> asAudioAllAudio = {
-        make_pair("title", title),
-        make_pair("meta['dc:title']", title),
-        make_pair("meta['upnp:artist']", artist),
-        make_pair("meta['upnp:album']", album),
-        make_pair("meta['dc:date']", date),
-        make_pair("meta['upnp:date']", year),
-        make_pair("meta['upnp:genre']", genre),
-        make_pair("meta['dc:description']", desc),
-        make_pair("meta['upnp:composer']", composer),
-        make_pair("meta['upnp:conductor']", conductor),
-        make_pair("meta['upnp:orchestra']", orchestra)
+    std::map<std::string, std::string> asAudioAllAudio {
+        { "title", title },
+        { "meta['dc:title']", title },
+        { "meta['upnp:artist']", artist },
+        { "meta['upnp:album']", album },
+        { "meta['dc:date']", date },
+        { "meta['upnp:date']", year },
+        { "meta['upnp:genre']", genre },
+        { "meta['dc:description']", desc },
+        { "meta['upnp:composer']", composer },
+        { "meta['upnp:conductor']", conductor },
+        { "meta['upnp:orchestra']", orchestra },
     };
 
-    map<string, string> asAudioAllFullName;
+    std::map<std::string, std::string> asAudioAllFullName;
     asAudioAllFullName.insert(asAudioAllAudio.begin(), asAudioAllAudio.end());
     asAudioAllFullName["title"] = "Artist - Album - Audio Title";
 
@@ -247,19 +247,19 @@ TEST_F(ImportScriptTest, AddsAudioItemToVariousCdsContainerChains)
 
 TEST_F(ImportScriptTest, AddsVideoItemToCdsContainerChainWithDirs)
 {
-    string title = "Video Title";
-    string mimetype = "video/mpeg";
-    string id = "2";
-    string location = "/home/gerbera/video.mp4";
+    std::string title = "Video Title";
+    std::string mimetype = "video/mpeg";
+    std::string id = "2";
+    std::string location = "/home/gerbera/video.mp4";
     auto online_service = int(OS_None);
     int theora = 0;
-    map<string, string> aux;
-    map<string, string> meta;
-    map<string, string> res;
+    std::map<std::string, std::string> aux;
+    std::map<std::string, std::string> meta;
+    std::map<std::string, std::string> res;
 
     // Represents the values passed to `addCdsObject`, extracted from keys defined there.
-    map<string, string> asVideoAllVideo = {
-        make_pair("title", title)
+    std::map<std::string, std::string> asVideoAllVideo {
+        { "title", title },
     };
 
     // Expecting the common script calls
@@ -282,30 +282,30 @@ TEST_F(ImportScriptTest, AddsVideoItemToCdsContainerChainWithDirs)
 
 TEST_F(ImportScriptTest, AddsAppleTrailerVideoItemToCdsContainerChains)
 {
-    string title = "Video Title";
-    string mimetype = "video/mpeg";
-    string date = "2018-01-01";
-    string genre = "Genre";
-    string id = "2";
-    string location = "/home/gerbera/video.mp4";
+    std::string title = "Video Title";
+    std::string mimetype = "video/mpeg";
+    std::string date = "2018-01-01";
+    std::string genre = "Genre";
+    std::string id = "2";
+    std::string location = "/home/gerbera/video.mp4";
     auto online_service = int(OS_ATrailers);
     int theora = 0;
-    map<string, string> res;
+    std::map<std::string, std::string> res;
 
-    map<string, string> meta = {
-        make_pair("dc:date", date),
-        make_pair("upnp:genre", genre)
+    std::map<std::string, std::string> meta {
+        { "dc:date", date },
+        { "upnp:genre", genre },
     };
 
-    map<string, string> aux = {
-        make_pair("T0", date)
+    std::map<std::string, std::string> aux {
+        { "T0", date },
     };
 
     // Represents the values passed to `addCdsObject`, extracted from keys defined there.
-    map<string, string> asVideoAllVideo = {
-        make_pair("title", title),
-        make_pair("meta['dc:date']", date),
-        make_pair("meta['upnp:genre']", genre)
+    std::map<std::string, std::string> asVideoAllVideo {
+        { "title", title },
+        { "meta['dc:date']", date },
+        { "meta['upnp:genre']", genre },
     };
 
     // Expecting the common script calls
@@ -332,25 +332,25 @@ TEST_F(ImportScriptTest, AddsAppleTrailerVideoItemToCdsContainerChains)
 
 TEST_F(ImportScriptTest, AddsImageItemToCdsContainerChains)
 {
-    string title = "Image Title";
-    string mimetype = "image/jpeg";
-    string date = "2018-01-01";
-    string id = "2";
-    string location = "/home/gerbera/image.jpg";
+    std::string title = "Image Title";
+    std::string mimetype = "image/jpeg";
+    std::string date = "2018-01-01";
+    std::string id = "2";
+    std::string location = "/home/gerbera/image.jpg";
     auto online_service = int(OS_ATrailers);
     int theora = 0;
 
-    map<string, string> meta = {
-        make_pair("dc:date", date)
+    std::map<std::string, std::string> meta {
+        { "dc:date", date },
     };
 
-    map<string, string> aux;
-    map<string, string> res;
+    std::map<std::string, std::string> aux;
+    std::map<std::string, std::string> res;
 
     // Represents the values passed to `addCdsObject`, extracted from keys defined there.
-    map<string, string> asImagePhotos = {
-        make_pair("title", title),
-        make_pair("meta['dc:date']", date)
+    std::map<std::string, std::string> asImagePhotos {
+        { "title", title },
+        { "meta['dc:date']", date },
     };
 
     // Expecting the common script calls
@@ -379,19 +379,19 @@ TEST_F(ImportScriptTest, AddsImageItemToCdsContainerChains)
 
 TEST_F(ImportScriptTest, AddsOggTheoraVideoItemToCdsContainerChainWithDirs)
 {
-    string title = "Video Title";
-    string mimetype = "application/ogg";
-    string id = "2";
-    string location = "/home/gerbera/video.ogg";
+    std::string title = "Video Title";
+    std::string mimetype = "application/ogg";
+    std::string id = "2";
+    std::string location = "/home/gerbera/video.ogg";
     auto online_service = int(OS_None);
     int theora = 1;
-    map<string, string> aux;
-    map<string, string> meta;
-    map<string, string> res;
+    std::map<std::string, std::string> aux;
+    std::map<std::string, std::string> meta;
+    std::map<std::string, std::string> res;
 
     // Represents the values passed to `addCdsObject`, extracted from keys defined there.
-    map<string, string> asVideoAllVideo = {
-        make_pair("title", title)
+    std::map<std::string, std::string> asVideoAllVideo {
+        { "title", title },
     };
 
     // Expecting the common script calls
@@ -414,57 +414,57 @@ TEST_F(ImportScriptTest, AddsOggTheoraVideoItemToCdsContainerChainWithDirs)
 
 TEST_F(ImportScriptTest, AddsOggTheoraAudioItemToVariousCdsContainerChains)
 {
-    string title = "Audio Title";
-    string mimetype = "application/ogg";
-    string artist = "Artist";
-    string album = "Album";
-    string date = "2018-01-01";
-    string year = "2018";
-    string genre = "Genre";
-    string desc = "Description";
-    string composer = "Composer";
-    string conductor = "Conductor";
-    string orchestra = "Orchestra";
-    string id = "2";
-    string location = "/home/gerbera/audio.mp3";
-    string channels = "2";
+    std::string title = "Audio Title";
+    std::string mimetype = "application/ogg";
+    std::string artist = "Artist";
+    std::string album = "Album";
+    std::string date = "2018-01-01";
+    std::string year = "2018";
+    std::string genre = "Genre";
+    std::string desc = "Description";
+    std::string composer = "Composer";
+    std::string conductor = "Conductor";
+    std::string orchestra = "Orchestra";
+    std::string id = "2";
+    std::string location = "/home/gerbera/audio.mp3";
+    std::string channels = "2";
     int online_service = 0;
     int theora = 0;
-    map<string, string> aux;
+    std::map<std::string, std::string> aux;
 
-    map<string, string> meta = {
-        make_pair("dc:title", title),
-        make_pair("upnp:artist", artist),
-        make_pair("upnp:album", album),
-        make_pair("dc:date", date),
-        make_pair("upnp:date", year),
-        make_pair("upnp:genre", genre),
-        make_pair("dc:description", desc),
-        make_pair("upnp:composer", composer),
-        make_pair("upnp:conductor", conductor),
-        make_pair("upnp:orchestra", orchestra)
+    std::map<std::string, std::string> meta {
+        { "dc:title", title },
+        { "upnp:artist", artist },
+        { "upnp:album", album },
+        { "dc:date", date },
+        { "upnp:date", year },
+        { "upnp:genre", genre },
+        { "dc:description", desc },
+        { "upnp:composer", composer },
+        { "upnp:conductor", conductor },
+        { "upnp:orchestra", orchestra },
     };
 
-    map<string, string> res = {
-        make_pair("res['nrAudioChannels']", channels)
+    std::map<std::string, std::string> res {
+        { "res['nrAudioChannels']", channels },
     };
 
     // Represents the values passed to `addCdsObject`, extracted from keys defined there.
-    map<string, string> asAudioAllAudio = {
-        make_pair("title", title),
-        make_pair("meta['dc:title']", title),
-        make_pair("meta['upnp:artist']", artist),
-        make_pair("meta['upnp:album']", album),
-        make_pair("meta['dc:date']", date),
-        make_pair("meta['upnp:date']", year),
-        make_pair("meta['upnp:genre']", genre),
-        make_pair("meta['dc:description']", desc),
-        make_pair("meta['upnp:composer']", composer),
-        make_pair("meta['upnp:conductor']", conductor),
-        make_pair("meta['upnp:orchestra']", orchestra)
+    std::map<std::string, std::string> asAudioAllAudio {
+        { "title", title },
+        { "meta['dc:title']", title },
+        { "meta['upnp:artist']", artist },
+        { "meta['upnp:album']", album },
+        { "meta['dc:date']", date },
+        { "meta['upnp:date']", year },
+        { "meta['upnp:genre']", genre },
+        { "meta['dc:description']", desc },
+        { "meta['upnp:composer']", composer },
+        { "meta['upnp:conductor']", conductor },
+        { "meta['upnp:orchestra']", orchestra },
     };
 
-    map<string, string> asAudioAllFullName;
+    std::map<std::string, std::string> asAudioAllFullName;
     asAudioAllFullName.insert(asAudioAllAudio.begin(), asAudioAllAudio.end());
     asAudioAllFullName["title"] = "Artist - Album - Audio Title";
 
